Class: Repull::AccountDisconnectedPayload

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/account_disconnected_payload.rb

Overview

Payload for ‘account.disconnected`. A PMS or channel connection was revoked, expired, or rejected by the upstream provider.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccountDisconnectedPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/repull/models/account_disconnected_payload.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AccountDisconnectedPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AccountDisconnectedPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'account_id')
    self. = attributes[:'account_id']
  end

  if attributes.key?(:'connection_id')
    self.connection_id = attributes[:'connection_id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'disconnected_at')
    self.disconnected_at = attributes[:'disconnected_at']
  end

  if attributes.key?(:'reason')
    self.reason = attributes[:'reason']
  end
end

Instance Attribute Details

#account_idObject

Returns the value of attribute account_id.



21
22
23
# File 'lib/repull/models/account_disconnected_payload.rb', line 21

def 
  @account_id
end

#connection_idObject

Stable connection identifier — alias of accountId for this event variant.



24
25
26
# File 'lib/repull/models/account_disconnected_payload.rb', line 24

def connection_id
  @connection_id
end

#disconnected_atObject

Returns the value of attribute disconnected_at.



28
29
30
# File 'lib/repull/models/account_disconnected_payload.rb', line 28

def disconnected_at
  @disconnected_at
end

#providerObject

Returns the value of attribute provider.



26
27
28
# File 'lib/repull/models/account_disconnected_payload.rb', line 26

def provider
  @provider
end

#reasonObject

Why the connection was lost. ‘refresh_token_rejected` — upstream OAuth refresh endpoint returned a hard rejection. `manual_disconnect` — host/admin disconnected via the dashboard. `auth_expired` — credentials aged out without ever being used. `revoked_upstream` — provider notified us the user revoked access.



31
32
33
# File 'lib/repull/models/account_disconnected_payload.rb', line 31

def reason
  @reason
end

#workspace_idObject

Returns the value of attribute workspace_id.



19
20
21
# File 'lib/repull/models/account_disconnected_payload.rb', line 19

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/repull/models/account_disconnected_payload.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/repull/models/account_disconnected_payload.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/repull/models/account_disconnected_payload.rb', line 34

def self.attribute_map
  {
    :'workspace_id' => :'workspaceId',
    :'account_id' => :'accountId',
    :'connection_id' => :'connectionId',
    :'provider' => :'provider',
    :'disconnected_at' => :'disconnectedAt',
    :'reason' => :'reason'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/repull/models/account_disconnected_payload.rb', line 158

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
72
# File 'lib/repull/models/account_disconnected_payload.rb', line 68

def self.openapi_nullable
  Set.new([
    :'connection_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/repull/models/account_disconnected_payload.rb', line 56

def self.openapi_types
  {
    :'workspace_id' => :'String',
    :'account_id' => :'String',
    :'connection_id' => :'String',
    :'provider' => :'String',
    :'disconnected_at' => :'Time',
    :'reason' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



132
133
134
135
136
137
138
139
140
141
# File 'lib/repull/models/account_disconnected_payload.rb', line 132

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      workspace_id == o.workspace_id &&
       == o. &&
      connection_id == o.connection_id &&
      provider == o.provider &&
      disconnected_at == o.disconnected_at &&
      reason == o.reason
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


145
146
147
# File 'lib/repull/models/account_disconnected_payload.rb', line 145

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



151
152
153
# File 'lib/repull/models/account_disconnected_payload.rb', line 151

def hash
  [workspace_id, , connection_id, provider, disconnected_at, reason].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
# File 'lib/repull/models/account_disconnected_payload.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/repull/models/account_disconnected_payload.rb', line 180

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



125
126
127
128
# File 'lib/repull/models/account_disconnected_payload.rb', line 125

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end