Class: Repull::AiOperationCompletedPayload
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::AiOperationCompletedPayload
- Defined in:
- lib/repull/models/ai_operation_completed_payload.rb
Overview
Payload for ‘ai.operation.completed`. An async AI run (review response, message draft, pricing suggestion) finished.
Instance Attribute Summary collapse
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#input_summary ⇒ Object
Returns the value of attribute input_summary.
-
#operation_id ⇒ Object
Returns the value of attribute operation_id.
-
#output ⇒ Object
Operation-specific output object.
-
#tokens_used ⇒ Object
Returns the value of attribute tokens_used.
-
#type ⇒ Object
AI operation kind — e.g.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AiOperationCompletedPayload
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AiOperationCompletedPayload
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AiOperationCompletedPayload` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AiOperationCompletedPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'operation_id') self.operation_id = attributes[:'operation_id'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'input_summary') self.input_summary = attributes[:'input_summary'] end if attributes.key?(:'output') if (value = attributes[:'output']).is_a?(Hash) self.output = value end end if attributes.key?(:'tokens_used') self.tokens_used = attributes[:'tokens_used'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end end |
Instance Attribute Details
#completed_at ⇒ Object
Returns the value of attribute completed_at.
31 32 33 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 31 def completed_at @completed_at end |
#input_summary ⇒ Object
Returns the value of attribute input_summary.
24 25 26 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 24 def input_summary @input_summary end |
#operation_id ⇒ Object
Returns the value of attribute operation_id.
19 20 21 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 19 def operation_id @operation_id end |
#output ⇒ Object
Operation-specific output object.
27 28 29 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 27 def output @output end |
#tokens_used ⇒ Object
Returns the value of attribute tokens_used.
29 30 31 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 29 def tokens_used @tokens_used end |
#type ⇒ Object
AI operation kind — e.g. respond-to-guest, price-suggestion, review-response.
22 23 24 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 22 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 43 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 34 def self.attribute_map { :'operation_id' => :'operationId', :'type' => :'type', :'input_summary' => :'inputSummary', :'output' => :'output', :'tokens_used' => :'tokensUsed', :'completed_at' => :'completedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 159 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
68 69 70 71 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 68 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 56 def self.openapi_types { :'operation_id' => :'String', :'type' => :'String', :'input_summary' => :'String', :'output' => :'Hash<String, Object>', :'tokens_used' => :'Integer', :'completed_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
133 134 135 136 137 138 139 140 141 142 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 133 def ==(o) return true if self.equal?(o) self.class == o.class && operation_id == o.operation_id && type == o.type && input_summary == o.input_summary && output == o.output && tokens_used == o.tokens_used && completed_at == o.completed_at end |
#eql?(o) ⇒ Boolean
146 147 148 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 146 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
152 153 154 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 152 def hash [operation_id, type, input_summary, output, tokens_used, completed_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
118 119 120 121 122 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 118 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 181 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 |
# File 'lib/repull/models/ai_operation_completed_payload.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |