Class: Repull::AirbnbListing

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/airbnb_listing.rb

Overview

An Airbnb listing in the host account. Mirrors the Airbnb partner API shape with light normalization.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AirbnbListing

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/repull/models/airbnb_listing.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AirbnbListing` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AirbnbListing`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'property_type')
    self.property_type = attributes[:'property_type']
  end

  if attributes.key?(:'room_type')
    self.room_type = attributes[:'room_type']
  end

  if attributes.key?(:'bedrooms')
    self.bedrooms = attributes[:'bedrooms']
  end

  if attributes.key?(:'bathrooms')
    self.bathrooms = attributes[:'bathrooms']
  end

  if attributes.key?(:'max_guests')
    self.max_guests = attributes[:'max_guests']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end
end

Instance Attribute Details

#bathroomsObject

Returns the value of attribute bathrooms.



34
35
36
# File 'lib/repull/models/airbnb_listing.rb', line 34

def bathrooms
  @bathrooms
end

#bedroomsObject

Returns the value of attribute bedrooms.



32
33
34
# File 'lib/repull/models/airbnb_listing.rb', line 32

def bedrooms
  @bedrooms
end

#idObject

Airbnb listing ID



20
21
22
# File 'lib/repull/models/airbnb_listing.rb', line 20

def id
  @id
end

#max_guestsObject

Returns the value of attribute max_guests.



36
37
38
# File 'lib/repull/models/airbnb_listing.rb', line 36

def max_guests
  @max_guests
end

#nameObject

Listing title



23
24
25
# File 'lib/repull/models/airbnb_listing.rb', line 23

def name
  @name
end

#property_typeObject

Returns the value of attribute property_type.



28
29
30
# File 'lib/repull/models/airbnb_listing.rb', line 28

def property_type
  @property_type
end

#room_typeObject

Returns the value of attribute room_type.



30
31
32
# File 'lib/repull/models/airbnb_listing.rb', line 30

def room_type
  @room_type
end

#statusObject

Listing status (active, unlisted, etc.)



26
27
28
# File 'lib/repull/models/airbnb_listing.rb', line 26

def status
  @status
end

#thumbnail_urlObject

Returns the value of attribute thumbnail_url.



38
39
40
# File 'lib/repull/models/airbnb_listing.rb', line 38

def thumbnail_url
  @thumbnail_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/repull/models/airbnb_listing.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/repull/models/airbnb_listing.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/repull/models/airbnb_listing.rb', line 41

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'status' => :'status',
    :'property_type' => :'propertyType',
    :'room_type' => :'roomType',
    :'bedrooms' => :'bedrooms',
    :'bathrooms' => :'bathrooms',
    :'max_guests' => :'maxGuests',
    :'thumbnail_url' => :'thumbnailUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/repull/models/airbnb_listing.rb', line 191

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
89
90
# File 'lib/repull/models/airbnb_listing.rb', line 81

def self.openapi_nullable
  Set.new([
    :'property_type',
    :'room_type',
    :'bedrooms',
    :'bathrooms',
    :'max_guests',
    :'thumbnail_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/repull/models/airbnb_listing.rb', line 66

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'status' => :'String',
    :'property_type' => :'String',
    :'room_type' => :'String',
    :'bedrooms' => :'Integer',
    :'bathrooms' => :'Float',
    :'max_guests' => :'Integer',
    :'thumbnail_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/repull/models/airbnb_listing.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      status == o.status &&
      property_type == o.property_type &&
      room_type == o.room_type &&
      bedrooms == o.bedrooms &&
      bathrooms == o.bathrooms &&
      max_guests == o.max_guests &&
      thumbnail_url == o.thumbnail_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


178
179
180
# File 'lib/repull/models/airbnb_listing.rb', line 178

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



184
185
186
# File 'lib/repull/models/airbnb_listing.rb', line 184

def hash
  [id, name, status, property_type, room_type, bedrooms, bathrooms, max_guests, thumbnail_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/repull/models/airbnb_listing.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/repull/models/airbnb_listing.rb', line 213

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/repull/models/airbnb_listing.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end