Class: Repull::AirbnbPricingWriteRequest

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/airbnb_pricing_write_request.rb

Overview

Body for PUT /v1/channels/airbnb/listings/{id}/pricing. The type discriminator selects the pricing sub-resource. type: \"calendar\" shares the same per-date restriction shape as the availability endpoint (min/max nights, closed-to-arrival/departure, stop-sell via availability: \"unavailable\").

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AirbnbPricingWriteRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AirbnbPricingWriteRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AirbnbPricingWriteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'operations')
    if (value = attributes[:'operations']).is_a?(Array)
      self.operations = value
    end
  end

  if attributes.key?(:'model_type')
    self.model_type = attributes[:'model_type']
  end

  if attributes.key?(:'settings')
    if (value = attributes[:'settings']).is_a?(Hash)
      self.settings = value
    end
  end

  if attributes.key?(:'records')
    if (value = attributes[:'records']).is_a?(Array)
      self.records = value
    end
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'rule')
    if (value = attributes[:'rule']).is_a?(Hash)
      self.rule = value
    end
  end
end

Instance Attribute Details

#currencyObject

Required for type: \"currency\" — ISO 4217 code.



34
35
36
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 34

def currency
  @currency
end

#model_typeObject

Required when type: \"model\" — the pricing-availability model to switch the listing to.



25
26
27
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 25

def model_type
  @model_type
end

#operationsObject

Required when type: \"calendar\". Batch of per-date price + restriction operations.



22
23
24
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 22

def operations
  @operations
end

#recordsObject

Required for type: \"los\" — length-of-stay records.



31
32
33
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 31

def records
  @records
end

#ruleObject

Required for type: \"rule\" — a single pricing rule appended to the listing.



37
38
39
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 37

def rule
  @rule
end

#settingsObject

Required for type: \"standard\" | \"rate-plan\" | \"fees\" — the pricing-settings object to PUT.



28
29
30
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 28

def settings
  @settings
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 40

def self.attribute_map
  {
    :'type' => :'type',
    :'operations' => :'operations',
    :'model_type' => :'modelType',
    :'settings' => :'settings',
    :'records' => :'records',
    :'currency' => :'currency',
    :'rule' => :'rule'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 200

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 76

def self.openapi_nullable
  Set.new([
    :'model_type',
    :'settings',
    :'records',
    :'currency',
    :'rule'
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 63

def self.openapi_types
  {
    :'type' => :'String',
    :'operations' => :'Array<AirbnbCalendarOperation>',
    :'model_type' => :'String',
    :'settings' => :'Hash<String, Object>',
    :'records' => :'Array<Hash<String, Object>>',
    :'currency' => :'String',
    :'rule' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      operations == o.operations &&
      model_type == o.model_type &&
      settings == o.settings &&
      records == o.records &&
      currency == o.currency &&
      rule == o.rule
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


187
188
189
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 187

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



193
194
195
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 193

def hash
  [type, operations, model_type, settings, records, currency, rule].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 222

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
# File 'lib/repull/models/airbnb_pricing_write_request.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @type.nil?
  true
end