Class: Repull::AirbnbThread
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::AirbnbThread
- Defined in:
- lib/repull/models/airbnb_thread.rb
Overview
An Airbnb message thread.
Instance Attribute Summary collapse
-
#guest_name ⇒ Object
Returns the value of attribute guest_name.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
-
#listing_id ⇒ Object
Returns the value of attribute listing_id.
-
#unread_count ⇒ Object
Returns the value of attribute unread_count.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AirbnbThread
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AirbnbThread
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/repull/models/airbnb_thread.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AirbnbThread` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AirbnbThread`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] end if attributes.key?(:'guest_name') self.guest_name = attributes[:'guest_name'] end if attributes.key?(:'last_message_at') self. = attributes[:'last_message_at'] end if attributes.key?(:'unread_count') self.unread_count = attributes[:'unread_count'] end end |
Instance Attribute Details
#guest_name ⇒ Object
Returns the value of attribute guest_name.
23 24 25 |
# File 'lib/repull/models/airbnb_thread.rb', line 23 def guest_name @guest_name end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/repull/models/airbnb_thread.rb', line 19 def id @id end |
#last_message_at ⇒ Object
Returns the value of attribute last_message_at.
25 26 27 |
# File 'lib/repull/models/airbnb_thread.rb', line 25 def @last_message_at end |
#listing_id ⇒ Object
Returns the value of attribute listing_id.
21 22 23 |
# File 'lib/repull/models/airbnb_thread.rb', line 21 def listing_id @listing_id end |
#unread_count ⇒ Object
Returns the value of attribute unread_count.
27 28 29 |
# File 'lib/repull/models/airbnb_thread.rb', line 27 def unread_count @unread_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/repull/models/airbnb_thread.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/repull/models/airbnb_thread.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/repull/models/airbnb_thread.rb', line 30 def self.attribute_map { :'id' => :'id', :'listing_id' => :'listingId', :'guest_name' => :'guestName', :'last_message_at' => :'lastMessageAt', :'unread_count' => :'unreadCount' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/repull/models/airbnb_thread.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/repull/models/airbnb_thread.rb', line 62 def self.openapi_nullable Set.new([ :'listing_id', :'guest_name', :'last_message_at', :'unread_count' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/repull/models/airbnb_thread.rb', line 51 def self.openapi_types { :'id' => :'String', :'listing_id' => :'String', :'guest_name' => :'String', :'last_message_at' => :'Time', :'unread_count' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 |
# File 'lib/repull/models/airbnb_thread.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && listing_id == o.listing_id && guest_name == o.guest_name && == o. && unread_count == o.unread_count end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/repull/models/airbnb_thread.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/repull/models/airbnb_thread.rb', line 143 def hash [id, listing_id, guest_name, , unread_count].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 |
# File 'lib/repull/models/airbnb_thread.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/repull/models/airbnb_thread.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 |
# File 'lib/repull/models/airbnb_thread.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |