Class: Repull::BookingAvailabilityUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/booking_availability_update.rb

Overview

One (room, rate-plan, date-range) availability update. Carries inventory (availableRooms), the dedicated stop-sell flag (closed), and the same length-of-stay / arrival restrictions as a rate update.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BookingAvailabilityUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/repull/models/booking_availability_update.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::BookingAvailabilityUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::BookingAvailabilityUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'room_id')
    self.room_id = attributes[:'room_id']
  else
    self.room_id = nil
  end

  if attributes.key?(:'rate_id')
    self.rate_id = attributes[:'rate_id']
  else
    self.rate_id = nil
  end

  if attributes.key?(:'date_range')
    self.date_range = attributes[:'date_range']
  else
    self.date_range = nil
  end

  if attributes.key?(:'available_rooms')
    self.available_rooms = attributes[:'available_rooms']
  else
    self.available_rooms = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'closed')
    self.closed = attributes[:'closed']
  end

  if attributes.key?(:'restrictions')
    self.restrictions = attributes[:'restrictions']
  end
end

Instance Attribute Details

#available_roomsObject

Rooms to sell (roomstosell). 0 blocks the room for the range.



28
29
30
# File 'lib/repull/models/booking_availability_update.rb', line 28

def available_rooms
  @available_rooms
end

#closedObject

Dedicated stop-sell flag (<closed> in Booking's XML). true fully stops sale for the room/date-range regardless of availableRooms.



33
34
35
# File 'lib/repull/models/booking_availability_update.rb', line 33

def closed
  @closed
end

#date_rangeObject

Returns the value of attribute date_range.



25
26
27
# File 'lib/repull/models/booking_availability_update.rb', line 25

def date_range
  @date_range
end

#rate_idObject

Booking.com rate-plan id.



23
24
25
# File 'lib/repull/models/booking_availability_update.rb', line 23

def rate_id
  @rate_id
end

#restrictionsObject

Returns the value of attribute restrictions.



35
36
37
# File 'lib/repull/models/booking_availability_update.rb', line 35

def restrictions
  @restrictions
end

#room_idObject

Booking.com room id.



20
21
22
# File 'lib/repull/models/booking_availability_update.rb', line 20

def room_id
  @room_id
end

#statusObject

Returns the value of attribute status.



30
31
32
# File 'lib/repull/models/booking_availability_update.rb', line 30

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/repull/models/booking_availability_update.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/repull/models/booking_availability_update.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/repull/models/booking_availability_update.rb', line 38

def self.attribute_map
  {
    :'room_id' => :'roomId',
    :'rate_id' => :'rateId',
    :'date_range' => :'dateRange',
    :'available_rooms' => :'availableRooms',
    :'status' => :'status',
    :'closed' => :'closed',
    :'restrictions' => :'restrictions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/repull/models/booking_availability_update.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
79
# File 'lib/repull/models/booking_availability_update.rb', line 74

def self.openapi_nullable
  Set.new([
    :'status',
    :'closed',
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/repull/models/booking_availability_update.rb', line 61

def self.openapi_types
  {
    :'room_id' => :'String',
    :'rate_id' => :'String',
    :'date_range' => :'BookingPricingRateUpdateDateRange',
    :'available_rooms' => :'Integer',
    :'status' => :'String',
    :'closed' => :'Boolean',
    :'restrictions' => :'BookingPricingRateUpdateRestrictions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
# File 'lib/repull/models/booking_availability_update.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      room_id == o.room_id &&
      rate_id == o.rate_id &&
      date_range == o.date_range &&
      available_rooms == o.available_rooms &&
      status == o.status &&
      closed == o.closed &&
      restrictions == o.restrictions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/repull/models/booking_availability_update.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/repull/models/booking_availability_update.rb', line 231

def hash
  [room_id, rate_id, date_range, available_rooms, status, closed, restrictions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/repull/models/booking_availability_update.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @room_id.nil?
    invalid_properties.push('invalid value for "room_id", room_id cannot be nil.')
  end

  if @rate_id.nil?
    invalid_properties.push('invalid value for "rate_id", rate_id cannot be nil.')
  end

  if @date_range.nil?
    invalid_properties.push('invalid value for "date_range", date_range cannot be nil.')
  end

  if @available_rooms.nil?
    invalid_properties.push('invalid value for "available_rooms", available_rooms cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/repull/models/booking_availability_update.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
# File 'lib/repull/models/booking_availability_update.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @room_id.nil?
  return false if @rate_id.nil?
  return false if @date_range.nil?
  return false if @available_rooms.nil?
  true
end