Class: Repull::BookingConnectRoom

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/booking_connect_room.rb

Overview

A Booking.com room imported from the claimed hotel. The customer maps each room to one of their Repull listings via ‘mapConnectBookingRooms`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BookingConnectRoom

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/repull/models/booking_connect_room.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::BookingConnectRoom` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::BookingConnectRoom`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'room_id')
    self.room_id = attributes[:'room_id']
  else
    self.room_id = nil
  end

  if attributes.key?(:'room_name')
    self.room_name = attributes[:'room_name']
  else
    self.room_name = nil
  end

  if attributes.key?(:'max_guests')
    self.max_guests = attributes[:'max_guests']
  end

  if attributes.key?(:'number_of_rooms')
    self.number_of_rooms = attributes[:'number_of_rooms']
  else
    self.number_of_rooms = nil
  end

  if attributes.key?(:'current_listing_id')
    self.current_listing_id = attributes[:'current_listing_id']
  end

  if attributes.key?(:'room_booking_id')
    self.room_booking_id = attributes[:'room_booking_id']
  end
end

Instance Attribute Details

#current_listing_idObject

Currently mapped Repull listing ID, or null if not yet mapped.



30
31
32
# File 'lib/repull/models/booking_connect_room.rb', line 30

def current_listing_id
  @current_listing_id
end

#max_guestsObject

Returns the value of attribute max_guests.



24
25
26
# File 'lib/repull/models/booking_connect_room.rb', line 24

def max_guests
  @max_guests
end

#number_of_roomsObject

Number of inventory units of this room type at the hotel.



27
28
29
# File 'lib/repull/models/booking_connect_room.rb', line 27

def number_of_rooms
  @number_of_rooms
end

#room_booking_idObject

Booking.com-side room ID (used internally for ‘listing_platform_links`).



33
34
35
# File 'lib/repull/models/booking_connect_room.rb', line 33

def room_booking_id
  @room_booking_id
end

#room_idObject

Repull-side ‘listings_booking_rooms.id`. Pass this back in the mapping submission.



20
21
22
# File 'lib/repull/models/booking_connect_room.rb', line 20

def room_id
  @room_id
end

#room_nameObject

Returns the value of attribute room_name.



22
23
24
# File 'lib/repull/models/booking_connect_room.rb', line 22

def room_name
  @room_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/repull/models/booking_connect_room.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/repull/models/booking_connect_room.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/repull/models/booking_connect_room.rb', line 36

def self.attribute_map
  {
    :'room_id' => :'roomId',
    :'room_name' => :'roomName',
    :'max_guests' => :'maxGuests',
    :'number_of_rooms' => :'numberOfRooms',
    :'current_listing_id' => :'currentListingId',
    :'room_booking_id' => :'roomBookingId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/repull/models/booking_connect_room.rb', line 213

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
75
76
# File 'lib/repull/models/booking_connect_room.rb', line 70

def self.openapi_nullable
  Set.new([
    :'max_guests',
    :'current_listing_id',
    :'room_booking_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/repull/models/booking_connect_room.rb', line 58

def self.openapi_types
  {
    :'room_id' => :'String',
    :'room_name' => :'String',
    :'max_guests' => :'Integer',
    :'number_of_rooms' => :'Integer',
    :'current_listing_id' => :'String',
    :'room_booking_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
# File 'lib/repull/models/booking_connect_room.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      room_id == o.room_id &&
      room_name == o.room_name &&
      max_guests == o.max_guests &&
      number_of_rooms == o.number_of_rooms &&
      current_listing_id == o.current_listing_id &&
      room_booking_id == o.room_booking_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


200
201
202
# File 'lib/repull/models/booking_connect_room.rb', line 200

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



206
207
208
# File 'lib/repull/models/booking_connect_room.rb', line 206

def hash
  [room_id, room_name, max_guests, number_of_rooms, current_listing_id, room_booking_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/repull/models/booking_connect_room.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @room_id.nil?
    invalid_properties.push('invalid value for "room_id", room_id cannot be nil.')
  end

  if @room_name.nil?
    invalid_properties.push('invalid value for "room_name", room_name cannot be nil.')
  end

  if @number_of_rooms.nil?
    invalid_properties.push('invalid value for "number_of_rooms", number_of_rooms cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/repull/models/booking_connect_room.rb', line 235

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
# File 'lib/repull/models/booking_connect_room.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @room_id.nil?
  return false if @room_name.nil?
  return false if @number_of_rooms.nil?
  true
end