Class: Repull::BookingPricingRateUpdate

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/booking_pricing_rate_update.rb

Overview

A single (room, rate-plan, date-range) update pushed to Booking.com via the rates API.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BookingPricingRateUpdate

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::BookingPricingRateUpdate` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::BookingPricingRateUpdate`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'room_id')
    self.room_id = attributes[:'room_id']
  else
    self.room_id = nil
  end

  if attributes.key?(:'rate_id')
    self.rate_id = attributes[:'rate_id']
  else
    self.rate_id = nil
  end

  if attributes.key?(:'date_range')
    self.date_range = attributes[:'date_range']
  else
    self.date_range = nil
  end

  if attributes.key?(:'price')
    self.price = attributes[:'price']
  else
    self.price = nil
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  else
    self.currency = nil
  end

  if attributes.key?(:'single_price')
    self.single_price = attributes[:'single_price']
  end

  if attributes.key?(:'occupancy')
    self.occupancy = attributes[:'occupancy']
  end

  if attributes.key?(:'rooms_to_sell')
    self.rooms_to_sell = attributes[:'rooms_to_sell']
  end

  if attributes.key?(:'restrictions')
    self.restrictions = attributes[:'restrictions']
  end
end

Instance Attribute Details

#currencyObject

Returns the value of attribute currency.



29
30
31
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 29

def currency
  @currency
end

#date_rangeObject

Returns the value of attribute date_range.



25
26
27
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 25

def date_range
  @date_range
end

#occupancyObject

Returns the value of attribute occupancy.



33
34
35
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 33

def occupancy
  @occupancy
end

#priceObject

Returns the value of attribute price.



27
28
29
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 27

def price
  @price
end

#rate_idObject

Booking.com rate-plan ID.



23
24
25
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 23

def rate_id
  @rate_id
end

#restrictionsObject

Returns the value of attribute restrictions.



37
38
39
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 37

def restrictions
  @restrictions
end

#room_idObject

Booking.com room ID for the rate plan. Comes from ‘listings_booking_rooms` mapping.



20
21
22
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 20

def room_id
  @room_id
end

#rooms_to_sellObject

Returns the value of attribute rooms_to_sell.



35
36
37
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 35

def rooms_to_sell
  @rooms_to_sell
end

#single_priceObject

Returns the value of attribute single_price.



31
32
33
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 31

def single_price
  @single_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 40

def self.attribute_map
  {
    :'room_id' => :'roomId',
    :'rate_id' => :'rateId',
    :'date_range' => :'dateRange',
    :'price' => :'price',
    :'currency' => :'currency',
    :'single_price' => :'singlePrice',
    :'occupancy' => :'occupancy',
    :'rooms_to_sell' => :'roomsToSell',
    :'restrictions' => :'restrictions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
84
85
86
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 80

def self.openapi_nullable
  Set.new([
    :'single_price',
    :'occupancy',
    :'rooms_to_sell',
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 65

def self.openapi_types
  {
    :'room_id' => :'String',
    :'rate_id' => :'String',
    :'date_range' => :'BookingPricingRateUpdateDateRange',
    :'price' => :'Float',
    :'currency' => :'String',
    :'single_price' => :'Float',
    :'occupancy' => :'Integer',
    :'rooms_to_sell' => :'Integer',
    :'restrictions' => :'BookingPricingRateUpdateRestrictions'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      room_id == o.room_id &&
      rate_id == o.rate_id &&
      date_range == o.date_range &&
      price == o.price &&
      currency == o.currency &&
      single_price == o.single_price &&
      occupancy == o.occupancy &&
      rooms_to_sell == o.rooms_to_sell &&
      restrictions == o.restrictions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 265

def hash
  [room_id, rate_id, date_range, price, currency, single_price, occupancy, rooms_to_sell, restrictions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 153

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @room_id.nil?
    invalid_properties.push('invalid value for "room_id", room_id cannot be nil.')
  end

  if @rate_id.nil?
    invalid_properties.push('invalid value for "rate_id", rate_id cannot be nil.')
  end

  if @date_range.nil?
    invalid_properties.push('invalid value for "date_range", date_range cannot be nil.')
  end

  if @price.nil?
    invalid_properties.push('invalid value for "price", price cannot be nil.')
  end

  if @currency.nil?
    invalid_properties.push('invalid value for "currency", currency cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



181
182
183
184
185
186
187
188
189
# File 'lib/repull/models/booking_pricing_rate_update.rb', line 181

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @room_id.nil?
  return false if @rate_id.nil?
  return false if @date_range.nil?
  return false if @price.nil?
  return false if @currency.nil?
  true
end