Class: Repull::BookingVerifyHotelResponse

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/booking_verify_hotel_response.rb

Overview

Successful verify response. The session is transitioned to ‘awaiting_room_mapping` and a `pms_connections` row is upserted.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BookingVerifyHotelResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::BookingVerifyHotelResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::BookingVerifyHotelResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'valid')
    self.valid = attributes[:'valid']
  else
    self.valid = nil
  end

  if attributes.key?(:'session_id')
    self.session_id = attributes[:'session_id']
  else
    self.session_id = nil
  end

  if attributes.key?(:'connection_id')
    self.connection_id = attributes[:'connection_id']
  else
    self.connection_id = nil
  end

  if attributes.key?(:'hotel_id')
    self.hotel_id = attributes[:'hotel_id']
  else
    self.hotel_id = nil
  end

  if attributes.key?(:'hotel_name')
    self.hotel_name = attributes[:'hotel_name']
  end

  if attributes.key?(:'hotel_type')
    self.hotel_type = attributes[:'hotel_type']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



35
36
37
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 35

def city
  @city
end

#connection_idObject

Repull-side ‘pms_connections.id` for the linked Booking account.



24
25
26
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 24

def connection_id
  @connection_id
end

#countryObject

Returns the value of attribute country.



33
34
35
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 33

def country
  @country
end

#hotel_idObject

Returns the value of attribute hotel_id.



26
27
28
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 26

def hotel_id
  @hotel_id
end

#hotel_nameObject

Returns the value of attribute hotel_name.



28
29
30
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 28

def hotel_name
  @hotel_name
end

#hotel_typeObject

Booking.com hotel/property type code (e.g. ‘apartment`, `hotel`).



31
32
33
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 31

def hotel_type
  @hotel_type
end

#session_idObject

Returns the value of attribute session_id.



21
22
23
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 21

def session_id
  @session_id
end

#validObject

Returns the value of attribute valid.



19
20
21
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 19

def valid
  @valid
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 38

def self.attribute_map
  {
    :'valid' => :'valid',
    :'session_id' => :'sessionId',
    :'connection_id' => :'connectionId',
    :'hotel_id' => :'hotelId',
    :'hotel_name' => :'hotelName',
    :'hotel_type' => :'hotelType',
    :'country' => :'country',
    :'city' => :'city'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 247

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 76

def self.openapi_nullable
  Set.new([
    :'hotel_name',
    :'hotel_type',
    :'country',
    :'city'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 62

def self.openapi_types
  {
    :'valid' => :'Boolean',
    :'session_id' => :'String',
    :'connection_id' => :'String',
    :'hotel_id' => :'String',
    :'hotel_name' => :'String',
    :'hotel_type' => :'String',
    :'country' => :'String',
    :'city' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 219

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      valid == o.valid &&
      session_id == o.session_id &&
      connection_id == o.connection_id &&
      hotel_id == o.hotel_id &&
      hotel_name == o.hotel_name &&
      hotel_type == o.hotel_type &&
      country == o.country &&
      city == o.city
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


234
235
236
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 234

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



240
241
242
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 240

def hash
  [valid, session_id, connection_id, hotel_id, hotel_name, hotel_type, country, city].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @valid.nil?
    invalid_properties.push('invalid value for "valid", valid cannot be nil.')
  end

  if @session_id.nil?
    invalid_properties.push('invalid value for "session_id", session_id cannot be nil.')
  end

  if @connection_id.nil?
    invalid_properties.push('invalid value for "connection_id", connection_id cannot be nil.')
  end

  if @hotel_id.nil?
    invalid_properties.push('invalid value for "hotel_id", hotel_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 269

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



168
169
170
171
172
173
174
175
# File 'lib/repull/models/booking_verify_hotel_response.rb', line 168

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @valid.nil?
  return false if @session_id.nil?
  return false if @connection_id.nil?
  return false if @hotel_id.nil?
  true
end