Class: Repull::BulkPricingItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::BulkPricingItem
- Defined in:
- lib/repull/models/bulk_pricing_item.rb
Overview
A single (listingId, dates) pair in a bulk pricing request. The action in the parent request body applies to every date in ‘dates` for this listing.
Instance Attribute Summary collapse
-
#dates ⇒ Object
Returns the value of attribute dates.
-
#listing_id ⇒ Object
Returns the value of attribute listing_id.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BulkPricingItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BulkPricingItem
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::BulkPricingItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::BulkPricingItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'listing_id') self.listing_id = attributes[:'listing_id'] else self.listing_id = nil end if attributes.key?(:'dates') if (value = attributes[:'dates']).is_a?(Array) self.dates = value end else self.dates = nil end end |
Instance Attribute Details
#dates ⇒ Object
Returns the value of attribute dates.
21 22 23 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 21 def dates @dates end |
#listing_id ⇒ Object
Returns the value of attribute listing_id.
19 20 21 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 19 def listing_id @listing_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 24 def self.attribute_map { :'listing_id' => :'listingId', :'dates' => :'dates' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 42 def self.openapi_types { :'listing_id' => :'String', :'dates' => :'Array<Date>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && listing_id == o.listing_id && dates == o.dates end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 157 def hash [listing_id, dates].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 88 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @listing_id.nil? invalid_properties.push('invalid value for "listing_id", listing_id cannot be nil.') end if @dates.nil? invalid_properties.push('invalid value for "dates", dates cannot be nil.') end if @dates.length < 1 invalid_properties.push('invalid value for "dates", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
108 109 110 111 112 113 114 |
# File 'lib/repull/models/bulk_pricing_item.rb', line 108 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @listing_id.nil? return false if @dates.nil? return false if @dates.length < 1 true end |