Class: Repull::ConnectStatus

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/connect_status.rb

Overview

Connection status response for a single provider. When ‘connected` is false, all other fields except `provider` and `host` may be omitted, and `host` is null.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConnectStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/repull/models/connect_status.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ConnectStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ConnectStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'connected')
    self.connected = attributes[:'connected']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'external_account_id')
    self. = attributes[:'external_account_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end
end

Instance Attribute Details

#connectedObject

Returns the value of attribute connected.



19
20
21
# File 'lib/repull/models/connect_status.rb', line 19

def connected
  @connected
end

#created_atObject

Returns the value of attribute created_at.



31
32
33
# File 'lib/repull/models/connect_status.rb', line 31

def created_at
  @created_at
end

#external_account_idObject

Provider-side account ID (e.g. the Airbnb host ID).



29
30
31
# File 'lib/repull/models/connect_status.rb', line 29

def 
  @external_account_id
end

#hostObject

Host metadata, populated for Airbnb when the host row exists. Null for other providers (per-provider enrichment is incremental).



34
35
36
# File 'lib/repull/models/connect_status.rb', line 34

def host
  @host
end

#idObject

Repull-side connection ID. Stable across token refreshes.



24
25
26
# File 'lib/repull/models/connect_status.rb', line 24

def id
  @id
end

#providerObject

Returns the value of attribute provider.



21
22
23
# File 'lib/repull/models/connect_status.rb', line 21

def provider
  @provider
end

#statusObject

Returns the value of attribute status.



26
27
28
# File 'lib/repull/models/connect_status.rb', line 26

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/repull/models/connect_status.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/repull/models/connect_status.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
# File 'lib/repull/models/connect_status.rb', line 37

def self.attribute_map
  {
    :'connected' => :'connected',
    :'provider' => :'provider',
    :'id' => :'id',
    :'status' => :'status',
    :'external_account_id' => :'externalAccountId',
    :'created_at' => :'createdAt',
    :'host' => :'host'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/repull/models/connect_status.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
78
# File 'lib/repull/models/connect_status.rb', line 73

def self.openapi_nullable
  Set.new([
    :'external_account_id',
    :'host'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
70
# File 'lib/repull/models/connect_status.rb', line 60

def self.openapi_types
  {
    :'connected' => :'Boolean',
    :'provider' => :'String',
    :'id' => :'String',
    :'status' => :'String',
    :'external_account_id' => :'String',
    :'created_at' => :'Time',
    :'host' => :'ConnectHost'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/repull/models/connect_status.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      connected == o.connected &&
      provider == o.provider &&
      id == o.id &&
      status == o.status &&
       == o. &&
      created_at == o.created_at &&
      host == o.host
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/repull/models/connect_status.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/repull/models/connect_status.rb', line 162

def hash
  [connected, provider, id, status, , created_at, host].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/repull/models/connect_status.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/repull/models/connect_status.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/repull/models/connect_status.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end