Class: Repull::Connection

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/connection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Connection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/repull/models/connection.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::Connection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::Connection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'external_account_id')
    self. = attributes[:'external_account_id']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'host')
    self.host = attributes[:'host']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



26
27
28
# File 'lib/repull/models/connection.rb', line 26

def created_at
  @created_at
end

#external_account_idObject

Returns the value of attribute external_account_id.



24
25
26
# File 'lib/repull/models/connection.rb', line 24

def 
  @external_account_id
end

#hostObject

Host metadata for the linked account. Currently populated for Airbnb only; null for other providers.



29
30
31
# File 'lib/repull/models/connection.rb', line 29

def host
  @host
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/repull/models/connection.rb', line 18

def id
  @id
end

#providerObject

Returns the value of attribute provider.



20
21
22
# File 'lib/repull/models/connection.rb', line 20

def provider
  @provider
end

#statusObject

Returns the value of attribute status.



22
23
24
# File 'lib/repull/models/connection.rb', line 22

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/repull/models/connection.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/repull/models/connection.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/repull/models/connection.rb', line 32

def self.attribute_map
  {
    :'id' => :'id',
    :'provider' => :'provider',
    :'status' => :'status',
    :'external_account_id' => :'externalAccountId',
    :'created_at' => :'createdAt',
    :'host' => :'host'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/repull/models/connection.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
70
71
# File 'lib/repull/models/connection.rb', line 66

def self.openapi_nullable
  Set.new([
    :'external_account_id',
    :'host'
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/repull/models/connection.rb', line 54

def self.openapi_types
  {
    :'id' => :'String',
    :'provider' => :'String',
    :'status' => :'String',
    :'external_account_id' => :'String',
    :'created_at' => :'Time',
    :'host' => :'ConnectHost'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



131
132
133
134
135
136
137
138
139
140
# File 'lib/repull/models/connection.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      provider == o.provider &&
      status == o.status &&
       == o. &&
      created_at == o.created_at &&
      host == o.host
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


144
145
146
# File 'lib/repull/models/connection.rb', line 144

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



150
151
152
# File 'lib/repull/models/connection.rb', line 150

def hash
  [id, provider, status, , created_at, host].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



116
117
118
119
120
# File 'lib/repull/models/connection.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/repull/models/connection.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
# File 'lib/repull/models/connection.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end