Class: Repull::CreateReservationRequest

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/create_reservation_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateReservationRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/repull/models/create_reservation_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::CreateReservationRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::CreateReservationRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'property_id')
    self.property_id = attributes[:'property_id']
  else
    self.property_id = nil
  end

  if attributes.key?(:'check_in')
    self.check_in = attributes[:'check_in']
  else
    self.check_in = nil
  end

  if attributes.key?(:'check_out')
    self.check_out = attributes[:'check_out']
  else
    self.check_out = nil
  end

  if attributes.key?(:'guest_first_name')
    self.guest_first_name = attributes[:'guest_first_name']
  else
    self.guest_first_name = nil
  end

  if attributes.key?(:'guest_last_name')
    self.guest_last_name = attributes[:'guest_last_name']
  else
    self.guest_last_name = nil
  end

  if attributes.key?(:'guest_email')
    self.guest_email = attributes[:'guest_email']
  end

  if attributes.key?(:'guest_phone')
    self.guest_phone = attributes[:'guest_phone']
  end

  if attributes.key?(:'guest_count')
    self.guest_count = attributes[:'guest_count']
  end

  if attributes.key?(:'total_price')
    self.total_price = attributes[:'total_price']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end
end

Instance Attribute Details

#check_inObject

Returns the value of attribute check_in.



20
21
22
# File 'lib/repull/models/create_reservation_request.rb', line 20

def check_in
  @check_in
end

#check_outObject

Returns the value of attribute check_out.



22
23
24
# File 'lib/repull/models/create_reservation_request.rb', line 22

def check_out
  @check_out
end

#currencyObject

Returns the value of attribute currency.



36
37
38
# File 'lib/repull/models/create_reservation_request.rb', line 36

def currency
  @currency
end

#guest_countObject

Returns the value of attribute guest_count.



32
33
34
# File 'lib/repull/models/create_reservation_request.rb', line 32

def guest_count
  @guest_count
end

#guest_emailObject

Returns the value of attribute guest_email.



28
29
30
# File 'lib/repull/models/create_reservation_request.rb', line 28

def guest_email
  @guest_email
end

#guest_first_nameObject

Returns the value of attribute guest_first_name.



24
25
26
# File 'lib/repull/models/create_reservation_request.rb', line 24

def guest_first_name
  @guest_first_name
end

#guest_last_nameObject

Returns the value of attribute guest_last_name.



26
27
28
# File 'lib/repull/models/create_reservation_request.rb', line 26

def guest_last_name
  @guest_last_name
end

#guest_phoneObject

Returns the value of attribute guest_phone.



30
31
32
# File 'lib/repull/models/create_reservation_request.rb', line 30

def guest_phone
  @guest_phone
end

#property_idObject

Returns the value of attribute property_id.



18
19
20
# File 'lib/repull/models/create_reservation_request.rb', line 18

def property_id
  @property_id
end

#total_priceObject

Returns the value of attribute total_price.



34
35
36
# File 'lib/repull/models/create_reservation_request.rb', line 34

def total_price
  @total_price
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/repull/models/create_reservation_request.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/repull/models/create_reservation_request.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/repull/models/create_reservation_request.rb', line 39

def self.attribute_map
  {
    :'property_id' => :'propertyId',
    :'check_in' => :'checkIn',
    :'check_out' => :'checkOut',
    :'guest_first_name' => :'guestFirstName',
    :'guest_last_name' => :'guestLastName',
    :'guest_email' => :'guestEmail',
    :'guest_phone' => :'guestPhone',
    :'guest_count' => :'guestCount',
    :'total_price' => :'totalPrice',
    :'currency' => :'currency'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
# File 'lib/repull/models/create_reservation_request.rb', line 275

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/repull/models/create_reservation_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/repull/models/create_reservation_request.rb', line 65

def self.openapi_types
  {
    :'property_id' => :'String',
    :'check_in' => :'Date',
    :'check_out' => :'Date',
    :'guest_first_name' => :'String',
    :'guest_last_name' => :'String',
    :'guest_email' => :'String',
    :'guest_phone' => :'String',
    :'guest_count' => :'Integer',
    :'total_price' => :'Float',
    :'currency' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/repull/models/create_reservation_request.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      property_id == o.property_id &&
      check_in == o.check_in &&
      check_out == o.check_out &&
      guest_first_name == o.guest_first_name &&
      guest_last_name == o.guest_last_name &&
      guest_email == o.guest_email &&
      guest_phone == o.guest_phone &&
      guest_count == o.guest_count &&
      total_price == o.total_price &&
      currency == o.currency
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


262
263
264
# File 'lib/repull/models/create_reservation_request.rb', line 262

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



268
269
270
# File 'lib/repull/models/create_reservation_request.rb', line 268

def hash
  [property_id, check_in, check_out, guest_first_name, guest_last_name, guest_email, guest_phone, guest_count, total_price, currency].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/repull/models/create_reservation_request.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @property_id.nil?
    invalid_properties.push('invalid value for "property_id", property_id cannot be nil.')
  end

  if @check_in.nil?
    invalid_properties.push('invalid value for "check_in", check_in cannot be nil.')
  end

  if @check_out.nil?
    invalid_properties.push('invalid value for "check_out", check_out cannot be nil.')
  end

  if @guest_first_name.nil?
    invalid_properties.push('invalid value for "guest_first_name", guest_first_name cannot be nil.')
  end

  if @guest_last_name.nil?
    invalid_properties.push('invalid value for "guest_last_name", guest_last_name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/repull/models/create_reservation_request.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
# File 'lib/repull/models/create_reservation_request.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @property_id.nil?
  return false if @check_in.nil?
  return false if @check_out.nil?
  return false if @guest_first_name.nil?
  return false if @guest_last_name.nil?
  true
end