Class: Repull::CustomSchema

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/custom_schema.rb

Overview

A custom field-mapping schema owned by the workspace. Reshapes the ‘native` response into the workspace’s preferred field names. Apply one per request via the ‘X-Schema: <name>` header on any read endpoint.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CustomSchema

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/repull/models/custom_schema.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::CustomSchema` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::CustomSchema`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'mappings')
    if (value = attributes[:'mappings']).is_a?(Hash)
      self.mappings = value
    end
  else
    self.mappings = nil
  end

  if attributes.key?(:'active')
    self.active = attributes[:'active']
  else
    self.active = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#activeObject

When ‘false`, requests carrying this schema name in `X-Schema` fall back to `native`.



31
32
33
# File 'lib/repull/models/custom_schema.rb', line 31

def active
  @active
end

#created_atObject

Returns the value of attribute created_at.



33
34
35
# File 'lib/repull/models/custom_schema.rb', line 33

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



25
26
27
# File 'lib/repull/models/custom_schema.rb', line 25

def description
  @description
end

#idObject

Stable workspace-scoped identifier.



20
21
22
# File 'lib/repull/models/custom_schema.rb', line 20

def id
  @id
end

#mappingsObject

Field-mapping table. Keys are the output field names emitted in the response payload; values are simple expressions referenced against the source ‘native` payload (dot paths, basic arithmetic, string concatenation). Min 1 entry, max 50 entries. Each key must be <= 100 chars; each expression must be <= 500 chars and pass the safety check (no `eval`, no `function`, no `process`, etc.).



28
29
30
# File 'lib/repull/models/custom_schema.rb', line 28

def mappings
  @mappings
end

#nameObject

3-100 lowercase chars, hyphens allowed (‘^[a-z0-9][a-z0-9-]1,98$`). Must be unique within the workspace. Cannot collide with reserved names (`calry`, `calry-v1`, `native`).



23
24
25
# File 'lib/repull/models/custom_schema.rb', line 23

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/repull/models/custom_schema.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/repull/models/custom_schema.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/repull/models/custom_schema.rb', line 36

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'description' => :'description',
    :'mappings' => :'mappings',
    :'active' => :'active',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
# File 'lib/repull/models/custom_schema.rb', line 265

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
74
# File 'lib/repull/models/custom_schema.rb', line 70

def self.openapi_nullable
  Set.new([
    :'description',
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/repull/models/custom_schema.rb', line 58

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'mappings' => :'Hash<String, String>',
    :'active' => :'Boolean',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



239
240
241
242
243
244
245
246
247
248
# File 'lib/repull/models/custom_schema.rb', line 239

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      description == o.description &&
      mappings == o.mappings &&
      active == o.active &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


252
253
254
# File 'lib/repull/models/custom_schema.rb', line 252

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



258
259
260
# File 'lib/repull/models/custom_schema.rb', line 258

def hash
  [id, name, description, mappings, active, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/repull/models/custom_schema.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @mappings.nil?
    invalid_properties.push('invalid value for "mappings", mappings cannot be nil.')
  end

  if @mappings.length > 50
    invalid_properties.push('invalid value for "mappings", number of items must be less than or equal to 50.')
  end

  if @mappings.length < 1
    invalid_properties.push('invalid value for "mappings", number of items must be greater than or equal to 1.')
  end

  if @active.nil?
    invalid_properties.push('invalid value for "active", active cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



287
288
289
290
291
292
293
294
295
296
297
298
299
# File 'lib/repull/models/custom_schema.rb', line 287

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
175
176
177
# File 'lib/repull/models/custom_schema.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @mappings.nil?
  return false if @mappings.length > 50
  return false if @mappings.length < 1
  return false if @active.nil?
  return false if @created_at.nil?
  true
end