Class: Repull::CustomSchemaCreateResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::CustomSchemaCreateResponse
- Defined in:
- lib/repull/models/custom_schema_create_response.rb
Overview
Returned by ‘POST /v1/schema/custom` (201). Includes a `usage` hint telling the caller exactly which header value to set on subsequent requests.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#id ⇒ Object
Returns the value of attribute id.
-
#mappings ⇒ Object
Field-mapping table.
-
#name ⇒ Object
Returns the value of attribute name.
-
#usage ⇒ Object
Returns the value of attribute usage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomSchemaCreateResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomSchemaCreateResponse
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::CustomSchemaCreateResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::CustomSchemaCreateResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'mappings') if (value = attributes[:'mappings']).is_a?(Hash) self.mappings = value end else self.mappings = nil end if attributes.key?(:'usage') self.usage = attributes[:'usage'] else self.usage = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 30 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 23 def description @description end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 19 def id @id end |
#mappings ⇒ Object
Field-mapping table. Keys are the output field names emitted in the response payload; values are simple expressions referenced against the source ‘native` payload (dot paths, basic arithmetic, string concatenation). Min 1 entry, max 50 entries. Each key must be <= 100 chars; each expression must be <= 500 chars and pass the safety check (no `eval`, no `function`, no `process`, etc.).
26 27 28 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 26 def mappings @mappings end |
#name ⇒ Object
Returns the value of attribute name.
21 22 23 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 21 def name @name end |
#usage ⇒ Object
Returns the value of attribute usage.
28 29 30 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 28 def usage @usage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 33 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'description' => :'description', :'mappings' => :'mappings', :'usage' => :'usage', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 67 def self.openapi_nullable Set.new([ :'description', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 55 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'description' => :'String', :'mappings' => :'Hash<String, String>', :'usage' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && description == o.description && mappings == o.mappings && usage == o.usage && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 255 def hash [id, name, description, mappings, usage, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @mappings.nil? invalid_properties.push('invalid value for "mappings", mappings cannot be nil.') end if @mappings.length > 50 invalid_properties.push('invalid value for "mappings", number of items must be less than or equal to 50.') end if @mappings.length < 1 invalid_properties.push('invalid value for "mappings", number of items must be greater than or equal to 1.') end if @usage.nil? invalid_properties.push('invalid value for "usage", usage cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/repull/models/custom_schema_create_response.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @mappings.nil? return false if @mappings.length > 50 return false if @mappings.length < 1 return false if @usage.nil? return false if @created_at.nil? true end |