Class: Repull::GenerateStudioCompletion200ResponseData

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/repull/models/generate_studio_completion200_response_data.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GenerateStudioCompletion200ResponseData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::GenerateStudioCompletion200ResponseData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::GenerateStudioCompletion200ResponseData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'generation_id')
    self.generation_id = attributes[:'generation_id']
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'tokens_in')
    self.tokens_in = attributes[:'tokens_in']
  end

  if attributes.key?(:'tokens_out')
    self.tokens_out = attributes[:'tokens_out']
  end

  if attributes.key?(:'latency_ms')
    self.latency_ms = attributes[:'latency_ms']
  end

  if attributes.key?(:'cost_usd_micro')
    self.cost_usd_micro = attributes[:'cost_usd_micro']
  end

  if attributes.key?(:'cached')
    self.cached = attributes[:'cached']
  end

  if attributes.key?(:'fallback')
    self.fallback = attributes[:'fallback']
  end
end

Instance Attribute Details

#cachedObject

True if the response was served from cache.



36
37
38
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 36

def cached
  @cached
end

#cost_usd_microObject

Cost in millionths of a USD.



33
34
35
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 33

def cost_usd_micro
  @cost_usd_micro
end

#fallbackObject

True if the primary model failed and Repull AI fell back to the secondary.



39
40
41
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 39

def fallback
  @fallback
end

#generation_idObject

Returns the value of attribute generation_id.



21
22
23
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 21

def generation_id
  @generation_id
end

#latency_msObject

Returns the value of attribute latency_ms.



30
31
32
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 30

def latency_ms
  @latency_ms
end

#modelObject

Model identifier that produced the response.



24
25
26
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 24

def model
  @model
end

#textObject

Generated completion text.



19
20
21
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 19

def text
  @text
end

#tokens_inObject

Returns the value of attribute tokens_in.



26
27
28
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 26

def tokens_in
  @tokens_in
end

#tokens_outObject

Returns the value of attribute tokens_out.



28
29
30
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 28

def tokens_out
  @tokens_out
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 42

def self.attribute_map
  {
    :'text' => :'text',
    :'generation_id' => :'generation_id',
    :'model' => :'model',
    :'tokens_in' => :'tokens_in',
    :'tokens_out' => :'tokens_out',
    :'latency_ms' => :'latency_ms',
    :'cost_usd_micro' => :'cost_usd_micro',
    :'cached' => :'cached',
    :'fallback' => :'fallback'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 186

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 67

def self.openapi_types
  {
    :'text' => :'String',
    :'generation_id' => :'String',
    :'model' => :'String',
    :'tokens_in' => :'Integer',
    :'tokens_out' => :'Integer',
    :'latency_ms' => :'Integer',
    :'cost_usd_micro' => :'Integer',
    :'cached' => :'Boolean',
    :'fallback' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      text == o.text &&
      generation_id == o.generation_id &&
      model == o.model &&
      tokens_in == o.tokens_in &&
      tokens_out == o.tokens_out &&
      latency_ms == o.latency_ms &&
      cost_usd_micro == o.cost_usd_micro &&
      cached == o.cached &&
      fallback == o.fallback
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


173
174
175
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 173

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



179
180
181
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 179

def hash
  [text, generation_id, model, tokens_in, tokens_out, latency_ms, cost_usd_micro, cached, fallback].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 208

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
# File 'lib/repull/models/generate_studio_completion200_response_data.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end