Class: Repull::GetUsageLogs200ResponseDataInner

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/repull/models/get_usage_logs200_response_data_inner.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetUsageLogs200ResponseDataInner

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::GetUsageLogs200ResponseDataInner` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::GetUsageLogs200ResponseDataInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'request_id')
    self.request_id = attributes[:'request_id']
  end

  if attributes.key?(:'method')
    self.method = attributes[:'method']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  end

  if attributes.key?(:'operation_id')
    self.operation_id = attributes[:'operation_id']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'latency_ms')
    self.latency_ms = attributes[:'latency_ms']
  end

  if attributes.key?(:'request_bytes')
    self.request_bytes = attributes[:'request_bytes']
  end

  if attributes.key?(:'response_bytes')
    self.response_bytes = attributes[:'response_bytes']
  end

  if attributes.key?(:'ip_address')
    self.ip_address = attributes[:'ip_address']
  end

  if attributes.key?(:'user_agent')
    self.user_agent = attributes[:'user_agent']
  end

  if attributes.key?(:'error_code')
    self.error_code = attributes[:'error_code']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 42

def created_at
  @created_at
end

#error_codeObject

Returns the value of attribute error_code.



40
41
42
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 40

def error_code
  @error_code
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 18

def id
  @id
end

#ip_addressObject

Returns the value of attribute ip_address.



36
37
38
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 36

def ip_address
  @ip_address
end

#latency_msObject

Returns the value of attribute latency_ms.



30
31
32
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 30

def latency_ms
  @latency_ms
end

#methodObject

Returns the value of attribute method.



22
23
24
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 22

def method
  @method
end

#operation_idObject

Returns the value of attribute operation_id.



26
27
28
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 26

def operation_id
  @operation_id
end

#pathObject

Returns the value of attribute path.



24
25
26
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 24

def path
  @path
end

#request_bytesObject

Returns the value of attribute request_bytes.



32
33
34
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 32

def request_bytes
  @request_bytes
end

#request_idObject

Returns the value of attribute request_id.



20
21
22
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 20

def request_id
  @request_id
end

#response_bytesObject

Returns the value of attribute response_bytes.



34
35
36
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 34

def response_bytes
  @response_bytes
end

#status_codeObject

Returns the value of attribute status_code.



28
29
30
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 28

def status_code
  @status_code
end

#user_agentObject

Returns the value of attribute user_agent.



38
39
40
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 38

def user_agent
  @user_agent
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 45

def self.attribute_map
  {
    :'id' => :'id',
    :'request_id' => :'requestId',
    :'method' => :'method',
    :'path' => :'path',
    :'operation_id' => :'operationId',
    :'status_code' => :'statusCode',
    :'latency_ms' => :'latencyMs',
    :'request_bytes' => :'requestBytes',
    :'response_bytes' => :'responseBytes',
    :'ip_address' => :'ipAddress',
    :'user_agent' => :'userAgent',
    :'error_code' => :'errorCode',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 226

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 93

def self.openapi_nullable
  Set.new([
    :'request_id',
    :'operation_id',
    :'status_code',
    :'latency_ms',
    :'request_bytes',
    :'response_bytes',
    :'ip_address',
    :'user_agent',
    :'error_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 74

def self.openapi_types
  {
    :'id' => :'String',
    :'request_id' => :'String',
    :'method' => :'String',
    :'path' => :'String',
    :'operation_id' => :'String',
    :'status_code' => :'Integer',
    :'latency_ms' => :'Integer',
    :'request_bytes' => :'Integer',
    :'response_bytes' => :'Integer',
    :'ip_address' => :'String',
    :'user_agent' => :'String',
    :'error_code' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 193

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      request_id == o.request_id &&
      method == o.method &&
      path == o.path &&
      operation_id == o.operation_id &&
      status_code == o.status_code &&
      latency_ms == o.latency_ms &&
      request_bytes == o.request_bytes &&
      response_bytes == o.response_bytes &&
      ip_address == o.ip_address &&
      user_agent == o.user_agent &&
      error_code == o.error_code &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


213
214
215
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 213

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



219
220
221
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 219

def hash
  [id, request_id, method, path, operation_id, status_code, latency_ms, request_bytes, response_bytes, ip_address, user_agent, error_code, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



178
179
180
181
182
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 178

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 248

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



186
187
188
189
# File 'lib/repull/models/get_usage_logs200_response_data_inner.rb', line 186

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end