Class: Repull::GetUsageSummary200Response

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/get_usage_summary200_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GetUsageSummary200Response

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/repull/models/get_usage_summary200_response.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::GetUsageSummary200Response` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::GetUsageSummary200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'tier')
    self.tier = attributes[:'tier']
  end

  if attributes.key?(:'limits')
    self.limits = attributes[:'limits']
  end

  if attributes.key?(:'used')
    self.used = attributes[:'used']
  end

  if attributes.key?(:'remaining')
    self.remaining = attributes[:'remaining']
  end

  if attributes.key?(:'resets_at')
    self.resets_at = attributes[:'resets_at']
  end

  if attributes.key?(:'breakdown')
    if (value = attributes[:'breakdown']).is_a?(Array)
      self.breakdown = value
    end
  end

  if attributes.key?(:'timeline')
    if (value = attributes[:'timeline']).is_a?(Array)
      self.timeline = value
    end
  end

  if attributes.key?(:'status_distribution')
    self.status_distribution = attributes[:'status_distribution']
  end

  if attributes.key?(:'totals')
    self.totals = attributes[:'totals']
  end

  if attributes.key?(:'range')
    self.range = attributes[:'range']
  end
end

Instance Attribute Details

#breakdownObject

Returns the value of attribute breakdown.



28
29
30
# File 'lib/repull/models/get_usage_summary200_response.rb', line 28

def breakdown
  @breakdown
end

#limitsObject

Returns the value of attribute limits.



20
21
22
# File 'lib/repull/models/get_usage_summary200_response.rb', line 20

def limits
  @limits
end

#rangeObject

Returns the value of attribute range.



36
37
38
# File 'lib/repull/models/get_usage_summary200_response.rb', line 36

def range
  @range
end

#remainingObject

Returns the value of attribute remaining.



24
25
26
# File 'lib/repull/models/get_usage_summary200_response.rb', line 24

def remaining
  @remaining
end

#resets_atObject

Returns the value of attribute resets_at.



26
27
28
# File 'lib/repull/models/get_usage_summary200_response.rb', line 26

def resets_at
  @resets_at
end

#status_distributionObject

Returns the value of attribute status_distribution.



32
33
34
# File 'lib/repull/models/get_usage_summary200_response.rb', line 32

def status_distribution
  @status_distribution
end

#tierObject

Returns the value of attribute tier.



18
19
20
# File 'lib/repull/models/get_usage_summary200_response.rb', line 18

def tier
  @tier
end

#timelineObject

Returns the value of attribute timeline.



30
31
32
# File 'lib/repull/models/get_usage_summary200_response.rb', line 30

def timeline
  @timeline
end

#totalsObject

Returns the value of attribute totals.



34
35
36
# File 'lib/repull/models/get_usage_summary200_response.rb', line 34

def totals
  @totals
end

#usedObject

Returns the value of attribute used.



22
23
24
# File 'lib/repull/models/get_usage_summary200_response.rb', line 22

def used
  @used
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/repull/models/get_usage_summary200_response.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/repull/models/get_usage_summary200_response.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/repull/models/get_usage_summary200_response.rb', line 39

def self.attribute_map
  {
    :'tier' => :'tier',
    :'limits' => :'limits',
    :'used' => :'used',
    :'remaining' => :'remaining',
    :'resets_at' => :'resets_at',
    :'breakdown' => :'breakdown',
    :'timeline' => :'timeline',
    :'status_distribution' => :'statusDistribution',
    :'totals' => :'totals',
    :'range' => :'range'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/repull/models/get_usage_summary200_response.rb', line 194

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/repull/models/get_usage_summary200_response.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/repull/models/get_usage_summary200_response.rb', line 65

def self.openapi_types
  {
    :'tier' => :'String',
    :'limits' => :'GetUsageSummary200ResponseLimits',
    :'used' => :'GetUsageSummary200ResponseUsed',
    :'remaining' => :'GetUsageSummary200ResponseRemaining',
    :'resets_at' => :'Time',
    :'breakdown' => :'Array<GetUsageSummary200ResponseBreakdownInner>',
    :'timeline' => :'Array<GetUsageSummary200ResponseTimelineInner>',
    :'status_distribution' => :'GetUsageSummary200ResponseStatusDistribution',
    :'totals' => :'GetUsageSummary200ResponseTotals',
    :'range' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/repull/models/get_usage_summary200_response.rb', line 164

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      tier == o.tier &&
      limits == o.limits &&
      used == o.used &&
      remaining == o.remaining &&
      resets_at == o.resets_at &&
      breakdown == o.breakdown &&
      timeline == o.timeline &&
      status_distribution == o.status_distribution &&
      totals == o.totals &&
      range == o.range
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


181
182
183
# File 'lib/repull/models/get_usage_summary200_response.rb', line 181

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



187
188
189
# File 'lib/repull/models/get_usage_summary200_response.rb', line 187

def hash
  [tier, limits, used, remaining, resets_at, breakdown, timeline, status_distribution, totals, range].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



149
150
151
152
153
# File 'lib/repull/models/get_usage_summary200_response.rb', line 149

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/repull/models/get_usage_summary200_response.rb', line 216

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



157
158
159
160
# File 'lib/repull/models/get_usage_summary200_response.rb', line 157

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end