Class: Repull::GuestContact

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/guest_contact.rb

Overview

One contact channel attached to a guest profile (phone, email, etc.).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GuestContact

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/repull/models/guest_contact.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::GuestContact` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::GuestContact`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  end

  if attributes.key?(:'is_primary')
    self.is_primary = attributes[:'is_primary']
  end

  if attributes.key?(:'last_used')
    self.last_used = attributes[:'last_used']
  end
end

Instance Attribute Details

#is_primaryObject

Returns the value of attribute is_primary.



26
27
28
# File 'lib/repull/models/guest_contact.rb', line 26

def is_primary
  @is_primary
end

#last_usedObject

Returns the value of attribute last_used.



28
29
30
# File 'lib/repull/models/guest_contact.rb', line 28

def last_used
  @last_used
end

#typeObject

Contact channel type (‘phone`, `email`, etc.).



20
21
22
# File 'lib/repull/models/guest_contact.rb', line 20

def type
  @type
end

#valueObject

Returns the value of attribute value.



22
23
24
# File 'lib/repull/models/guest_contact.rb', line 22

def value
  @value
end

#verifiedObject

Returns the value of attribute verified.



24
25
26
# File 'lib/repull/models/guest_contact.rb', line 24

def verified
  @verified
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/repull/models/guest_contact.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/repull/models/guest_contact.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/repull/models/guest_contact.rb', line 31

def self.attribute_map
  {
    :'type' => :'type',
    :'value' => :'value',
    :'verified' => :'verified',
    :'is_primary' => :'isPrimary',
    :'last_used' => :'lastUsed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/repull/models/guest_contact.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
67
# File 'lib/repull/models/guest_contact.rb', line 63

def self.openapi_nullable
  Set.new([
    :'last_used'
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/repull/models/guest_contact.rb', line 52

def self.openapi_types
  {
    :'type' => :'String',
    :'value' => :'String',
    :'verified' => :'Boolean',
    :'is_primary' => :'Boolean',
    :'last_used' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



123
124
125
126
127
128
129
130
131
# File 'lib/repull/models/guest_contact.rb', line 123

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      value == o.value &&
      verified == o.verified &&
      is_primary == o.is_primary &&
      last_used == o.last_used
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/repull/models/guest_contact.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/repull/models/guest_contact.rb', line 141

def hash
  [type, value, verified, is_primary, last_used].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
# File 'lib/repull/models/guest_contact.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/repull/models/guest_contact.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



116
117
118
119
# File 'lib/repull/models/guest_contact.rb', line 116

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end