Class: Repull::Listing

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/listing.rb

Overview

A vacation rental listing in your Repull workspace.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Listing

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/repull/models/listing.rb', line 101

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::Listing` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::Listing`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'channels')
    if (value = attributes[:'channels']).is_a?(Array)
      self.channels = value
    end
  end

  if attributes.key?(:'amenities')
    if (value = attributes[:'amenities']).is_a?(Array)
      self.amenities = value
    end
  end

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end
end

Instance Attribute Details

#addressObject

Returns the value of attribute address.



24
25
26
# File 'lib/repull/models/listing.rb', line 24

def address
  @address
end

#amenitiesObject

Amenity rows for the listing. **Only present when the caller passes ‘?include=amenities`.** Empty array (`[]`) when the listing has no amenity rows.



34
35
36
# File 'lib/repull/models/listing.rb', line 34

def amenities
  @amenities
end

#channelsObject

Channels (Airbnb, Booking, VRBO, etc.) the listing is connected to.



31
32
33
# File 'lib/repull/models/listing.rb', line 31

def channels
  @channels
end

#contentObject

**Only present when the caller passes ‘?include=content`.** Sourced from `listings_descriptions` for the `en` locale. `null` when the listing has no description row stored (vs the field being absent — that signals the caller did not opt into the expansion).



37
38
39
# File 'lib/repull/models/listing.rb', line 37

def content
  @content
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/repull/models/listing.rb', line 42

def created_at
  @created_at
end

#detailsObject

**Only present when the caller passes ‘?include=details`.** Sourced from `listings_details`. `null` when the listing has no details row stored (vs the field being absent — that signals the caller did not opt into the expansion).



40
41
42
# File 'lib/repull/models/listing.rb', line 40

def details
  @details
end

#idObject

Repull listing id



20
21
22
# File 'lib/repull/models/listing.rb', line 20

def id
  @id
end

#nameObject

Returns the value of attribute name.



22
23
24
# File 'lib/repull/models/listing.rb', line 22

def name
  @name
end

#statusObject

Returns the value of attribute status.



28
29
30
# File 'lib/repull/models/listing.rb', line 28

def status
  @status
end

#thumbnail_urlObject

Returns the value of attribute thumbnail_url.



26
27
28
# File 'lib/repull/models/listing.rb', line 26

def thumbnail_url
  @thumbnail_url
end

#updated_atObject

Returns the value of attribute updated_at.



44
45
46
# File 'lib/repull/models/listing.rb', line 44

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/repull/models/listing.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/repull/models/listing.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/repull/models/listing.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'address' => :'address',
    :'thumbnail_url' => :'thumbnailUrl',
    :'status' => :'status',
    :'channels' => :'channels',
    :'amenities' => :'amenities',
    :'content' => :'content',
    :'details' => :'details',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/repull/models/listing.rb', line 212

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
# File 'lib/repull/models/listing.rb', line 91

def self.openapi_nullable
  Set.new([
    :'thumbnail_url',
    :'content',
    :'details',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/repull/models/listing.rb', line 74

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'address' => :'ListingAddress',
    :'thumbnail_url' => :'String',
    :'status' => :'String',
    :'channels' => :'Array<ListingChannel>',
    :'amenities' => :'Array<ListingAmenity>',
    :'content' => :'ListingContent',
    :'details' => :'ListingDetails',
    :'created_at' => :'Time',
    :'updated_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/repull/models/listing.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      address == o.address &&
      thumbnail_url == o.thumbnail_url &&
      status == o.status &&
      channels == o.channels &&
      amenities == o.amenities &&
      content == o.content &&
      details == o.details &&
      created_at == o.created_at &&
      updated_at == o.updated_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


199
200
201
# File 'lib/repull/models/listing.rb', line 199

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



205
206
207
# File 'lib/repull/models/listing.rb', line 205

def hash
  [id, name, address, thumbnail_url, status, channels, amenities, content, details, created_at, updated_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
# File 'lib/repull/models/listing.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/repull/models/listing.rb', line 234

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
# File 'lib/repull/models/listing.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end