Class: Repull::ListingAmenity
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ListingAmenity
- Defined in:
- lib/repull/models/listing_amenity.rb
Overview
A single amenity row from the unified ‘listings_amenities` table. Surfaced on `GET /v1/listings/id` and `GET /v1/properties/id` only when the caller passes `?include=amenities`.
Instance Attribute Summary collapse
-
#amenity_key ⇒ Object
Canonical amenity key (e.g. ‘wifi`, `pool`, `parking`).
-
#category ⇒ Object
Optional grouping (e.g. ‘essentials`, `safety`).
-
#instruction ⇒ Object
Optional free-form instruction for the guest (e.g. WiFi password, parking notes).
-
#is_present ⇒ Object
‘true` when the listing has this amenity, `false` when it has been explicitly opted out.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListingAmenity
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListingAmenity
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/repull/models/listing_amenity.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingAmenity` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingAmenity`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'amenity_key') self.amenity_key = attributes[:'amenity_key'] else self.amenity_key = nil end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'is_present') self.is_present = attributes[:'is_present'] else self.is_present = nil end if attributes.key?(:'instruction') self.instruction = attributes[:'instruction'] end end |
Instance Attribute Details
#amenity_key ⇒ Object
Canonical amenity key (e.g. ‘wifi`, `pool`, `parking`).
20 21 22 |
# File 'lib/repull/models/listing_amenity.rb', line 20 def amenity_key @amenity_key end |
#category ⇒ Object
Optional grouping (e.g. ‘essentials`, `safety`).
23 24 25 |
# File 'lib/repull/models/listing_amenity.rb', line 23 def category @category end |
#instruction ⇒ Object
Optional free-form instruction for the guest (e.g. WiFi password, parking notes).
29 30 31 |
# File 'lib/repull/models/listing_amenity.rb', line 29 def instruction @instruction end |
#is_present ⇒ Object
‘true` when the listing has this amenity, `false` when it has been explicitly opted out.
26 27 28 |
# File 'lib/repull/models/listing_amenity.rb', line 26 def is_present @is_present end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/repull/models/listing_amenity.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/repull/models/listing_amenity.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/repull/models/listing_amenity.rb', line 32 def self.attribute_map { :'amenity_key' => :'amenityKey', :'category' => :'category', :'is_present' => :'isPresent', :'instruction' => :'instruction' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/repull/models/listing_amenity.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 |
# File 'lib/repull/models/listing_amenity.rb', line 62 def self.openapi_nullable Set.new([ :'category', :'instruction' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/repull/models/listing_amenity.rb', line 52 def self.openapi_types { :'amenity_key' => :'String', :'category' => :'String', :'is_present' => :'Boolean', :'instruction' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 |
# File 'lib/repull/models/listing_amenity.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && amenity_key == o.amenity_key && category == o.category && is_present == o.is_present && instruction == o.instruction end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/repull/models/listing_amenity.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/repull/models/listing_amenity.rb', line 170 def hash [amenity_key, category, is_present, instruction].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/repull/models/listing_amenity.rb', line 108 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @amenity_key.nil? invalid_properties.push('invalid value for "amenity_key", amenity_key cannot be nil.') end if @is_present.nil? invalid_properties.push('invalid value for "is_present", is_present cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/repull/models/listing_amenity.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 129 |
# File 'lib/repull/models/listing_amenity.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @amenity_key.nil? return false if @is_present.nil? true end |