Class: Repull::ListingCompsResponse

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/listing_comps_response.rb

Overview

Returned by ‘GET /v1/listings/id/comps`. Comps without coordinates are excluded — there’s no way to rank them by distance. May include a ‘warning` field when the source listing itself has no coordinates.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListingCompsResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/repull/models/listing_comps_response.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingCompsResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingCompsResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'listing_id')
    self.listing_id = attributes[:'listing_id']
  end

  if attributes.key?(:'date_range')
    self.date_range = attributes[:'date_range']
  end

  if attributes.key?(:'radius_km')
    self.radius_km = attributes[:'radius_km']
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  end

  if attributes.key?(:'data')
    if (value = attributes[:'data']).is_a?(Array)
      self.data = value
    end
  end

  if attributes.key?(:'warning')
    self.warning = attributes[:'warning']
  end
end

Instance Attribute Details

#dataObject

Returns the value of attribute data.



27
28
29
# File 'lib/repull/models/listing_comps_response.rb', line 27

def data
  @data
end

#date_rangeObject

Returns the value of attribute date_range.



21
22
23
# File 'lib/repull/models/listing_comps_response.rb', line 21

def date_range
  @date_range
end

#listing_idObject

Returns the value of attribute listing_id.



19
20
21
# File 'lib/repull/models/listing_comps_response.rb', line 19

def listing_id
  @listing_id
end

#radius_kmObject

Returns the value of attribute radius_km.



23
24
25
# File 'lib/repull/models/listing_comps_response.rb', line 23

def radius_km
  @radius_km
end

#totalObject

Returns the value of attribute total.



25
26
27
# File 'lib/repull/models/listing_comps_response.rb', line 25

def total
  @total
end

#warningObject

Present (and ‘data` empty) when the source listing has no coordinates.



30
31
32
# File 'lib/repull/models/listing_comps_response.rb', line 30

def warning
  @warning
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/repull/models/listing_comps_response.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/repull/models/listing_comps_response.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/repull/models/listing_comps_response.rb', line 33

def self.attribute_map
  {
    :'listing_id' => :'listingId',
    :'date_range' => :'dateRange',
    :'radius_km' => :'radiusKm',
    :'total' => :'total',
    :'data' => :'data',
    :'warning' => :'warning'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/repull/models/listing_comps_response.rb', line 159

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/repull/models/listing_comps_response.rb', line 67

def self.openapi_nullable
  Set.new([
    :'warning'
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/repull/models/listing_comps_response.rb', line 55

def self.openapi_types
  {
    :'listing_id' => :'String',
    :'date_range' => :'ListingPricingResponseDateRange',
    :'radius_km' => :'Float',
    :'total' => :'Integer',
    :'data' => :'Array<ListingComp>',
    :'warning' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
140
141
142
# File 'lib/repull/models/listing_comps_response.rb', line 133

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      listing_id == o.listing_id &&
      date_range == o.date_range &&
      radius_km == o.radius_km &&
      total == o.total &&
      data == o.data &&
      warning == o.warning
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


146
147
148
# File 'lib/repull/models/listing_comps_response.rb', line 146

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



152
153
154
# File 'lib/repull/models/listing_comps_response.rb', line 152

def hash
  [listing_id, date_range, radius_km, total, data, warning].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
# File 'lib/repull/models/listing_comps_response.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/repull/models/listing_comps_response.rb', line 181

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
# File 'lib/repull/models/listing_comps_response.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end