Class: Repull::ListingContentUpdateRequestPhotosInnerOneOf

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/repull/models/listing_content_update_request_photos_inner_one_of.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ListingContentUpdateRequestPhotosInnerOneOf

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingContentUpdateRequestPhotosInnerOneOf` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingContentUpdateRequestPhotosInnerOneOf`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'thumbnail_url')
    self.thumbnail_url = attributes[:'thumbnail_url']
  end

  if attributes.key?(:'caption')
    self.caption = attributes[:'caption']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  else
    self.category = 'property'
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'sort_order')
    self.sort_order = attributes[:'sort_order']
  end

  if attributes.key?(:'source_url')
    self.source_url = attributes[:'source_url']
  end
end

Instance Attribute Details

#captionObject

Returns the value of attribute caption.



23
24
25
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 23

def caption
  @caption
end

#categoryObject

Returns the value of attribute category.



25
26
27
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 25

def category
  @category
end

#heightObject

Returns the value of attribute height.



29
30
31
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 29

def height
  @height
end

#sort_orderObject

Explicit position; defaults to the array index.



32
33
34
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 32

def sort_order
  @sort_order
end

#source_urlObject

Provenance URL; defaults to url.



35
36
37
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 35

def source_url
  @source_url
end

#thumbnail_urlObject

Returns the value of attribute thumbnail_url.



21
22
23
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 21

def thumbnail_url
  @thumbnail_url
end

#urlObject

Hosted image URL (http/https).



19
20
21
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 19

def url
  @url
end

#widthObject

Returns the value of attribute width.



27
28
29
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 27

def width
  @width
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 38

def self.attribute_map
  {
    :'url' => :'url',
    :'thumbnail_url' => :'thumbnailUrl',
    :'caption' => :'caption',
    :'category' => :'category',
    :'width' => :'width',
    :'height' => :'height',
    :'sort_order' => :'sortOrder',
    :'source_url' => :'sourceUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
85
86
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 76

def self.openapi_nullable
  Set.new([
    :'thumbnail_url',
    :'caption',
    :'category',
    :'width',
    :'height',
    :'sort_order',
    :'source_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 62

def self.openapi_types
  {
    :'url' => :'String',
    :'thumbnail_url' => :'String',
    :'caption' => :'String',
    :'category' => :'String',
    :'width' => :'Integer',
    :'height' => :'Integer',
    :'sort_order' => :'Integer',
    :'source_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      url == o.url &&
      thumbnail_url == o.thumbnail_url &&
      caption == o.caption &&
      category == o.category &&
      width == o.width &&
      height == o.height &&
      sort_order == o.sort_order &&
      source_url == o.source_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 194

def hash
  [url, thumbnail_url, caption, category, width, height, sort_order, source_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
159
# File 'lib/repull/models/listing_content_update_request_photos_inner_one_of.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @url.nil?
  true
end