Class: Repull::ListingPricingApplyResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ListingPricingApplyResponse
- Defined in:
- lib/repull/models/listing_pricing_apply_response.rb
Instance Attribute Summary collapse
-
#applied ⇒ Object
Number of recommendations applied (apply action only).
-
#declined ⇒ Object
Number of dates declined (decline action only).
-
#ok ⇒ Object
Returns the value of attribute ok.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListingPricingApplyResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListingPricingApplyResponse
Initializes the object
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 64 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingPricingApplyResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingPricingApplyResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'ok') self.ok = attributes[:'ok'] end if attributes.key?(:'applied') self.applied = attributes[:'applied'] end if attributes.key?(:'declined') self.declined = attributes[:'declined'] end end |
Instance Attribute Details
#applied ⇒ Object
Number of recommendations applied (apply action only).
21 22 23 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 21 def applied @applied end |
#declined ⇒ Object
Number of dates declined (decline action only).
24 25 26 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 24 def declined @declined end |
#ok ⇒ Object
Returns the value of attribute ok.
18 19 20 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 18 def ok @ok end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 27 def self.attribute_map { :'ok' => :'ok', :'applied' => :'applied', :'declined' => :'declined' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 131 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 59 60 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 55 def self.openapi_nullable Set.new([ :'applied', :'declined' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 46 def self.openapi_types { :'ok' => :'Boolean', :'applied' => :'Integer', :'declined' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
108 109 110 111 112 113 114 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 108 def ==(o) return true if self.equal?(o) self.class == o.class && ok == o.ok && applied == o.applied && declined == o.declined end |
#eql?(o) ⇒ Boolean
118 119 120 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 118 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
124 125 126 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 124 def hash [ok, applied, declined].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
93 94 95 96 97 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 93 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 153 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
101 102 103 104 |
# File 'lib/repull/models/listing_pricing_apply_response.rb', line 101 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |