Class: Repull::ListingPublishStatusConnection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ListingPublishStatusConnection
- Defined in:
- lib/repull/models/listing_publish_status_connection.rb
Overview
Per-channel connection state. Distinct from ‘channels` (sync activity) — a listing can be connected here yet have empty `channels` if it has never been pushed.
Instance Attribute Summary collapse
-
#channel ⇒ Object
Channel name: airbnb, booking, vrbo, etc.
-
#connected ⇒ Object
True when the link is active (not disconnected/suspended).
-
#since ⇒ Object
ISO timestamp the connection was first established.
-
#sync_enabled ⇒ Object
True when sync writes are enabled for this channel.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListingPublishStatusConnection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListingPublishStatusConnection
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingPublishStatusConnection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingPublishStatusConnection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'channel') self.channel = attributes[:'channel'] end if attributes.key?(:'connected') self.connected = attributes[:'connected'] end if attributes.key?(:'sync_enabled') self.sync_enabled = attributes[:'sync_enabled'] end if attributes.key?(:'since') self.since = attributes[:'since'] end end |
Instance Attribute Details
#channel ⇒ Object
Channel name: airbnb, booking, vrbo, etc.
20 21 22 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 20 def channel @channel end |
#connected ⇒ Object
True when the link is active (not disconnected/suspended).
23 24 25 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 23 def connected @connected end |
#since ⇒ Object
ISO timestamp the connection was first established.
29 30 31 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 29 def since @since end |
#sync_enabled ⇒ Object
True when sync writes are enabled for this channel.
26 27 28 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 26 def sync_enabled @sync_enabled end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 32 def self.attribute_map { :'channel' => :'channel', :'connected' => :'connected', :'sync_enabled' => :'syncEnabled', :'since' => :'since' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 142 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 62 def self.openapi_nullable Set.new([ :'since' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 52 def self.openapi_types { :'channel' => :'String', :'connected' => :'Boolean', :'sync_enabled' => :'Boolean', :'since' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
118 119 120 121 122 123 124 125 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 118 def ==(o) return true if self.equal?(o) self.class == o.class && channel == o.channel && connected == o.connected && sync_enabled == o.sync_enabled && since == o.since end |
#eql?(o) ⇒ Boolean
129 130 131 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 129 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
135 136 137 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 135 def hash [channel, connected, sync_enabled, since].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
103 104 105 106 107 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 103 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 164 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
111 112 113 114 |
# File 'lib/repull/models/listing_publish_status_connection.rb', line 111 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |