Class: Repull::MapAirbnbListingResponse

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/map_airbnb_listing_response.rb

Overview

Id fields are strings (API-wide convention — bigint ids are stringified to avoid 53-bit JS-number precision loss).

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MapAirbnbListingResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::MapAirbnbListingResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::MapAirbnbListingResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  else
    self.success = nil
  end

  if attributes.key?(:'already_mapped')
    self.already_mapped = attributes[:'already_mapped']
  else
    self.already_mapped = nil
  end

  if attributes.key?(:'airbnb_id')
    self.airbnb_id = attributes[:'airbnb_id']
  else
    self.airbnb_id = nil
  end

  if attributes.key?(:'listing_id')
    self.listing_id = attributes[:'listing_id']
  else
    self.listing_id = nil
  end

  if attributes.key?(:'previous_listing_id')
    self.previous_listing_id = attributes[:'previous_listing_id']
  end

  if attributes.key?(:'host_id')
    self.host_id = attributes[:'host_id']
  else
    self.host_id = nil
  end

  if attributes.key?(:'listing_airbnb_id')
    self.listing_airbnb_id = attributes[:'listing_airbnb_id']
  else
    self.listing_airbnb_id = nil
  end

  if attributes.key?(:'platform_link_id')
    self.platform_link_id = attributes[:'platform_link_id']
  else
    self.platform_link_id = nil
  end
end

Instance Attribute Details

#airbnb_idObject

Returns the value of attribute airbnb_id.



24
25
26
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 24

def airbnb_id
  @airbnb_id
end

#already_mappedObject

True when the Airbnb listing was already mapped to this listing (no-op).



22
23
24
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 22

def already_mapped
  @already_mapped
end

#host_idObject

Returns the value of attribute host_id.



31
32
33
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 31

def host_id
  @host_id
end

#listing_airbnb_idObject

Internal id of the listings_airbnb record.



34
35
36
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 34

def listing_airbnb_id
  @listing_airbnb_id
end

#listing_idObject

Returns the value of attribute listing_id.



26
27
28
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 26

def listing_id
  @listing_id
end

Internal id of the resulting listing_platform_links row.



37
38
39
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 37

def platform_link_id
  @platform_link_id
end

#previous_listing_idObject

The listing the Airbnb record pointed at before this call. Omitted on a no-op.



29
30
31
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 29

def previous_listing_id
  @previous_listing_id
end

#successObject

Returns the value of attribute success.



19
20
21
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 19

def success
  @success
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 40

def self.attribute_map
  {
    :'success' => :'success',
    :'already_mapped' => :'alreadyMapped',
    :'airbnb_id' => :'airbnbId',
    :'listing_id' => :'listingId',
    :'previous_listing_id' => :'previousListingId',
    :'host_id' => :'hostId',
    :'listing_airbnb_id' => :'listingAirbnbId',
    :'platform_link_id' => :'platformLinkId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 64

def self.openapi_types
  {
    :'success' => :'Boolean',
    :'already_mapped' => :'Boolean',
    :'airbnb_id' => :'String',
    :'listing_id' => :'String',
    :'previous_listing_id' => :'String',
    :'host_id' => :'String',
    :'listing_airbnb_id' => :'String',
    :'platform_link_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 268

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      success == o.success &&
      already_mapped == o.already_mapped &&
      airbnb_id == o.airbnb_id &&
      listing_id == o.listing_id &&
      previous_listing_id == o.previous_listing_id &&
      host_id == o.host_id &&
      listing_airbnb_id == o.listing_airbnb_id &&
      platform_link_id == o.platform_link_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 289

def hash
  [success, already_mapped, airbnb_id, listing_id, previous_listing_id, host_id, listing_airbnb_id, platform_link_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 148

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @success.nil?
    invalid_properties.push('invalid value for "success", success cannot be nil.')
  end

  if @already_mapped.nil?
    invalid_properties.push('invalid value for "already_mapped", already_mapped cannot be nil.')
  end

  if @airbnb_id.nil?
    invalid_properties.push('invalid value for "airbnb_id", airbnb_id cannot be nil.')
  end

  if @listing_id.nil?
    invalid_properties.push('invalid value for "listing_id", listing_id cannot be nil.')
  end

  if @host_id.nil?
    invalid_properties.push('invalid value for "host_id", host_id cannot be nil.')
  end

  if @listing_airbnb_id.nil?
    invalid_properties.push('invalid value for "listing_airbnb_id", listing_airbnb_id cannot be nil.')
  end

  if @platform_link_id.nil?
    invalid_properties.push('invalid value for "platform_link_id", platform_link_id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
194
# File 'lib/repull/models/map_airbnb_listing_response.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @success.nil?
  return false if @already_mapped.nil?
  return false if @airbnb_id.nil?
  return false if @listing_id.nil?
  return false if @host_id.nil?
  return false if @listing_airbnb_id.nil?
  return false if @platform_link_id.nil?
  true
end