Class: Repull::MarketBrowseEntry

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/market_browse_entry.rb

Overview

Discovery catalog entry returned by ‘/v1/markets/browse`.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarketBrowseEntry

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/repull/models/market_browse_entry.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::MarketBrowseEntry` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::MarketBrowseEntry`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'listings')
    self.listings = attributes[:'listings']
  end

  if attributes.key?(:'avg_adr')
    self.avg_adr = attributes[:'avg_adr']
  end

  if attributes.key?(:'currency')
    self.currency = attributes[:'currency']
  end

  if attributes.key?(:'subscribed')
    self.subscribed = attributes[:'subscribed']
  end
end

Instance Attribute Details

#avg_adrObject

Returns the value of attribute avg_adr.



27
28
29
# File 'lib/repull/models/market_browse_entry.rb', line 27

def avg_adr
  @avg_adr
end

#cityObject

Returns the value of attribute city.



19
20
21
# File 'lib/repull/models/market_browse_entry.rb', line 19

def city
  @city
end

#countryObject

ISO 3166-1 alpha-2.



22
23
24
# File 'lib/repull/models/market_browse_entry.rb', line 22

def country
  @country
end

#currencyObject

ISO 4217 currency derived from the country code.



30
31
32
# File 'lib/repull/models/market_browse_entry.rb', line 30

def currency
  @currency
end

#listingsObject

Atlas-tracked active comps in this city.



25
26
27
# File 'lib/repull/models/market_browse_entry.rb', line 25

def listings
  @listings
end

#subscribedObject

Returns the value of attribute subscribed.



32
33
34
# File 'lib/repull/models/market_browse_entry.rb', line 32

def subscribed
  @subscribed
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/repull/models/market_browse_entry.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/repull/models/market_browse_entry.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/repull/models/market_browse_entry.rb', line 35

def self.attribute_map
  {
    :'city' => :'city',
    :'country' => :'country',
    :'listings' => :'listings',
    :'avg_adr' => :'avgAdr',
    :'currency' => :'currency',
    :'subscribed' => :'subscribed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/repull/models/market_browse_entry.rb', line 159

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
73
# File 'lib/repull/models/market_browse_entry.rb', line 69

def self.openapi_nullable
  Set.new([
    :'avg_adr',
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/repull/models/market_browse_entry.rb', line 57

def self.openapi_types
  {
    :'city' => :'String',
    :'country' => :'String',
    :'listings' => :'Integer',
    :'avg_adr' => :'Float',
    :'currency' => :'String',
    :'subscribed' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



133
134
135
136
137
138
139
140
141
142
# File 'lib/repull/models/market_browse_entry.rb', line 133

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      city == o.city &&
      country == o.country &&
      listings == o.listings &&
      avg_adr == o.avg_adr &&
      currency == o.currency &&
      subscribed == o.subscribed
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


146
147
148
# File 'lib/repull/models/market_browse_entry.rb', line 146

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



152
153
154
# File 'lib/repull/models/market_browse_entry.rb', line 152

def hash
  [city, country, listings, avg_adr, currency, subscribed].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
# File 'lib/repull/models/market_browse_entry.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/repull/models/market_browse_entry.rb', line 181

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



126
127
128
129
# File 'lib/repull/models/market_browse_entry.rb', line 126

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end