Class: Repull::MarketEvent

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/market_event.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarketEvent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/repull/models/market_event.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::MarketEvent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::MarketEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'start_date')
    self.start_date = attributes[:'start_date']
  end

  if attributes.key?(:'end_date')
    self.end_date = attributes[:'end_date']
  end

  if attributes.key?(:'lat')
    self.lat = attributes[:'lat']
  end

  if attributes.key?(:'lng')
    self.lng = attributes[:'lng']
  end

  if attributes.key?(:'rank')
    self.rank = attributes[:'rank']
  end

  if attributes.key?(:'local_rank')
    self.local_rank = attributes[:'local_rank']
  end

  if attributes.key?(:'attendance')
    self.attendance = attributes[:'attendance']
  end

  if attributes.key?(:'demand_impact')
    self.demand_impact = attributes[:'demand_impact']
  end

  if attributes.key?(:'labels')
    if (value = attributes[:'labels']).is_a?(Array)
      self.labels = value
    end
  end
end

Instance Attribute Details

#attendanceObject

Returns the value of attribute attendance.



36
37
38
# File 'lib/repull/models/market_event.rb', line 36

def attendance
  @attendance
end

#categoryObject

Returns the value of attribute category.



22
23
24
# File 'lib/repull/models/market_event.rb', line 22

def category
  @category
end

#demand_impactObject

Returns the value of attribute demand_impact.



38
39
40
# File 'lib/repull/models/market_event.rb', line 38

def demand_impact
  @demand_impact
end

#end_dateObject

Returns the value of attribute end_date.



26
27
28
# File 'lib/repull/models/market_event.rb', line 26

def end_date
  @end_date
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/repull/models/market_event.rb', line 18

def id
  @id
end

#labelsObject

Returns the value of attribute labels.



40
41
42
# File 'lib/repull/models/market_event.rb', line 40

def labels
  @labels
end

#latObject

Returns the value of attribute lat.



28
29
30
# File 'lib/repull/models/market_event.rb', line 28

def lat
  @lat
end

#lngObject

Returns the value of attribute lng.



30
31
32
# File 'lib/repull/models/market_event.rb', line 30

def lng
  @lng
end

#local_rankObject

Returns the value of attribute local_rank.



34
35
36
# File 'lib/repull/models/market_event.rb', line 34

def local_rank
  @local_rank
end

#rankObject

Returns the value of attribute rank.



32
33
34
# File 'lib/repull/models/market_event.rb', line 32

def rank
  @rank
end

#start_dateObject

Returns the value of attribute start_date.



24
25
26
# File 'lib/repull/models/market_event.rb', line 24

def start_date
  @start_date
end

#titleObject

Returns the value of attribute title.



20
21
22
# File 'lib/repull/models/market_event.rb', line 20

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/repull/models/market_event.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/repull/models/market_event.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/repull/models/market_event.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'title' => :'title',
    :'category' => :'category',
    :'start_date' => :'startDate',
    :'end_date' => :'endDate',
    :'lat' => :'lat',
    :'lng' => :'lng',
    :'rank' => :'rank',
    :'local_rank' => :'localRank',
    :'attendance' => :'attendance',
    :'demand_impact' => :'demandImpact',
    :'labels' => :'labels'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/repull/models/market_event.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/repull/models/market_event.rb', line 89

def self.openapi_nullable
  Set.new([
    :'category',
    :'end_date',
    :'lat',
    :'lng',
    :'rank',
    :'local_rank',
    :'attendance',
    :'demand_impact',
    :'labels'
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/repull/models/market_event.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'title' => :'String',
    :'category' => :'String',
    :'start_date' => :'Date',
    :'end_date' => :'Date',
    :'lat' => :'Float',
    :'lng' => :'Float',
    :'rank' => :'Float',
    :'local_rank' => :'Float',
    :'attendance' => :'Integer',
    :'demand_impact' => :'String',
    :'labels' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/repull/models/market_event.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      title == o.title &&
      category == o.category &&
      start_date == o.start_date &&
      end_date == o.end_date &&
      lat == o.lat &&
      lng == o.lng &&
      rank == o.rank &&
      local_rank == o.local_rank &&
      attendance == o.attendance &&
      demand_impact == o.demand_impact &&
      labels == o.labels
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/repull/models/market_event.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/repull/models/market_event.rb', line 212

def hash
  [id, title, category, start_date, end_date, lat, lng, rank, local_rank, attendance, demand_impact, labels].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
# File 'lib/repull/models/market_event.rb', line 172

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/repull/models/market_event.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



180
181
182
183
# File 'lib/repull/models/market_event.rb', line 180

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end