Class: Repull::MarketMyListing

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/market_my_listing.rb

Overview

Lightweight customer listing entry for map rendering.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarketMyListing

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/repull/models/market_my_listing.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::MarketMyListing` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::MarketMyListing`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'lat')
    self.lat = attributes[:'lat']
  end

  if attributes.key?(:'lng')
    self.lng = attributes[:'lng']
  end

  if attributes.key?(:'thumbnail')
    self.thumbnail = attributes[:'thumbnail']
  end

  if attributes.key?(:'today_price')
    self.today_price = attributes[:'today_price']
  end

  if attributes.key?(:'blocked')
    self.blocked = attributes[:'blocked']
  end

  if attributes.key?(:'booked_nights')
    self.booked_nights = attributes[:'booked_nights']
  end

  if attributes.key?(:'available_nights')
    self.available_nights = attributes[:'available_nights']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#available_nightsObject

Returns the value of attribute available_nights.



38
39
40
# File 'lib/repull/models/market_my_listing.rb', line 38

def available_nights
  @available_nights
end

#blockedObject

Returns the value of attribute blocked.



34
35
36
# File 'lib/repull/models/market_my_listing.rb', line 34

def blocked
  @blocked
end

#booked_nightsObject

Returns the value of attribute booked_nights.



36
37
38
# File 'lib/repull/models/market_my_listing.rb', line 36

def booked_nights
  @booked_nights
end

#cityObject

Returns the value of attribute city.



23
24
25
# File 'lib/repull/models/market_my_listing.rb', line 23

def city
  @city
end

#idObject

Returns the value of attribute id.



19
20
21
# File 'lib/repull/models/market_my_listing.rb', line 19

def id
  @id
end

#latObject

Returns the value of attribute lat.



25
26
27
# File 'lib/repull/models/market_my_listing.rb', line 25

def lat
  @lat
end

#lngObject

Returns the value of attribute lng.



27
28
29
# File 'lib/repull/models/market_my_listing.rb', line 27

def lng
  @lng
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/repull/models/market_my_listing.rb', line 21

def name
  @name
end

#thumbnailObject

Returns the value of attribute thumbnail.



29
30
31
# File 'lib/repull/models/market_my_listing.rb', line 29

def thumbnail
  @thumbnail
end

#today_priceObject

Pre-computed ADR rounded to integer.



32
33
34
# File 'lib/repull/models/market_my_listing.rb', line 32

def today_price
  @today_price
end

#typeObject

Returns the value of attribute type.



40
41
42
# File 'lib/repull/models/market_my_listing.rb', line 40

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/repull/models/market_my_listing.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/repull/models/market_my_listing.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/repull/models/market_my_listing.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'city' => :'city',
    :'lat' => :'lat',
    :'lng' => :'lng',
    :'thumbnail' => :'thumbnail',
    :'today_price' => :'todayPrice',
    :'blocked' => :'blocked',
    :'booked_nights' => :'bookedNights',
    :'available_nights' => :'availableNights',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/repull/models/market_my_listing.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
92
93
# File 'lib/repull/models/market_my_listing.rb', line 87

def self.openapi_nullable
  Set.new([
    :'city',
    :'thumbnail',
    :'today_price',
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/repull/models/market_my_listing.rb', line 70

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'city' => :'String',
    :'lat' => :'Float',
    :'lng' => :'Float',
    :'thumbnail' => :'String',
    :'today_price' => :'Integer',
    :'blocked' => :'Boolean',
    :'booked_nights' => :'Integer',
    :'available_nights' => :'Integer',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/repull/models/market_my_listing.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      city == o.city &&
      lat == o.lat &&
      lng == o.lng &&
      thumbnail == o.thumbnail &&
      today_price == o.today_price &&
      blocked == o.blocked &&
      booked_nights == o.booked_nights &&
      available_nights == o.available_nights &&
      type == o.type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/repull/models/market_my_listing.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/repull/models/market_my_listing.rb', line 197

def hash
  [id, name, city, lat, lng, thumbnail, today_price, blocked, booked_nights, available_nights, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
162
# File 'lib/repull/models/market_my_listing.rb', line 158

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/repull/models/market_my_listing.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



166
167
168
169
# File 'lib/repull/models/market_my_listing.rb', line 166

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end