Class: Repull::MarketSummary

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/market_summary.rb

Overview

Per-city KPIs combining the customer’s own listings with Atlas comp aggregates.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MarketSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/repull/models/market_summary.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::MarketSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::MarketSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'my_listings')
    self.my_listings = attributes[:'my_listings']
  end

  if attributes.key?(:'total_listings')
    self.total_listings = attributes[:'total_listings']
  end

  if attributes.key?(:'market_share_pct')
    self.market_share_pct = attributes[:'market_share_pct']
  end

  if attributes.key?(:'my_avg_adr')
    self.my_avg_adr = attributes[:'my_avg_adr']
  end

  if attributes.key?(:'market_avg_adr')
    self.market_avg_adr = attributes[:'market_avg_adr']
  end

  if attributes.key?(:'price_diff_pct')
    self.price_diff_pct = attributes[:'price_diff_pct']
  end

  if attributes.key?(:'my_avg_rating')
    self.my_avg_rating = attributes[:'my_avg_rating']
  end

  if attributes.key?(:'market_avg_rating')
    self.market_avg_rating = attributes[:'market_avg_rating']
  end

  if attributes.key?(:'my_occupancy_pct')
    self.my_occupancy_pct = attributes[:'my_occupancy_pct']
  end

  if attributes.key?(:'market_occupancy_pct')
    self.market_occupancy_pct = attributes[:'market_occupancy_pct']
  end

  if attributes.key?(:'property_types')
    self.property_types = attributes[:'property_types']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



19
20
21
# File 'lib/repull/models/market_summary.rb', line 19

def city
  @city
end

#market_avg_adrObject

Returns the value of attribute market_avg_adr.



30
31
32
# File 'lib/repull/models/market_summary.rb', line 30

def market_avg_adr
  @market_avg_adr
end

#market_avg_ratingObject

Returns the value of attribute market_avg_rating.



37
38
39
# File 'lib/repull/models/market_summary.rb', line 37

def market_avg_rating
  @market_avg_rating
end

#market_occupancy_pctObject

Returns the value of attribute market_occupancy_pct.



42
43
44
# File 'lib/repull/models/market_summary.rb', line 42

def market_occupancy_pct
  @market_occupancy_pct
end

#market_share_pctObject

Returns the value of attribute market_share_pct.



26
27
28
# File 'lib/repull/models/market_summary.rb', line 26

def market_share_pct
  @market_share_pct
end

#my_avg_adrObject

Returns the value of attribute my_avg_adr.



28
29
30
# File 'lib/repull/models/market_summary.rb', line 28

def my_avg_adr
  @my_avg_adr
end

#my_avg_ratingObject

Returns the value of attribute my_avg_rating.



35
36
37
# File 'lib/repull/models/market_summary.rb', line 35

def my_avg_rating
  @my_avg_rating
end

#my_listingsObject

Returns the value of attribute my_listings.



21
22
23
# File 'lib/repull/models/market_summary.rb', line 21

def my_listings
  @my_listings
end

#my_occupancy_pctObject

Customer’s 30-day forward occupancy %.



40
41
42
# File 'lib/repull/models/market_summary.rb', line 40

def my_occupancy_pct
  @my_occupancy_pct
end

#price_diff_pctObject

(myAvgAdr - marketAvgAdr) / marketAvgAdr * 100, rounded.



33
34
35
# File 'lib/repull/models/market_summary.rb', line 33

def price_diff_pct
  @price_diff_pct
end

#property_typesObject

Distinct property types Atlas has seen in this city.



45
46
47
# File 'lib/repull/models/market_summary.rb', line 45

def property_types
  @property_types
end

#total_listingsObject

Atlas-tracked active comps in this city.



24
25
26
# File 'lib/repull/models/market_summary.rb', line 24

def total_listings
  @total_listings
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/repull/models/market_summary.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/repull/models/market_summary.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/repull/models/market_summary.rb', line 48

def self.attribute_map
  {
    :'city' => :'city',
    :'my_listings' => :'myListings',
    :'total_listings' => :'totalListings',
    :'market_share_pct' => :'marketSharePct',
    :'my_avg_adr' => :'myAvgAdr',
    :'market_avg_adr' => :'marketAvgAdr',
    :'price_diff_pct' => :'priceDiffPct',
    :'my_avg_rating' => :'myAvgRating',
    :'market_avg_rating' => :'marketAvgRating',
    :'my_occupancy_pct' => :'myOccupancyPct',
    :'market_occupancy_pct' => :'marketOccupancyPct',
    :'property_types' => :'propertyTypes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/repull/models/market_summary.rb', line 221

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/repull/models/market_summary.rb', line 94

def self.openapi_nullable
  Set.new([
    :'market_share_pct',
    :'my_avg_adr',
    :'market_avg_adr',
    :'price_diff_pct',
    :'my_avg_rating',
    :'market_avg_rating',
    :'my_occupancy_pct',
    :'market_occupancy_pct',
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/repull/models/market_summary.rb', line 76

def self.openapi_types
  {
    :'city' => :'String',
    :'my_listings' => :'Integer',
    :'total_listings' => :'Integer',
    :'market_share_pct' => :'Integer',
    :'my_avg_adr' => :'Float',
    :'market_avg_adr' => :'Float',
    :'price_diff_pct' => :'Integer',
    :'my_avg_rating' => :'Float',
    :'market_avg_rating' => :'Float',
    :'my_occupancy_pct' => :'Float',
    :'market_occupancy_pct' => :'Float',
    :'property_types' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
# File 'lib/repull/models/market_summary.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      city == o.city &&
      my_listings == o.my_listings &&
      total_listings == o.total_listings &&
      market_share_pct == o.market_share_pct &&
      my_avg_adr == o.my_avg_adr &&
      market_avg_adr == o.market_avg_adr &&
      price_diff_pct == o.price_diff_pct &&
      my_avg_rating == o.my_avg_rating &&
      market_avg_rating == o.market_avg_rating &&
      my_occupancy_pct == o.my_occupancy_pct &&
      market_occupancy_pct == o.market_occupancy_pct &&
      property_types == o.property_types
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


208
209
210
# File 'lib/repull/models/market_summary.rb', line 208

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



214
215
216
# File 'lib/repull/models/market_summary.rb', line 214

def hash
  [city, my_listings, total_listings, market_share_pct, my_avg_adr, market_avg_adr, price_diff_pct, my_avg_rating, market_avg_rating, my_occupancy_pct, market_occupancy_pct, property_types].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
# File 'lib/repull/models/market_summary.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/repull/models/market_summary.rb', line 243

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
# File 'lib/repull/models/market_summary.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end