Class: Repull::PlumguideApi
- Inherits:
-
Object
- Object
- Repull::PlumguideApi
- Defined in:
- lib/repull/api/plumguide_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_plumguide_webhooks(opts = {}) ⇒ nil
Remove Plumguide webhook config Delete the Plumguide webhook configuration for this workspace.
-
#delete_plumguide_webhooks_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove Plumguide webhook config Delete the Plumguide webhook configuration for this workspace.
-
#get_plumguide_availability(opts = {}) ⇒ nil
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing.
-
#get_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing.
-
#get_plumguide_pricing(opts = {}) ⇒ nil
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
-
#get_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
-
#get_plumguide_webhooks(opts = {}) ⇒ nil
Get Plumguide webhook config Read the current Plumguide webhook configuration for this workspace.
-
#get_plumguide_webhooks_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide webhook config Read the current Plumguide webhook configuration for this workspace.
-
#initialize(api_client = ApiClient.default) ⇒ PlumguideApi
constructor
A new instance of PlumguideApi.
-
#list_plumguide_bookings(opts = {}) ⇒ nil
List Plumguide bookings List Plumguide bookings.
-
#list_plumguide_bookings_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
List Plumguide bookings List Plumguide bookings.
-
#list_plumguide_listings(opts = {}) ⇒ PlumguideListingListResponse
List Plumguide listings List Plumguide listings this workspace has access to.
-
#list_plumguide_listings_with_http_info(opts = {}) ⇒ Array<(PlumguideListingListResponse, Integer, Hash)>
List Plumguide listings List Plumguide listings this workspace has access to.
-
#update_plumguide_availability(opts = {}) ⇒ nil
Push availability to Plumguide Push per-day availability changes to Plumguide.
-
#update_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push availability to Plumguide Push per-day availability changes to Plumguide.
-
#update_plumguide_pricing(opts = {}) ⇒ nil
Push pricing to Plumguide Push pricing changes to Plumguide.
-
#update_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push pricing to Plumguide Push pricing changes to Plumguide.
-
#update_plumguide_webhooks(request_body, opts = {}) ⇒ nil
Replace Plumguide webhook config Replace the Plumguide webhook configuration.
-
#update_plumguide_webhooks_with_http_info(request_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Replace Plumguide webhook config Replace the Plumguide webhook configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PlumguideApi
Returns a new instance of PlumguideApi.
19 20 21 |
# File 'lib/repull/api/plumguide_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/plumguide_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_plumguide_webhooks(opts = {}) ⇒ nil
Remove Plumguide webhook config Delete the Plumguide webhook configuration for this workspace. Plumguide stops delivering webhooks until a new config is set.
26 27 28 29 |
# File 'lib/repull/api/plumguide_api.rb', line 26 def delete_plumguide_webhooks(opts = {}) delete_plumguide_webhooks_with_http_info(opts) nil end |
#delete_plumguide_webhooks_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Remove Plumguide webhook config Delete the Plumguide webhook configuration for this workspace. Plumguide stops delivering webhooks until a new config is set.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/repull/api/plumguide_api.rb', line 35 def delete_plumguide_webhooks_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.delete_plumguide_webhooks ...' end # resource path local_var_path = '/v1/channels/plumguide/webhooks' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.delete_plumguide_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#delete_plumguide_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plumguide_availability(opts = {}) ⇒ nil
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing. Returns the same row shape as Airbnb availability for SDK convenience.
83 84 85 86 |
# File 'lib/repull/api/plumguide_api.rb', line 83 def get_plumguide_availability(opts = {}) get_plumguide_availability_with_http_info(opts) nil end |
#get_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing. Returns the same row shape as Airbnb availability for SDK convenience.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/repull/api/plumguide_api.rb', line 92 def get_plumguide_availability_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.get_plumguide_availability ...' end # resource path local_var_path = '/v1/channels/plumguide/availability' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.get_plumguide_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#get_plumguide_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plumguide_pricing(opts = {}) ⇒ nil
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
138 139 140 141 |
# File 'lib/repull/api/plumguide_api.rb', line 138 def get_plumguide_pricing(opts = {}) get_plumguide_pricing_with_http_info(opts) nil end |
#get_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/repull/api/plumguide_api.rb', line 147 def get_plumguide_pricing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.get_plumguide_pricing ...' end # resource path local_var_path = '/v1/channels/plumguide/pricing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.get_plumguide_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#get_plumguide_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plumguide_webhooks(opts = {}) ⇒ nil
Get Plumguide webhook config Read the current Plumguide webhook configuration for this workspace.
193 194 195 196 |
# File 'lib/repull/api/plumguide_api.rb', line 193 def get_plumguide_webhooks(opts = {}) get_plumguide_webhooks_with_http_info(opts) nil end |
#get_plumguide_webhooks_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide webhook config Read the current Plumguide webhook configuration for this workspace.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/repull/api/plumguide_api.rb', line 202 def get_plumguide_webhooks_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.get_plumguide_webhooks ...' end # resource path local_var_path = '/v1/channels/plumguide/webhooks' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.get_plumguide_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#get_plumguide_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_plumguide_bookings(opts = {}) ⇒ nil
List Plumguide bookings
List Plumguide bookings. Default returns all bookings; pass listing_id to filter to one listing, or booking_code to fetch a single booking.
252 253 254 255 |
# File 'lib/repull/api/plumguide_api.rb', line 252 def list_plumguide_bookings(opts = {}) list_plumguide_bookings_with_http_info(opts) nil end |
#list_plumguide_bookings_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
List Plumguide bookings List Plumguide bookings. Default returns all bookings; pass `listing_id` to filter to one listing, or `booking_code` to fetch a single booking.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/repull/api/plumguide_api.rb', line 263 def list_plumguide_bookings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.list_plumguide_bookings ...' end # resource path local_var_path = '/v1/channels/plumguide/bookings' # query parameters query_params = opts[:query_params] || {} query_params[:'listing_id'] = opts[:'listing_id'] if !opts[:'listing_id'].nil? query_params[:'booking_code'] = opts[:'booking_code'] if !opts[:'booking_code'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.list_plumguide_bookings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#list_plumguide_bookings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_plumguide_listings(opts = {}) ⇒ PlumguideListingListResponse
List Plumguide listings List Plumguide listings this workspace has access to. Plumguide is approval-based — listings appear once Plumguide has accepted them.
313 314 315 316 |
# File 'lib/repull/api/plumguide_api.rb', line 313 def list_plumguide_listings(opts = {}) data, _status_code, _headers = list_plumguide_listings_with_http_info(opts) data end |
#list_plumguide_listings_with_http_info(opts = {}) ⇒ Array<(PlumguideListingListResponse, Integer, Hash)>
List Plumguide listings List Plumguide listings this workspace has access to. Plumguide is approval-based — listings appear once Plumguide has accepted them.
322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/repull/api/plumguide_api.rb', line 322 def list_plumguide_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.list_plumguide_listings ...' end # resource path local_var_path = '/v1/channels/plumguide/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlumguideListingListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.list_plumguide_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#list_plumguide_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_plumguide_availability(opts = {}) ⇒ nil
Push availability to Plumguide Push per-day availability changes to Plumguide. Plumguide accepts only the next 24 months — dates beyond that are silently ignored.
370 371 372 373 |
# File 'lib/repull/api/plumguide_api.rb', line 370 def update_plumguide_availability(opts = {}) update_plumguide_availability_with_http_info(opts) nil end |
#update_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push availability to Plumguide Push per-day availability changes to Plumguide. Plumguide accepts only the next 24 months — dates beyond that are silently ignored.
379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/repull/api/plumguide_api.rb', line 379 def update_plumguide_availability_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.update_plumguide_availability ...' end # resource path local_var_path = '/v1/channels/plumguide/availability' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.update_plumguide_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#update_plumguide_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_plumguide_pricing(opts = {}) ⇒ nil
Push pricing to Plumguide Push pricing changes to Plumguide. Plumguide rounds all prices to whole units of the listing currency — sub-unit precision is silently truncated.
425 426 427 428 |
# File 'lib/repull/api/plumguide_api.rb', line 425 def update_plumguide_pricing(opts = {}) update_plumguide_pricing_with_http_info(opts) nil end |
#update_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push pricing to Plumguide Push pricing changes to Plumguide. Plumguide rounds all prices to whole units of the listing currency — sub-unit precision is silently truncated.
434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 |
# File 'lib/repull/api/plumguide_api.rb', line 434 def update_plumguide_pricing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.update_plumguide_pricing ...' end # resource path local_var_path = '/v1/channels/plumguide/pricing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.update_plumguide_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#update_plumguide_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_plumguide_webhooks(request_body, opts = {}) ⇒ nil
Replace Plumguide webhook config Replace the Plumguide webhook configuration. The body carries the full webhook config payload — this is a full replacement, not a patch.
481 482 483 484 |
# File 'lib/repull/api/plumguide_api.rb', line 481 def update_plumguide_webhooks(request_body, opts = {}) update_plumguide_webhooks_with_http_info(request_body, opts) nil end |
#update_plumguide_webhooks_with_http_info(request_body, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Replace Plumguide webhook config Replace the Plumguide webhook configuration. The body carries the full webhook config payload — this is a full replacement, not a patch.
491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/repull/api/plumguide_api.rb', line 491 def update_plumguide_webhooks_with_http_info(request_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.update_plumguide_webhooks ...' end # verify the required parameter 'request_body' is set if @api_client.config.client_side_validation && request_body.nil? fail ArgumentError, "Missing the required parameter 'request_body' when calling PlumguideApi.update_plumguide_webhooks" end # resource path local_var_path = '/v1/channels/plumguide/webhooks' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request_body) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.update_plumguide_webhooks", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#update_plumguide_webhooks\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |