Class: Repull::ReservationCreatedEvent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ReservationCreatedEvent
- Defined in:
- lib/repull/models/reservation_created_event.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Object
Returns the value of attribute api_version.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#data ⇒ Object
Returns the value of attribute data.
-
#id ⇒ Object
Stable event id — same across delivery retries of the same logical event.
-
#type ⇒ Object
Returns the value of attribute type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReservationCreatedEvent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReservationCreatedEvent
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/repull/models/reservation_created_event.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ReservationCreatedEvent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ReservationCreatedEvent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'data') self.data = attributes[:'data'] else self.data = nil end end |
Instance Attribute Details
#api_version ⇒ Object
Returns the value of attribute api_version.
25 26 27 |
# File 'lib/repull/models/reservation_created_event.rb', line 25 def api_version @api_version end |
#created_at ⇒ Object
Returns the value of attribute created_at.
23 24 25 |
# File 'lib/repull/models/reservation_created_event.rb', line 23 def created_at @created_at end |
#data ⇒ Object
Returns the value of attribute data.
27 28 29 |
# File 'lib/repull/models/reservation_created_event.rb', line 27 def data @data end |
#id ⇒ Object
Stable event id — same across delivery retries of the same logical event.
19 20 21 |
# File 'lib/repull/models/reservation_created_event.rb', line 19 def id @id end |
#type ⇒ Object
Returns the value of attribute type.
21 22 23 |
# File 'lib/repull/models/reservation_created_event.rb', line 21 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/repull/models/reservation_created_event.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/repull/models/reservation_created_event.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/repull/models/reservation_created_event.rb', line 30 def self.attribute_map { :'id' => :'id', :'type' => :'type', :'created_at' => :'createdAt', :'api_version' => :'apiVersion', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/repull/models/reservation_created_event.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/repull/models/reservation_created_event.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/repull/models/reservation_created_event.rb', line 51 def self.openapi_types { :'id' => :'String', :'type' => :'String', :'created_at' => :'Time', :'api_version' => :'String', :'data' => :'ReservationCreatedPayload' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
155 156 157 158 159 160 161 162 163 |
# File 'lib/repull/models/reservation_created_event.rb', line 155 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && type == o.type && created_at == o.created_at && api_version == o.api_version && data == o.data end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/repull/models/reservation_created_event.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/repull/models/reservation_created_event.rb', line 173 def hash [id, type, created_at, api_version, data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/repull/models/reservation_created_event.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @data.nil? invalid_properties.push('invalid value for "data", data cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/repull/models/reservation_created_event.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
126 127 128 129 130 131 |
# File 'lib/repull/models/reservation_created_event.rb', line 126 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? return false if @data.nil? true end |