Class: Repull::ReviewResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ReviewResponse
- Defined in:
- lib/repull/models/review_response.rb
Overview
Host response to a review, when present.
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#submitted_at ⇒ Object
Returns the value of attribute submitted_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReviewResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReviewResponse
Initializes the object
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/repull/models/review_response.rb', line 58 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ReviewResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ReviewResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'body') self.body = attributes[:'body'] end if attributes.key?(:'submitted_at') self.submitted_at = attributes[:'submitted_at'] end end |
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body.
19 20 21 |
# File 'lib/repull/models/review_response.rb', line 19 def body @body end |
#submitted_at ⇒ Object
Returns the value of attribute submitted_at.
21 22 23 |
# File 'lib/repull/models/review_response.rb', line 21 def submitted_at @submitted_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/repull/models/review_response.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/repull/models/review_response.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/repull/models/review_response.rb', line 24 def self.attribute_map { :'body' => :'body', :'submitted_at' => :'submittedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/repull/models/review_response.rb', line 120 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 54 |
# File 'lib/repull/models/review_response.rb', line 50 def self.openapi_nullable Set.new([ :'submitted_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/repull/models/review_response.rb', line 42 def self.openapi_types { :'body' => :'String', :'submitted_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
98 99 100 101 102 103 |
# File 'lib/repull/models/review_response.rb', line 98 def ==(o) return true if self.equal?(o) self.class == o.class && body == o.body && submitted_at == o.submitted_at end |
#eql?(o) ⇒ Boolean
107 108 109 |
# File 'lib/repull/models/review_response.rb', line 107 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
113 114 115 |
# File 'lib/repull/models/review_response.rb', line 113 def hash [body, submitted_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
83 84 85 86 87 |
# File 'lib/repull/models/review_response.rb', line 83 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/repull/models/review_response.rb', line 142 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
91 92 93 94 |
# File 'lib/repull/models/review_response.rb', line 91 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |