Class: Repull::SandboxSeedResult

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/sandbox_seed_result.rb

Overview

Result of provisioning the sandbox fixture set.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SandboxSeedResult

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/repull/models/sandbox_seed_result.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::SandboxSeedResult` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::SandboxSeedResult`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  else
    self.customer_id = nil
  end

  if attributes.key?(:'seeded_at')
    self.seeded_at = attributes[:'seeded_at']
  else
    self.seeded_at = nil
  end

  if attributes.key?(:'listings')
    if (value = attributes[:'listings']).is_a?(Array)
      self.listings = value
    end
  else
    self.listings = nil
  end

  if attributes.key?(:'reservations')
    if (value = attributes[:'reservations']).is_a?(Array)
      self.reservations = value
    end
  else
    self.reservations = nil
  end

  if attributes.key?(:'connections')
    if (value = attributes[:'connections']).is_a?(Array)
      self.connections = value
    end
  else
    self.connections = nil
  end
end

Instance Attribute Details

#connectionsObject

2 fake connected provider accounts: Airbnb + Booking.com.



30
31
32
# File 'lib/repull/models/sandbox_seed_result.rb', line 30

def connections
  @connections
end

#customer_idObject

Returns the value of attribute customer_id.



19
20
21
# File 'lib/repull/models/sandbox_seed_result.rb', line 19

def customer_id
  @customer_id
end

#listingsObject

3 sample listings.



24
25
26
# File 'lib/repull/models/sandbox_seed_result.rb', line 24

def listings
  @listings
end

#reservationsObject

5 reservations across the lifecycle: created, modified, cancelled, date-changed, pending.



27
28
29
# File 'lib/repull/models/sandbox_seed_result.rb', line 27

def reservations
  @reservations
end

#seeded_atObject

Returns the value of attribute seeded_at.



21
22
23
# File 'lib/repull/models/sandbox_seed_result.rb', line 21

def seeded_at
  @seeded_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/repull/models/sandbox_seed_result.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/repull/models/sandbox_seed_result.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/repull/models/sandbox_seed_result.rb', line 33

def self.attribute_map
  {
    :'customer_id' => :'customerId',
    :'seeded_at' => :'seededAt',
    :'listings' => :'listings',
    :'reservations' => :'reservations',
    :'connections' => :'connections'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/repull/models/sandbox_seed_result.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/repull/models/sandbox_seed_result.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/repull/models/sandbox_seed_result.rb', line 54

def self.openapi_types
  {
    :'customer_id' => :'String',
    :'seeded_at' => :'Time',
    :'listings' => :'Array<SandboxFixtureRef>',
    :'reservations' => :'Array<SandboxFixtureRef>',
    :'connections' => :'Array<SandboxFixtureRef>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



215
216
217
218
219
220
221
222
223
# File 'lib/repull/models/sandbox_seed_result.rb', line 215

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      customer_id == o.customer_id &&
      seeded_at == o.seeded_at &&
      listings == o.listings &&
      reservations == o.reservations &&
      connections == o.connections
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/repull/models/sandbox_seed_result.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/repull/models/sandbox_seed_result.rb', line 233

def hash
  [customer_id, seeded_at, listings, reservations, connections].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/repull/models/sandbox_seed_result.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @customer_id.nil?
    invalid_properties.push('invalid value for "customer_id", customer_id cannot be nil.')
  end

  if @seeded_at.nil?
    invalid_properties.push('invalid value for "seeded_at", seeded_at cannot be nil.')
  end

  if @listings.nil?
    invalid_properties.push('invalid value for "listings", listings cannot be nil.')
  end

  if @reservations.nil?
    invalid_properties.push('invalid value for "reservations", reservations cannot be nil.')
  end

  if @connections.nil?
    invalid_properties.push('invalid value for "connections", connections cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/repull/models/sandbox_seed_result.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
157
158
159
160
161
# File 'lib/repull/models/sandbox_seed_result.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @customer_id.nil?
  return false if @seeded_at.nil?
  return false if @listings.nil?
  return false if @reservations.nil?
  return false if @connections.nil?
  true
end