Class: Repull::SchemaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/repull/api/schema_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SchemaApi

Returns a new instance of SchemaApi.



19
20
21
# File 'lib/repull/api/schema_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/repull/api/schema_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_custom_schema(custom_schema_create, opts = {}) ⇒ CustomSchemaCreateResponse

Create a custom schema Create a workspace-scoped field-mapping schema. The schema reshapes the ‘native` response payload into your app’s preferred field names. After creation, set ‘X-Schema: <name>` on any read endpoint to apply it. **Reserved names:** `calry`, `calry-v1`, `native` are built-in schemas and cannot be used as a custom name. **Mapping safety:** Each mapping value is parsed by an internal expression engine — `eval`, `Function`, `process`, and other unsafe keywords are rejected up front. Field names are capped at 100 chars and expressions at 500 chars.

Parameters:

  • custom_schema_create (CustomSchemaCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/repull/api/schema_api.rb', line 27

def create_custom_schema(custom_schema_create, opts = {})
  data, _status_code, _headers = create_custom_schema_with_http_info(custom_schema_create, opts)
  data
end

#create_custom_schema_with_http_info(custom_schema_create, opts = {}) ⇒ Array<(CustomSchemaCreateResponse, Integer, Hash)>

Create a custom schema Create a workspace-scoped field-mapping schema. The schema reshapes the &#x60;native&#x60; response payload into your app&#39;s preferred field names. After creation, set &#x60;X-Schema: &lt;name&gt;&#x60; on any read endpoint to apply it. **Reserved names:** &#x60;calry&#x60;, &#x60;calry-v1&#x60;, &#x60;native&#x60; are built-in schemas and cannot be used as a custom name. **Mapping safety:** Each mapping value is parsed by an internal expression engine — &#x60;eval&#x60;, &#x60;Function&#x60;, &#x60;process&#x60;, and other unsafe keywords are rejected up front. Field names are capped at 100 chars and expressions at 500 chars.

Parameters:

  • custom_schema_create (CustomSchemaCreate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomSchemaCreateResponse, Integer, Hash)>)

    CustomSchemaCreateResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/repull/api/schema_api.rb', line 37

def create_custom_schema_with_http_info(custom_schema_create, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SchemaApi.create_custom_schema ...'
  end
  # verify the required parameter 'custom_schema_create' is set
  if @api_client.config.client_side_validation && custom_schema_create.nil?
    fail ArgumentError, "Missing the required parameter 'custom_schema_create' when calling SchemaApi.create_custom_schema"
  end
  # resource path
  local_var_path = '/v1/schema/custom'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(custom_schema_create)

  # return_type
  return_type = opts[:debug_return_type] || 'CustomSchemaCreateResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"SchemaApi.create_custom_schema",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SchemaApi#create_custom_schema\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_custom_schema(id, opts = {}) ⇒ CustomSchemaDeleteResponse

Delete a custom schema Hard-delete a custom schema. Subsequent requests carrying its name in ‘X-Schema` fall back to `native`. There is no undelete.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



95
96
97
98
# File 'lib/repull/api/schema_api.rb', line 95

def delete_custom_schema(id, opts = {})
  data, _status_code, _headers = delete_custom_schema_with_http_info(id, opts)
  data
end

#delete_custom_schema_with_http_info(id, opts = {}) ⇒ Array<(CustomSchemaDeleteResponse, Integer, Hash)>

Delete a custom schema Hard-delete a custom schema. Subsequent requests carrying its name in &#x60;X-Schema&#x60; fall back to &#x60;native&#x60;. There is no undelete.

Parameters:

  • id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomSchemaDeleteResponse, Integer, Hash)>)

    CustomSchemaDeleteResponse data, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/repull/api/schema_api.rb', line 105

def delete_custom_schema_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SchemaApi.delete_custom_schema ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SchemaApi.delete_custom_schema"
  end
  # resource path
  local_var_path = '/v1/schema/custom/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CustomSchemaDeleteResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"SchemaApi.delete_custom_schema",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SchemaApi#delete_custom_schema\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_custom_schema(id, opts = {}) ⇒ CustomSchema

Get a custom schema Fetch a single custom schema by id. Scoped to the authenticated workspace — schemas that belong to other workspaces return 404.

Parameters:

  • id (String)

    Custom schema id.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



158
159
160
161
# File 'lib/repull/api/schema_api.rb', line 158

def get_custom_schema(id, opts = {})
  data, _status_code, _headers = get_custom_schema_with_http_info(id, opts)
  data
end

#get_custom_schema_with_http_info(id, opts = {}) ⇒ Array<(CustomSchema, Integer, Hash)>

Get a custom schema Fetch a single custom schema by id. Scoped to the authenticated workspace — schemas that belong to other workspaces return 404.

Parameters:

  • id (String)

    Custom schema id.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomSchema, Integer, Hash)>)

    CustomSchema data, response status code and response headers



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/repull/api/schema_api.rb', line 168

def get_custom_schema_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SchemaApi.get_custom_schema ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SchemaApi.get_custom_schema"
  end
  # resource path
  local_var_path = '/v1/schema/custom/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CustomSchema'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"SchemaApi.get_custom_schema",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SchemaApi#get_custom_schema\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_custom_schemas(opts = {}) ⇒ CustomSchemaListResponse

List custom schemas Returns every custom schema owned by the workspace, including inactive ones.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



220
221
222
223
# File 'lib/repull/api/schema_api.rb', line 220

def list_custom_schemas(opts = {})
  data, _status_code, _headers = list_custom_schemas_with_http_info(opts)
  data
end

#list_custom_schemas_with_http_info(opts = {}) ⇒ Array<(CustomSchemaListResponse, Integer, Hash)>

List custom schemas Returns every custom schema owned by the workspace, including inactive ones.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomSchemaListResponse, Integer, Hash)>)

    CustomSchemaListResponse data, response status code and response headers



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/repull/api/schema_api.rb', line 229

def list_custom_schemas_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SchemaApi.list_custom_schemas ...'
  end
  # resource path
  local_var_path = '/v1/schema/custom'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CustomSchemaListResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"SchemaApi.list_custom_schemas",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SchemaApi#list_custom_schemas\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#update_custom_schema(id, custom_schema_update, opts = {}) ⇒ CustomSchema

Update a custom schema Patch the description, mappings, or active flag of a custom schema. The schema ‘name` is immutable — create a new schema and migrate consumers if you need to rename. Mapping updates are revalidated for safety.

Parameters:

  • id (String)
  • custom_schema_update (CustomSchemaUpdate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



279
280
281
282
# File 'lib/repull/api/schema_api.rb', line 279

def update_custom_schema(id, custom_schema_update, opts = {})
  data, _status_code, _headers = update_custom_schema_with_http_info(id, custom_schema_update, opts)
  data
end

#update_custom_schema_with_http_info(id, custom_schema_update, opts = {}) ⇒ Array<(CustomSchema, Integer, Hash)>

Update a custom schema Patch the description, mappings, or active flag of a custom schema. The schema &#x60;name&#x60; is immutable — create a new schema and migrate consumers if you need to rename. Mapping updates are revalidated for safety.

Parameters:

  • id (String)
  • custom_schema_update (CustomSchemaUpdate)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CustomSchema, Integer, Hash)>)

    CustomSchema data, response status code and response headers



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/repull/api/schema_api.rb', line 290

def update_custom_schema_with_http_info(id, custom_schema_update, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SchemaApi.update_custom_schema ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling SchemaApi.update_custom_schema"
  end
  # verify the required parameter 'custom_schema_update' is set
  if @api_client.config.client_side_validation && custom_schema_update.nil?
    fail ArgumentError, "Missing the required parameter 'custom_schema_update' when calling SchemaApi.update_custom_schema"
  end
  # resource path
  local_var_path = '/v1/schema/custom/{id}'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(custom_schema_update)

  # return_type
  return_type = opts[:debug_return_type] || 'CustomSchema'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearerAuth']

  new_options = opts.merge(
    :operation => :"SchemaApi.update_custom_schema",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SchemaApi#update_custom_schema\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end