Class: Repull::StudioDeployment

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/studio_deployment.rb

Overview

A deployed instance of a Studio project, served from a ‘*.studio.repull.dev` subdomain.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StudioDeployment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/repull/models/studio_deployment.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::StudioDeployment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::StudioDeployment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'deployment_id')
    self.deployment_id = attributes[:'deployment_id']
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  end

  if attributes.key?(:'subdomain')
    self.subdomain = attributes[:'subdomain']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'suspended_at')
    self.suspended_at = attributes[:'suspended_at']
  end
end

Instance Attribute Details

#created_atObject

Returns the value of attribute created_at.



32
33
34
# File 'lib/repull/models/studio_deployment.rb', line 32

def created_at
  @created_at
end

#deployment_idObject

Returns the value of attribute deployment_id.



19
20
21
# File 'lib/repull/models/studio_deployment.rb', line 19

def deployment_id
  @deployment_id
end

#project_idObject

Returns the value of attribute project_id.



21
22
23
# File 'lib/repull/models/studio_deployment.rb', line 21

def project_id
  @project_id
end

#statusObject

Current deployment lifecycle status.



27
28
29
# File 'lib/repull/models/studio_deployment.rb', line 27

def status
  @status
end

#subdomainObject

Subdomain assigned to this deployment (e.g. ‘my-app-a1b2c3`).



24
25
26
# File 'lib/repull/models/studio_deployment.rb', line 24

def subdomain
  @subdomain
end

#suspended_atObject

Set when the deployment is paused via ‘/suspend`.



35
36
37
# File 'lib/repull/models/studio_deployment.rb', line 35

def suspended_at
  @suspended_at
end

#urlObject

Fully-qualified URL where the deployment is reachable when ‘status` is `live`.



30
31
32
# File 'lib/repull/models/studio_deployment.rb', line 30

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/repull/models/studio_deployment.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/repull/models/studio_deployment.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/repull/models/studio_deployment.rb', line 38

def self.attribute_map
  {
    :'deployment_id' => :'deployment_id',
    :'project_id' => :'project_id',
    :'subdomain' => :'subdomain',
    :'status' => :'status',
    :'url' => :'url',
    :'created_at' => :'created_at',
    :'suspended_at' => :'suspended_at'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/repull/models/studio_deployment.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
78
# File 'lib/repull/models/studio_deployment.rb', line 74

def self.openapi_nullable
  Set.new([
    :'suspended_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/repull/models/studio_deployment.rb', line 61

def self.openapi_types
  {
    :'deployment_id' => :'String',
    :'project_id' => :'String',
    :'subdomain' => :'String',
    :'status' => :'String',
    :'url' => :'String',
    :'created_at' => :'Time',
    :'suspended_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/repull/models/studio_deployment.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      deployment_id == o.deployment_id &&
      project_id == o.project_id &&
      subdomain == o.subdomain &&
      status == o.status &&
      url == o.url &&
      created_at == o.created_at &&
      suspended_at == o.suspended_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/repull/models/studio_deployment.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/repull/models/studio_deployment.rb', line 162

def hash
  [deployment_id, project_id, subdomain, status, url, created_at, suspended_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/repull/models/studio_deployment.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/repull/models/studio_deployment.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/repull/models/studio_deployment.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end