Class: Repull::AirbnbApi
- Inherits:
-
Object
- Object
- Repull::AirbnbApi
- Defined in:
- lib/repull/api/airbnb_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#airbnb_listing_action(id, opts = {}) ⇒ nil
Listing action (push/publish/unlist/delete) Apply a state action to an Airbnb listing — ‘push` (sync local changes upstream), `publish` (make publicly bookable), `unlist` (hide), or `delete` (permanent).
-
#airbnb_listing_action_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Listing action (push/publish/unlist/delete) Apply a state action to an Airbnb listing — `push` (sync local changes upstream), `publish` (make publicly bookable), `unlist` (hide), or `delete` (permanent).
-
#airbnb_reservation_action(code, opts = {}) ⇒ nil
Accept/decline/cancel Airbnb reservation Apply a state action to an Airbnb reservation — ‘accept` / `decline` (for inquiries and reservation requests), `cancel` (host cancellation, carries penalties), `pre-approve` (for inquiries).
-
#airbnb_reservation_action_with_http_info(code, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Accept/decline/cancel Airbnb reservation Apply a state action to an Airbnb reservation — `accept` / `decline` (for inquiries and reservation requests), `cancel` (host cancellation, carries penalties), `pre-approve` (for inquiries).
-
#create_airbnb_listing(opts = {}) ⇒ AirbnbListing
Create/push Airbnb listing Create a new Airbnb listing or push an existing Repull listing to Airbnb.
-
#create_airbnb_listing_with_http_info(opts = {}) ⇒ Array<(AirbnbListing, Integer, Hash)>
Create/push Airbnb listing Create a new Airbnb listing or push an existing Repull listing to Airbnb.
-
#get_airbnb_listing(id, opts = {}) ⇒ AirbnbListing
Get Airbnb listing Fetch a single Airbnb listing by id with full pricing, availability, and content.
-
#get_airbnb_listing_availability(id, opts = {}) ⇒ nil
Get Airbnb availability Read the per-day availability calendar for an Airbnb listing.
-
#get_airbnb_listing_availability_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Airbnb availability Read the per-day availability calendar for an Airbnb listing.
-
#get_airbnb_listing_pricing(id, opts = {}) ⇒ nil
Get Airbnb pricing Read the current pricing config (base price, weekend uplift, length-of-stay discounts, smart-pricing bounds) for an Airbnb listing.
-
#get_airbnb_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Airbnb pricing Read the current pricing config (base price, weekend uplift, length-of-stay discounts, smart-pricing bounds) for an Airbnb listing.
-
#get_airbnb_listing_with_http_info(id, opts = {}) ⇒ Array<(AirbnbListing, Integer, Hash)>
Get Airbnb listing Fetch a single Airbnb listing by id with full pricing, availability, and content.
-
#get_airbnb_reservation(code, opts = {}) ⇒ AirbnbReservation
Get Airbnb reservation Fetch a single Airbnb reservation by Airbnb confirmation code (e.g. ‘HMABCDEF12`).
-
#get_airbnb_reservation_with_http_info(code, opts = {}) ⇒ Array<(AirbnbReservation, Integer, Hash)>
Get Airbnb reservation Fetch a single Airbnb reservation by Airbnb confirmation code (e.g. `HMABCDEF12`).
-
#initialize(api_client = ApiClient.default) ⇒ AirbnbApi
constructor
A new instance of AirbnbApi.
-
#list_airbnb_listing_photos(id, opts = {}) ⇒ nil
List Airbnb photos List photos attached to an Airbnb listing in display order.
-
#list_airbnb_listing_photos_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
List Airbnb photos List photos attached to an Airbnb listing in display order.
-
#list_airbnb_listings(opts = {}) ⇒ AirbnbListingListResponse
List Airbnb listings List every Airbnb listing this workspace has access to via the connected Airbnb account.
-
#list_airbnb_listings_with_http_info(opts = {}) ⇒ Array<(AirbnbListingListResponse, Integer, Hash)>
List Airbnb listings List every Airbnb listing this workspace has access to via the connected Airbnb account.
-
#list_airbnb_reservations(opts = {}) ⇒ AirbnbReservationListResponse
List Airbnb reservations List reservations sourced directly from Airbnb.
-
#list_airbnb_reservations_with_http_info(opts = {}) ⇒ Array<(AirbnbReservationListResponse, Integer, Hash)>
List Airbnb reservations List reservations sourced directly from Airbnb.
-
#list_airbnb_reviews(opts = {}) ⇒ AirbnbReviewListResponse
List Airbnb reviews List reviews left by guests on Airbnb listings in this workspace.
-
#list_airbnb_reviews_with_http_info(opts = {}) ⇒ Array<(AirbnbReviewListResponse, Integer, Hash)>
List Airbnb reviews List reviews left by guests on Airbnb listings in this workspace.
-
#list_airbnb_thread_messages(thread_id, opts = {}) ⇒ MessageListResponse
Get Airbnb messages Fetch the full message log for an Airbnb thread, ordered oldest-to-newest.
-
#list_airbnb_thread_messages_with_http_info(thread_id, opts = {}) ⇒ Array<(MessageListResponse, Integer, Hash)>
Get Airbnb messages Fetch the full message log for an Airbnb thread, ordered oldest-to-newest.
-
#list_airbnb_threads(opts = {}) ⇒ AirbnbThreadListResponse
List Airbnb message threads List Airbnb message threads (one per guest conversation).
-
#list_airbnb_threads_with_http_info(opts = {}) ⇒ Array<(AirbnbThreadListResponse, Integer, Hash)>
List Airbnb message threads List Airbnb message threads (one per guest conversation).
-
#respond_airbnb_review(opts = {}) ⇒ nil
Respond to Airbnb review Post a public response to a guest review.
-
#respond_airbnb_review_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Respond to Airbnb review Post a public response to a guest review.
-
#send_airbnb_message(thread_id, opts = {}) ⇒ nil
Send Airbnb message Send a message in an Airbnb thread as the host.
-
#send_airbnb_message_with_http_info(thread_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send Airbnb message Send a message in an Airbnb thread as the host.
-
#sync_airbnb(opts = {}) ⇒ nil
Bulk sync to Airbnb Push all property data to Airbnb in one call.
-
#sync_airbnb_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Bulk sync to Airbnb Push all property data to Airbnb in one call.
-
#update_airbnb_listing_availability(id, opts = {}) ⇒ nil
Update Airbnb availability Push per-day availability + pricing overrides to Airbnb.
-
#update_airbnb_listing_availability_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Airbnb availability Push per-day availability + pricing overrides to Airbnb.
-
#update_airbnb_listing_pricing(id, opts = {}) ⇒ nil
Update Airbnb pricing Push pricing changes to Airbnb.
-
#update_airbnb_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Airbnb pricing Push pricing changes to Airbnb.
-
#upload_airbnb_listing_photos(id, opts = {}) ⇒ nil
Upload photos to Airbnb Upload one or more photos to an Airbnb listing.
-
#upload_airbnb_listing_photos_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload photos to Airbnb Upload one or more photos to an Airbnb listing.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/airbnb_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#airbnb_listing_action(id, opts = {}) ⇒ nil
Listing action (push/publish/unlist/delete) Apply a state action to an Airbnb listing — ‘push` (sync local changes upstream), `publish` (make publicly bookable), `unlist` (hide), or `delete` (permanent). Each action has different reversibility — see docs.
27 28 29 30 |
# File 'lib/repull/api/airbnb_api.rb', line 27 def airbnb_listing_action(id, opts = {}) airbnb_listing_action_with_http_info(id, opts) nil end |
#airbnb_listing_action_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Listing action (push/publish/unlist/delete) Apply a state action to an Airbnb listing — `push` (sync local changes upstream), `publish` (make publicly bookable), `unlist` (hide), or `delete` (permanent). Each action has different reversibility — see docs.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/repull/api/airbnb_api.rb', line 37 def airbnb_listing_action_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.airbnb_listing_action ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.airbnb_listing_action" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.airbnb_listing_action", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#airbnb_listing_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#airbnb_reservation_action(code, opts = {}) ⇒ nil
Accept/decline/cancel Airbnb reservation Apply a state action to an Airbnb reservation — ‘accept` / `decline` (for inquiries and reservation requests), `cancel` (host cancellation, carries penalties), `pre-approve` (for inquiries).
88 89 90 91 |
# File 'lib/repull/api/airbnb_api.rb', line 88 def airbnb_reservation_action(code, opts = {}) airbnb_reservation_action_with_http_info(code, opts) nil end |
#airbnb_reservation_action_with_http_info(code, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Accept/decline/cancel Airbnb reservation Apply a state action to an Airbnb reservation — `accept` / `decline` (for inquiries and reservation requests), `cancel` (host cancellation, carries penalties), `pre-approve` (for inquiries).
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/repull/api/airbnb_api.rb', line 98 def airbnb_reservation_action_with_http_info(code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.airbnb_reservation_action ...' end # verify the required parameter 'code' is set if @api_client.config.client_side_validation && code.nil? fail ArgumentError, "Missing the required parameter 'code' when calling AirbnbApi.airbnb_reservation_action" end # resource path local_var_path = '/v1/channels/airbnb/reservations/{code}'.sub('{code}', CGI.escape(code.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.airbnb_reservation_action", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#airbnb_reservation_action\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_airbnb_listing(opts = {}) ⇒ AirbnbListing
Create/push Airbnb listing Create a new Airbnb listing or push an existing Repull listing to Airbnb. Requires a connected Airbnb account. Returns the created listing id; publishing happens via the listing-action endpoint.
148 149 150 151 |
# File 'lib/repull/api/airbnb_api.rb', line 148 def create_airbnb_listing(opts = {}) data, _status_code, _headers = create_airbnb_listing_with_http_info(opts) data end |
#create_airbnb_listing_with_http_info(opts = {}) ⇒ Array<(AirbnbListing, Integer, Hash)>
Create/push Airbnb listing Create a new Airbnb listing or push an existing Repull listing to Airbnb. Requires a connected Airbnb account. Returns the created listing id; publishing happens via the listing-action endpoint.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/repull/api/airbnb_api.rb', line 157 def create_airbnb_listing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.create_airbnb_listing ...' end # resource path local_var_path = '/v1/channels/airbnb/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbListing' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.create_airbnb_listing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#create_airbnb_listing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_airbnb_listing(id, opts = {}) ⇒ AirbnbListing
Get Airbnb listing Fetch a single Airbnb listing by id with full pricing, availability, and content. Listing ids are Airbnb-side ids (numeric strings).
206 207 208 209 |
# File 'lib/repull/api/airbnb_api.rb', line 206 def get_airbnb_listing(id, opts = {}) data, _status_code, _headers = get_airbnb_listing_with_http_info(id, opts) data end |
#get_airbnb_listing_availability(id, opts = {}) ⇒ nil
Get Airbnb availability Read the per-day availability calendar for an Airbnb listing. Returns one row per day including price overrides, min-stay, and blocked status.
269 270 271 272 |
# File 'lib/repull/api/airbnb_api.rb', line 269 def get_airbnb_listing_availability(id, opts = {}) get_airbnb_listing_availability_with_http_info(id, opts) nil end |
#get_airbnb_listing_availability_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Airbnb availability Read the per-day availability calendar for an Airbnb listing. Returns one row per day including price overrides, min-stay, and blocked status.
279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/repull/api/airbnb_api.rb', line 279 def get_airbnb_listing_availability_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.get_airbnb_listing_availability ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.get_airbnb_listing_availability" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/availability'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.get_airbnb_listing_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#get_airbnb_listing_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_airbnb_listing_pricing(id, opts = {}) ⇒ nil
Get Airbnb pricing Read the current pricing config (base price, weekend uplift, length-of-stay discounts, smart-pricing bounds) for an Airbnb listing.
330 331 332 333 |
# File 'lib/repull/api/airbnb_api.rb', line 330 def get_airbnb_listing_pricing(id, opts = {}) get_airbnb_listing_pricing_with_http_info(id, opts) nil end |
#get_airbnb_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Airbnb pricing Read the current pricing config (base price, weekend uplift, length-of-stay discounts, smart-pricing bounds) for an Airbnb listing.
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 |
# File 'lib/repull/api/airbnb_api.rb', line 340 def get_airbnb_listing_pricing_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.get_airbnb_listing_pricing ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.get_airbnb_listing_pricing" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/pricing'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.get_airbnb_listing_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#get_airbnb_listing_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_airbnb_listing_with_http_info(id, opts = {}) ⇒ Array<(AirbnbListing, Integer, Hash)>
Get Airbnb listing Fetch a single Airbnb listing by id with full pricing, availability, and content. Listing ids are Airbnb-side ids (numeric strings).
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/repull/api/airbnb_api.rb', line 216 def get_airbnb_listing_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.get_airbnb_listing ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.get_airbnb_listing" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbListing' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.get_airbnb_listing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#get_airbnb_listing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_airbnb_reservation(code, opts = {}) ⇒ AirbnbReservation
Get Airbnb reservation Fetch a single Airbnb reservation by Airbnb confirmation code (e.g. ‘HMABCDEF12`).
391 392 393 394 |
# File 'lib/repull/api/airbnb_api.rb', line 391 def get_airbnb_reservation(code, opts = {}) data, _status_code, _headers = get_airbnb_reservation_with_http_info(code, opts) data end |
#get_airbnb_reservation_with_http_info(code, opts = {}) ⇒ Array<(AirbnbReservation, Integer, Hash)>
Get Airbnb reservation Fetch a single Airbnb reservation by Airbnb confirmation code (e.g. `HMABCDEF12`).
401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/repull/api/airbnb_api.rb', line 401 def get_airbnb_reservation_with_http_info(code, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.get_airbnb_reservation ...' end # verify the required parameter 'code' is set if @api_client.config.client_side_validation && code.nil? fail ArgumentError, "Missing the required parameter 'code' when calling AirbnbApi.get_airbnb_reservation" end # resource path local_var_path = '/v1/channels/airbnb/reservations/{code}'.sub('{code}', CGI.escape(code.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbReservation' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.get_airbnb_reservation", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#get_airbnb_reservation\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_listing_photos(id, opts = {}) ⇒ nil
List Airbnb photos List photos attached to an Airbnb listing in display order. Returns the public CDN URL plus Airbnb-side metadata (id, caption, room).
454 455 456 457 |
# File 'lib/repull/api/airbnb_api.rb', line 454 def list_airbnb_listing_photos(id, opts = {}) list_airbnb_listing_photos_with_http_info(id, opts) nil end |
#list_airbnb_listing_photos_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
List Airbnb photos List photos attached to an Airbnb listing in display order. Returns the public CDN URL plus Airbnb-side metadata (id, caption, room).
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 |
# File 'lib/repull/api/airbnb_api.rb', line 464 def list_airbnb_listing_photos_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_listing_photos ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.list_airbnb_listing_photos" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/photos'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_listing_photos", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_listing_photos\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_listings(opts = {}) ⇒ AirbnbListingListResponse
List Airbnb listings List every Airbnb listing this workspace has access to via the connected Airbnb account. Sourced from the Airbnb Listing API. Listings sync automatically every few minutes — pass ‘?refresh=true` to force a fresh upstream pull.
514 515 516 517 |
# File 'lib/repull/api/airbnb_api.rb', line 514 def list_airbnb_listings(opts = {}) data, _status_code, _headers = list_airbnb_listings_with_http_info(opts) data end |
#list_airbnb_listings_with_http_info(opts = {}) ⇒ Array<(AirbnbListingListResponse, Integer, Hash)>
List Airbnb listings List every Airbnb listing this workspace has access to via the connected Airbnb account. Sourced from the Airbnb Listing API. Listings sync automatically every few minutes — pass `?refresh=true` to force a fresh upstream pull.
523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/repull/api/airbnb_api.rb', line 523 def list_airbnb_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_listings ...' end # resource path local_var_path = '/v1/channels/airbnb/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbListingListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_reservations(opts = {}) ⇒ AirbnbReservationListResponse
List Airbnb reservations List reservations sourced directly from Airbnb. Use this when you need Airbnb-specific fields (guest payout split, cancellation policy snapshot) that the unified ‘/v1/reservations` endpoint flattens away.
571 572 573 574 |
# File 'lib/repull/api/airbnb_api.rb', line 571 def list_airbnb_reservations(opts = {}) data, _status_code, _headers = list_airbnb_reservations_with_http_info(opts) data end |
#list_airbnb_reservations_with_http_info(opts = {}) ⇒ Array<(AirbnbReservationListResponse, Integer, Hash)>
List Airbnb reservations List reservations sourced directly from Airbnb. Use this when you need Airbnb-specific fields (guest payout split, cancellation policy snapshot) that the unified `/v1/reservations` endpoint flattens away.
580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 |
# File 'lib/repull/api/airbnb_api.rb', line 580 def list_airbnb_reservations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_reservations ...' end # resource path local_var_path = '/v1/channels/airbnb/reservations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbReservationListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_reservations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_reservations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_reviews(opts = {}) ⇒ AirbnbReviewListResponse
List Airbnb reviews List reviews left by guests on Airbnb listings in this workspace. Includes both reviews of the host and reviews of the guest (where the host has not yet submitted theirs).
628 629 630 631 |
# File 'lib/repull/api/airbnb_api.rb', line 628 def list_airbnb_reviews(opts = {}) data, _status_code, _headers = list_airbnb_reviews_with_http_info(opts) data end |
#list_airbnb_reviews_with_http_info(opts = {}) ⇒ Array<(AirbnbReviewListResponse, Integer, Hash)>
List Airbnb reviews List reviews left by guests on Airbnb listings in this workspace. Includes both reviews of the host and reviews of the guest (where the host has not yet submitted theirs).
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 |
# File 'lib/repull/api/airbnb_api.rb', line 637 def list_airbnb_reviews_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_reviews ...' end # resource path local_var_path = '/v1/channels/airbnb/reviews' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbReviewListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_reviews", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_reviews\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_thread_messages(thread_id, opts = {}) ⇒ MessageListResponse
Get Airbnb messages Fetch the full message log for an Airbnb thread, ordered oldest-to-newest. Walk pages with ‘?cursor=` until `pagination.hasMore` is `false`.
686 687 688 689 |
# File 'lib/repull/api/airbnb_api.rb', line 686 def (thread_id, opts = {}) data, _status_code, _headers = (thread_id, opts) data end |
#list_airbnb_thread_messages_with_http_info(thread_id, opts = {}) ⇒ Array<(MessageListResponse, Integer, Hash)>
Get Airbnb messages Fetch the full message log for an Airbnb thread, ordered oldest-to-newest. Walk pages with `?cursor=` until `pagination.hasMore` is `false`.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 |
# File 'lib/repull/api/airbnb_api.rb', line 696 def (thread_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_thread_messages ...' end # verify the required parameter 'thread_id' is set if @api_client.config.client_side_validation && thread_id.nil? fail ArgumentError, "Missing the required parameter 'thread_id' when calling AirbnbApi.list_airbnb_thread_messages" end # resource path local_var_path = '/v1/channels/airbnb/messaging/{threadId}/messages'.sub('{threadId}', CGI.escape(thread_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MessageListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_thread_messages", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_thread_messages\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_airbnb_threads(opts = {}) ⇒ AirbnbThreadListResponse
List Airbnb message threads List Airbnb message threads (one per guest conversation). Cursor-paginated. Each thread includes a preview of the latest message.
748 749 750 751 |
# File 'lib/repull/api/airbnb_api.rb', line 748 def list_airbnb_threads(opts = {}) data, _status_code, _headers = list_airbnb_threads_with_http_info(opts) data end |
#list_airbnb_threads_with_http_info(opts = {}) ⇒ Array<(AirbnbThreadListResponse, Integer, Hash)>
List Airbnb message threads List Airbnb message threads (one per guest conversation). Cursor-paginated. Each thread includes a preview of the latest message.
757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 |
# File 'lib/repull/api/airbnb_api.rb', line 757 def list_airbnb_threads_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.list_airbnb_threads ...' end # resource path local_var_path = '/v1/channels/airbnb/messaging' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AirbnbThreadListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.list_airbnb_threads", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#list_airbnb_threads\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#respond_airbnb_review(opts = {}) ⇒ nil
Respond to Airbnb review Post a public response to a guest review. Airbnb allows one response per review — repeated POSTs return 409.
805 806 807 808 |
# File 'lib/repull/api/airbnb_api.rb', line 805 def respond_airbnb_review(opts = {}) respond_airbnb_review_with_http_info(opts) nil end |
#respond_airbnb_review_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Respond to Airbnb review Post a public response to a guest review. Airbnb allows one response per review — repeated POSTs return 409.
814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 |
# File 'lib/repull/api/airbnb_api.rb', line 814 def respond_airbnb_review_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.respond_airbnb_review ...' end # resource path local_var_path = '/v1/channels/airbnb/reviews' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.respond_airbnb_review", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#respond_airbnb_review\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#send_airbnb_message(thread_id, opts = {}) ⇒ nil
Send Airbnb message Send a message in an Airbnb thread as the host. Airbnb enforces content rules (no off-platform contact info, no external URLs) — violating messages are rejected upstream and surface as ‘airbnb_error`.
861 862 863 864 |
# File 'lib/repull/api/airbnb_api.rb', line 861 def (thread_id, opts = {}) (thread_id, opts) nil end |
#send_airbnb_message_with_http_info(thread_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Send Airbnb message Send a message in an Airbnb thread as the host. Airbnb enforces content rules (no off-platform contact info, no external URLs) — violating messages are rejected upstream and surface as `airbnb_error`.
871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 |
# File 'lib/repull/api/airbnb_api.rb', line 871 def (thread_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.send_airbnb_message ...' end # verify the required parameter 'thread_id' is set if @api_client.config.client_side_validation && thread_id.nil? fail ArgumentError, "Missing the required parameter 'thread_id' when calling AirbnbApi.send_airbnb_message" end # resource path local_var_path = '/v1/channels/airbnb/messaging/{threadId}/messages'.sub('{threadId}', CGI.escape(thread_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.send_airbnb_message", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#send_airbnb_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync_airbnb(opts = {}) ⇒ nil
Bulk sync to Airbnb Push all property data to Airbnb in one call.
921 922 923 924 |
# File 'lib/repull/api/airbnb_api.rb', line 921 def sync_airbnb(opts = {}) sync_airbnb_with_http_info(opts) nil end |
#sync_airbnb_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Bulk sync to Airbnb Push all property data to Airbnb in one call.
930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 |
# File 'lib/repull/api/airbnb_api.rb', line 930 def sync_airbnb_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.sync_airbnb ...' end # resource path local_var_path = '/v1/channels/airbnb/sync' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.sync_airbnb", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#sync_airbnb\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_airbnb_listing_availability(id, opts = {}) ⇒ nil
Update Airbnb availability Push per-day availability + pricing overrides to Airbnb. Accepts a sparse map (date → fields) — only included dates are updated.
977 978 979 980 |
# File 'lib/repull/api/airbnb_api.rb', line 977 def update_airbnb_listing_availability(id, opts = {}) update_airbnb_listing_availability_with_http_info(id, opts) nil end |
#update_airbnb_listing_availability_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Airbnb availability Push per-day availability + pricing overrides to Airbnb. Accepts a sparse map (date → fields) — only included dates are updated.
987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 |
# File 'lib/repull/api/airbnb_api.rb', line 987 def update_airbnb_listing_availability_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.update_airbnb_listing_availability ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.update_airbnb_listing_availability" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/availability'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.update_airbnb_listing_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#update_airbnb_listing_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_airbnb_listing_pricing(id, opts = {}) ⇒ nil
Update Airbnb pricing Push pricing changes to Airbnb. The full pricing object is replaced — to patch a single field, GET first, mutate locally, then PUT the whole object.
1038 1039 1040 1041 |
# File 'lib/repull/api/airbnb_api.rb', line 1038 def update_airbnb_listing_pricing(id, opts = {}) update_airbnb_listing_pricing_with_http_info(id, opts) nil end |
#update_airbnb_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update Airbnb pricing Push pricing changes to Airbnb. The full pricing object is replaced — to patch a single field, GET first, mutate locally, then PUT the whole object.
1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 |
# File 'lib/repull/api/airbnb_api.rb', line 1048 def update_airbnb_listing_pricing_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.update_airbnb_listing_pricing ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.update_airbnb_listing_pricing" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/pricing'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.update_airbnb_listing_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#update_airbnb_listing_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#upload_airbnb_listing_photos(id, opts = {}) ⇒ nil
Upload photos to Airbnb Upload one or more photos to an Airbnb listing. Accepts public image URLs (Airbnb fetches them) — direct binary upload is not supported on this endpoint.
1099 1100 1101 1102 |
# File 'lib/repull/api/airbnb_api.rb', line 1099 def upload_airbnb_listing_photos(id, opts = {}) upload_airbnb_listing_photos_with_http_info(id, opts) nil end |
#upload_airbnb_listing_photos_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Upload photos to Airbnb Upload one or more photos to an Airbnb listing. Accepts public image URLs (Airbnb fetches them) — direct binary upload is not supported on this endpoint.
1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 1142 1143 1144 1145 1146 1147 1148 1149 1150 1151 1152 1153 |
# File 'lib/repull/api/airbnb_api.rb', line 1109 def upload_airbnb_listing_photos_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AirbnbApi.upload_airbnb_listing_photos ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AirbnbApi.upload_airbnb_listing_photos" end # resource path local_var_path = '/v1/channels/airbnb/listings/{id}/photos'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AirbnbApi.upload_airbnb_listing_photos", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AirbnbApi#upload_airbnb_listing_photos\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |