Class: Repull::AirbnbReview
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::AirbnbReview
- Defined in:
- lib/repull/models/airbnb_review.rb
Overview
An Airbnb review (guest → host or host → guest).
Instance Attribute Summary collapse
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#rating ⇒ Object
Returns the value of attribute rating.
-
#reservation_code ⇒ Object
Returns the value of attribute reservation_code.
-
#response ⇒ Object
Returns the value of attribute response.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AirbnbReview
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AirbnbReview
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/repull/models/airbnb_review.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::AirbnbReview` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::AirbnbReview`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'reservation_code') self.reservation_code = attributes[:'reservation_code'] end if attributes.key?(:'rating') self. = attributes[:'rating'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#comment ⇒ Object
Returns the value of attribute comment.
25 26 27 |
# File 'lib/repull/models/airbnb_review.rb', line 25 def comment @comment end |
#created_at ⇒ Object
Returns the value of attribute created_at.
29 30 31 |
# File 'lib/repull/models/airbnb_review.rb', line 29 def created_at @created_at end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/repull/models/airbnb_review.rb', line 19 def id @id end |
#rating ⇒ Object
Returns the value of attribute rating.
23 24 25 |
# File 'lib/repull/models/airbnb_review.rb', line 23 def @rating end |
#reservation_code ⇒ Object
Returns the value of attribute reservation_code.
21 22 23 |
# File 'lib/repull/models/airbnb_review.rb', line 21 def reservation_code @reservation_code end |
#response ⇒ Object
Returns the value of attribute response.
27 28 29 |
# File 'lib/repull/models/airbnb_review.rb', line 27 def response @response end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/repull/models/airbnb_review.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/repull/models/airbnb_review.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 41 |
# File 'lib/repull/models/airbnb_review.rb', line 32 def self.attribute_map { :'id' => :'id', :'reservation_code' => :'reservationCode', :'rating' => :'rating', :'comment' => :'comment', :'response' => :'response', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/repull/models/airbnb_review.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 71 72 73 74 |
# File 'lib/repull/models/airbnb_review.rb', line 66 def self.openapi_nullable Set.new([ :'reservation_code', :'rating', :'comment', :'response', :'created_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 63 |
# File 'lib/repull/models/airbnb_review.rb', line 54 def self.openapi_types { :'id' => :'String', :'reservation_code' => :'String', :'rating' => :'Integer', :'comment' => :'String', :'response' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/repull/models/airbnb_review.rb', line 158 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && reservation_code == o.reservation_code && == o. && comment == o.comment && response == o.response && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/repull/models/airbnb_review.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/repull/models/airbnb_review.rb', line 177 def hash [id, reservation_code, , comment, response, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/repull/models/airbnb_review.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@rating.nil? && @rating > 5 invalid_properties.push('invalid value for "rating", must be smaller than or equal to 5.') end if !@rating.nil? && @rating < 1 invalid_properties.push('invalid value for "rating", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/repull/models/airbnb_review.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 |
# File 'lib/repull/models/airbnb_review.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@rating.nil? && @rating > 5 return false if !@rating.nil? && @rating < 1 true end |