Class: Repull::AvailabilityApi
- Inherits:
-
Object
- Object
- Repull::AvailabilityApi
- Defined in:
- lib/repull/api/availability_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_availability(property_id, start_date, end_date, opts = {}) ⇒ CalendarResponse
Get availability calendar Returns day-by-day availability, pricing, and minimum stay for a property.
-
#get_availability_with_http_info(property_id, start_date, end_date, opts = {}) ⇒ Array<(CalendarResponse, Integer, Hash)>
Get availability calendar Returns day-by-day availability, pricing, and minimum stay for a property.
-
#initialize(api_client = ApiClient.default) ⇒ AvailabilityApi
constructor
A new instance of AvailabilityApi.
-
#update_availability(property_id, opts = {}) ⇒ nil
Update availability Update pricing, availability, and minimum stay for specific dates.
-
#update_availability_with_http_info(property_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update availability Update pricing, availability, and minimum stay for specific dates.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AvailabilityApi
Returns a new instance of AvailabilityApi.
19 20 21 |
# File 'lib/repull/api/availability_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/availability_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_availability(property_id, start_date, end_date, opts = {}) ⇒ CalendarResponse
Get availability calendar Returns day-by-day availability, pricing, and minimum stay for a property.
29 30 31 32 |
# File 'lib/repull/api/availability_api.rb', line 29 def get_availability(property_id, start_date, end_date, opts = {}) data, _status_code, _headers = get_availability_with_http_info(property_id, start_date, end_date, opts) data end |
#get_availability_with_http_info(property_id, start_date, end_date, opts = {}) ⇒ Array<(CalendarResponse, Integer, Hash)>
Get availability calendar Returns day-by-day availability, pricing, and minimum stay for a property.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/repull/api/availability_api.rb', line 41 def get_availability_with_http_info(property_id, start_date, end_date, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AvailabilityApi.get_availability ...' end # verify the required parameter 'property_id' is set if @api_client.config.client_side_validation && property_id.nil? fail ArgumentError, "Missing the required parameter 'property_id' when calling AvailabilityApi.get_availability" end # verify the required parameter 'start_date' is set if @api_client.config.client_side_validation && start_date.nil? fail ArgumentError, "Missing the required parameter 'start_date' when calling AvailabilityApi.get_availability" end # verify the required parameter 'end_date' is set if @api_client.config.client_side_validation && end_date.nil? fail ArgumentError, "Missing the required parameter 'end_date' when calling AvailabilityApi.get_availability" end # resource path local_var_path = '/v1/availability/{propertyId}'.sub('{propertyId}', CGI.escape(property_id.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'startDate'] = start_date query_params[:'endDate'] = end_date # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CalendarResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AvailabilityApi.get_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AvailabilityApi#get_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_availability(property_id, opts = {}) ⇒ nil
Update availability Update pricing, availability, and minimum stay for specific dates.
105 106 107 108 |
# File 'lib/repull/api/availability_api.rb', line 105 def update_availability(property_id, opts = {}) update_availability_with_http_info(property_id, opts) nil end |
#update_availability_with_http_info(property_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update availability Update pricing, availability, and minimum stay for specific dates.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/repull/api/availability_api.rb', line 116 def update_availability_with_http_info(property_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AvailabilityApi.update_availability ...' end # verify the required parameter 'property_id' is set if @api_client.config.client_side_validation && property_id.nil? fail ArgumentError, "Missing the required parameter 'property_id' when calling AvailabilityApi.update_availability" end # resource path local_var_path = '/v1/availability/{propertyId}'.sub('{propertyId}', CGI.escape(property_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'update_availability_request']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"AvailabilityApi.update_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AvailabilityApi#update_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |