Class: Repull::BillingApi
- Inherits:
-
Object
- Object
- Repull::BillingApi
- Defined in:
- lib/repull/api/billing_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_billing_checkout(opts = {}) ⇒ nil
Create checkout session Redirect user to Stripe checkout.
-
#create_billing_checkout_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create checkout session Redirect user to Stripe checkout.
-
#get_billing(opts = {}) ⇒ nil
Get plan and usage Fetch the current plan, usage counters, and billing-cycle reset date for this workspace.
-
#get_billing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get plan and usage Fetch the current plan, usage counters, and billing-cycle reset date for this workspace.
-
#initialize(api_client = ApiClient.default) ⇒ BillingApi
constructor
A new instance of BillingApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ BillingApi
Returns a new instance of BillingApi.
19 20 21 |
# File 'lib/repull/api/billing_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/billing_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_billing_checkout(opts = {}) ⇒ nil
Create checkout session Redirect user to Stripe checkout.
27 28 29 30 |
# File 'lib/repull/api/billing_api.rb', line 27 def create_billing_checkout(opts = {}) create_billing_checkout_with_http_info(opts) nil end |
#create_billing_checkout_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create checkout session Redirect user to Stripe checkout.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/repull/api/billing_api.rb', line 37 def create_billing_checkout_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingApi.create_billing_checkout ...' end # resource path local_var_path = '/v1/billing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_billing_checkout_request']) # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"BillingApi.create_billing_checkout", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingApi#create_billing_checkout\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_billing(opts = {}) ⇒ nil
Get plan and usage Fetch the current plan, usage counters, and billing-cycle reset date for this workspace. Use this to surface a "you have used X / Y" indicator in your dashboard.
88 89 90 91 |
# File 'lib/repull/api/billing_api.rb', line 88 def get_billing(opts = {}) get_billing_with_http_info(opts) nil end |
#get_billing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get plan and usage Fetch the current plan, usage counters, and billing-cycle reset date for this workspace. Use this to surface a "you have used X / Y" indicator in your dashboard.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/repull/api/billing_api.rb', line 97 def get_billing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: BillingApi.get_billing ...' end # resource path local_var_path = '/v1/billing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"BillingApi.get_billing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: BillingApi#get_billing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |