Class: Repull::CreateConnectionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::CreateConnectionRequest
- Defined in:
- lib/repull/models/create_connection_request.rb
Overview
Provider-specific credentials (apiKey, clientId/clientSecret, etc.) or OAuth init params for Airbnb.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#access_type ⇒ Object
Airbnb only — selects the OAuth scope set.
-
#api_key ⇒ Object
PMS providers — API key.
-
#client_id ⇒ Object
Plumguide — client ID.
-
#client_secret ⇒ Object
Plumguide — client secret.
-
#redirect_url ⇒ Object
Airbnb only — where to redirect the user after the OAuth flow completes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateConnectionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateConnectionRequest
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/repull/models/create_connection_request.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::CreateConnectionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::CreateConnectionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'access_type') self.access_type = attributes[:'access_type'] else self.access_type = 'full_access' end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'client_secret') self.client_secret = attributes[:'client_secret'] end end |
Instance Attribute Details
#access_type ⇒ Object
Airbnb only — selects the OAuth scope set. ‘read_only’ grants calendar-only access; ‘full_access’ grants full host scopes (default).
23 24 25 |
# File 'lib/repull/models/create_connection_request.rb', line 23 def access_type @access_type end |
#api_key ⇒ Object
PMS providers — API key.
26 27 28 |
# File 'lib/repull/models/create_connection_request.rb', line 26 def api_key @api_key end |
#client_id ⇒ Object
Plumguide — client ID.
29 30 31 |
# File 'lib/repull/models/create_connection_request.rb', line 29 def client_id @client_id end |
#client_secret ⇒ Object
Plumguide — client secret.
32 33 34 |
# File 'lib/repull/models/create_connection_request.rb', line 32 def client_secret @client_secret end |
#redirect_url ⇒ Object
Airbnb only — where to redirect the user after the OAuth flow completes.
20 21 22 |
# File 'lib/repull/models/create_connection_request.rb', line 20 def redirect_url @redirect_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/repull/models/create_connection_request.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/repull/models/create_connection_request.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/repull/models/create_connection_request.rb', line 57 def self.attribute_map { :'redirect_url' => :'redirectUrl', :'access_type' => :'accessType', :'api_key' => :'apiKey', :'client_id' => :'clientId', :'client_secret' => :'clientSecret' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/repull/models/create_connection_request.rb', line 187 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/repull/models/create_connection_request.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/repull/models/create_connection_request.rb', line 78 def self.openapi_types { :'redirect_url' => :'String', :'access_type' => :'String', :'api_key' => :'String', :'client_id' => :'String', :'client_secret' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
162 163 164 165 166 167 168 169 170 |
# File 'lib/repull/models/create_connection_request.rb', line 162 def ==(o) return true if self.equal?(o) self.class == o.class && redirect_url == o.redirect_url && access_type == o.access_type && api_key == o.api_key && client_id == o.client_id && client_secret == o.client_secret end |
#eql?(o) ⇒ Boolean
174 175 176 |
# File 'lib/repull/models/create_connection_request.rb', line 174 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
180 181 182 |
# File 'lib/repull/models/create_connection_request.rb', line 180 def hash [redirect_url, access_type, api_key, client_id, client_secret].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/repull/models/create_connection_request.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/repull/models/create_connection_request.rb', line 209 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 |
# File 'lib/repull/models/create_connection_request.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' access_type_validator = EnumAttributeValidator.new('String', ["read_only", "full_access"]) return false unless access_type_validator.valid?(@access_type) true end |