Class: Repull::GenerateStudioCompletionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::GenerateStudioCompletionRequest
- Defined in:
- lib/repull/models/generate_studio_completion_request.rb
Instance Attribute Summary collapse
-
#max_tokens ⇒ Object
Maximum completion tokens.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#prompt ⇒ Object
User prompt.
-
#system_prompt ⇒ Object
Optional system prompt to steer the response.
-
#temperature ⇒ Object
Sampling temperature.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerateStudioCompletionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GenerateStudioCompletionRequest
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::GenerateStudioCompletionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::GenerateStudioCompletionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] else self.project_id = nil end if attributes.key?(:'prompt') self.prompt = attributes[:'prompt'] else self.prompt = nil end if attributes.key?(:'system_prompt') self.system_prompt = attributes[:'system_prompt'] end if attributes.key?(:'temperature') self.temperature = attributes[:'temperature'] end if attributes.key?(:'max_tokens') self.max_tokens = attributes[:'max_tokens'] end end |
Instance Attribute Details
#max_tokens ⇒ Object
Maximum completion tokens.
30 31 32 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 30 def max_tokens @max_tokens end |
#project_id ⇒ Object
Returns the value of attribute project_id.
18 19 20 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 18 def project_id @project_id end |
#prompt ⇒ Object
User prompt. Up to 32,000 characters.
21 22 23 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 21 def prompt @prompt end |
#system_prompt ⇒ Object
Optional system prompt to steer the response.
24 25 26 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 24 def system_prompt @system_prompt end |
#temperature ⇒ Object
Sampling temperature. Defaults to model preset.
27 28 29 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 27 def temperature @temperature end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 33 def self.attribute_map { :'project_id' => :'project_id', :'prompt' => :'prompt', :'system_prompt' => :'system_prompt', :'temperature' => :'temperature', :'max_tokens' => :'max_tokens' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 54 def self.openapi_types { :'project_id' => :'GenerateStudioCompletionRequestProjectId', :'prompt' => :'String', :'system_prompt' => :'String', :'temperature' => :'Float', :'max_tokens' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && project_id == o.project_id && prompt == o.prompt && system_prompt == o.system_prompt && temperature == o.temperature && max_tokens == o.max_tokens end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 260 def hash [project_id, prompt, system_prompt, temperature, max_tokens].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @prompt.nil? invalid_properties.push('invalid value for "prompt", prompt cannot be nil.') end if @prompt.to_s.length > 32000 invalid_properties.push('invalid value for "prompt", the character length must be smaller than or equal to 32000.') end if !@system_prompt.nil? && @system_prompt.to_s.length > 32000 invalid_properties.push('invalid value for "system_prompt", the character length must be smaller than or equal to 32000.') end if !@temperature.nil? && @temperature > 2 invalid_properties.push('invalid value for "temperature", must be smaller than or equal to 2.') end if !@temperature.nil? && @temperature < 0 invalid_properties.push('invalid value for "temperature", must be greater than or equal to 0.') end if !@max_tokens.nil? && @max_tokens > 16384 invalid_properties.push('invalid value for "max_tokens", must be smaller than or equal to 16384.') end if !@max_tokens.nil? && @max_tokens < 1 invalid_properties.push('invalid value for "max_tokens", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/repull/models/generate_studio_completion_request.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @project_id.nil? return false if @prompt.nil? return false if @prompt.to_s.length > 32000 return false if !@system_prompt.nil? && @system_prompt.to_s.length > 32000 return false if !@temperature.nil? && @temperature > 2 return false if !@temperature.nil? && @temperature < 0 return false if !@max_tokens.nil? && @max_tokens > 16384 return false if !@max_tokens.nil? && @max_tokens < 1 true end |