Class: Repull::Listing
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::Listing
- Defined in:
- lib/repull/models/listing.rb
Overview
A vacation rental listing in your Repull workspace.
Instance Attribute Summary collapse
-
#address ⇒ Object
Returns the value of attribute address.
-
#channels ⇒ Object
Channels (Airbnb, Booking, VRBO, etc.) the listing is connected to.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#id ⇒ Object
Repull listing id.
-
#name ⇒ Object
Returns the value of attribute name.
-
#status ⇒ Object
Returns the value of attribute status.
-
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Listing
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Listing
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/repull/models/listing.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::Listing` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::Listing`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'thumbnail_url') self.thumbnail_url = attributes[:'thumbnail_url'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'channels') if (value = attributes[:'channels']).is_a?(Array) self.channels = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end end |
Instance Attribute Details
#address ⇒ Object
Returns the value of attribute address.
24 25 26 |
# File 'lib/repull/models/listing.rb', line 24 def address @address end |
#channels ⇒ Object
Channels (Airbnb, Booking, VRBO, etc.) the listing is connected to.
31 32 33 |
# File 'lib/repull/models/listing.rb', line 31 def channels @channels end |
#created_at ⇒ Object
Returns the value of attribute created_at.
33 34 35 |
# File 'lib/repull/models/listing.rb', line 33 def created_at @created_at end |
#id ⇒ Object
Repull listing id
20 21 22 |
# File 'lib/repull/models/listing.rb', line 20 def id @id end |
#name ⇒ Object
Returns the value of attribute name.
22 23 24 |
# File 'lib/repull/models/listing.rb', line 22 def name @name end |
#status ⇒ Object
Returns the value of attribute status.
28 29 30 |
# File 'lib/repull/models/listing.rb', line 28 def status @status end |
#thumbnail_url ⇒ Object
Returns the value of attribute thumbnail_url.
26 27 28 |
# File 'lib/repull/models/listing.rb', line 26 def thumbnail_url @thumbnail_url end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
35 36 37 |
# File 'lib/repull/models/listing.rb', line 35 def updated_at @updated_at end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/repull/models/listing.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/repull/models/listing.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/repull/models/listing.rb', line 38 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'address' => :'address', :'thumbnail_url' => :'thumbnailUrl', :'status' => :'status', :'channels' => :'channels', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/repull/models/listing.rb', line 178 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 |
# File 'lib/repull/models/listing.rb', line 76 def self.openapi_nullable Set.new([ :'thumbnail_url', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/repull/models/listing.rb', line 62 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'address' => :'ListingAddress', :'thumbnail_url' => :'String', :'status' => :'String', :'channels' => :'Array<ListingChannel>', :'created_at' => :'Time', :'updated_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/repull/models/listing.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && address == o.address && thumbnail_url == o.thumbnail_url && status == o.status && channels == o.channels && created_at == o.created_at && updated_at == o.updated_at end |
#eql?(o) ⇒ Boolean
165 166 167 |
# File 'lib/repull/models/listing.rb', line 165 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
171 172 173 |
# File 'lib/repull/models/listing.rb', line 171 def hash [id, name, address, thumbnail_url, status, channels, created_at, updated_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/repull/models/listing.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/repull/models/listing.rb', line 200 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/repull/models/listing.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |