Class: Repull::ListingContent
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::ListingContent
- Defined in:
- lib/repull/models/listing_content.rb
Instance Attribute Summary collapse
-
#amenities ⇒ Object
Returns the value of attribute amenities.
-
#description ⇒ Object
Returns the value of attribute description.
-
#guest_access ⇒ Object
Returns the value of attribute guest_access.
-
#house_rules ⇒ Object
Returns the value of attribute house_rules.
-
#neighborhood_overview ⇒ Object
Returns the value of attribute neighborhood_overview.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#space ⇒ Object
Returns the value of attribute space.
-
#summary ⇒ Object
Returns the value of attribute summary.
-
#title ⇒ Object
Returns the value of attribute title.
-
#transit ⇒ Object
Returns the value of attribute transit.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ListingContent
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ListingContent
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/repull/models/listing_content.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::ListingContent` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::ListingContent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'summary') self.summary = attributes[:'summary'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'space') self.space = attributes[:'space'] end if attributes.key?(:'guest_access') self.guest_access = attributes[:'guest_access'] end if attributes.key?(:'neighborhood_overview') self.neighborhood_overview = attributes[:'neighborhood_overview'] end if attributes.key?(:'transit') self.transit = attributes[:'transit'] end if attributes.key?(:'notes') self.notes = attributes[:'notes'] end if attributes.key?(:'house_rules') self.house_rules = attributes[:'house_rules'] end if attributes.key?(:'amenities') if (value = attributes[:'amenities']).is_a?(Array) self.amenities = value end end end |
Instance Attribute Details
#amenities ⇒ Object
Returns the value of attribute amenities.
36 37 38 |
# File 'lib/repull/models/listing_content.rb', line 36 def amenities @amenities end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/repull/models/listing_content.rb', line 22 def description @description end |
#guest_access ⇒ Object
Returns the value of attribute guest_access.
26 27 28 |
# File 'lib/repull/models/listing_content.rb', line 26 def guest_access @guest_access end |
#house_rules ⇒ Object
Returns the value of attribute house_rules.
34 35 36 |
# File 'lib/repull/models/listing_content.rb', line 34 def house_rules @house_rules end |
#neighborhood_overview ⇒ Object
Returns the value of attribute neighborhood_overview.
28 29 30 |
# File 'lib/repull/models/listing_content.rb', line 28 def neighborhood_overview @neighborhood_overview end |
#notes ⇒ Object
Returns the value of attribute notes.
32 33 34 |
# File 'lib/repull/models/listing_content.rb', line 32 def notes @notes end |
#space ⇒ Object
Returns the value of attribute space.
24 25 26 |
# File 'lib/repull/models/listing_content.rb', line 24 def space @space end |
#summary ⇒ Object
Returns the value of attribute summary.
20 21 22 |
# File 'lib/repull/models/listing_content.rb', line 20 def summary @summary end |
#title ⇒ Object
Returns the value of attribute title.
18 19 20 |
# File 'lib/repull/models/listing_content.rb', line 18 def title @title end |
#transit ⇒ Object
Returns the value of attribute transit.
30 31 32 |
# File 'lib/repull/models/listing_content.rb', line 30 def transit @transit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/repull/models/listing_content.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/repull/models/listing_content.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/repull/models/listing_content.rb', line 39 def self.attribute_map { :'title' => :'title', :'summary' => :'summary', :'description' => :'description', :'space' => :'space', :'guest_access' => :'guestAccess', :'neighborhood_overview' => :'neighborhoodOverview', :'transit' => :'transit', :'notes' => :'notes', :'house_rules' => :'houseRules', :'amenities' => :'amenities' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/repull/models/listing_content.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/repull/models/listing_content.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/repull/models/listing_content.rb', line 65 def self.openapi_types { :'title' => :'String', :'summary' => :'String', :'description' => :'String', :'space' => :'String', :'guest_access' => :'String', :'neighborhood_overview' => :'String', :'transit' => :'String', :'notes' => :'String', :'house_rules' => :'String', :'amenities' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/repull/models/listing_content.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && title == o.title && summary == o.summary && description == o.description && space == o.space && guest_access == o.guest_access && neighborhood_overview == o.neighborhood_overview && transit == o.transit && notes == o.notes && house_rules == o.house_rules && amenities == o.amenities end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/repull/models/listing_content.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/repull/models/listing_content.rb', line 204 def hash [title, summary, description, space, guest_access, neighborhood_overview, transit, notes, house_rules, amenities].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 |
# File 'lib/repull/models/listing_content.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if !@title.nil? && @title.to_s.length > 50 invalid_properties.push('invalid value for "title", the character length must be smaller than or equal to 50.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/repull/models/listing_content.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
159 160 161 162 163 |
# File 'lib/repull/models/listing_content.rb', line 159 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if !@title.nil? && @title.to_s.length > 50 true end |