Class: Repull::PlumguideApi
- Inherits:
-
Object
- Object
- Repull::PlumguideApi
- Defined in:
- lib/repull/api/plumguide_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_plumguide_availability(opts = {}) ⇒ nil
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing.
-
#get_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing.
-
#get_plumguide_pricing(opts = {}) ⇒ nil
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
-
#get_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
-
#initialize(api_client = ApiClient.default) ⇒ PlumguideApi
constructor
A new instance of PlumguideApi.
-
#list_plumguide_listings(opts = {}) ⇒ PlumguideListingListResponse
List Plumguide listings List Plumguide listings this workspace has access to.
-
#list_plumguide_listings_with_http_info(opts = {}) ⇒ Array<(PlumguideListingListResponse, Integer, Hash)>
List Plumguide listings List Plumguide listings this workspace has access to.
-
#update_plumguide_availability(opts = {}) ⇒ nil
Push availability to Plumguide Push per-day availability changes to Plumguide.
-
#update_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push availability to Plumguide Push per-day availability changes to Plumguide.
-
#update_plumguide_pricing(opts = {}) ⇒ nil
Push pricing to Plumguide Push pricing changes to Plumguide.
-
#update_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push pricing to Plumguide Push pricing changes to Plumguide.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PlumguideApi
Returns a new instance of PlumguideApi.
19 20 21 |
# File 'lib/repull/api/plumguide_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/plumguide_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_plumguide_availability(opts = {}) ⇒ nil
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing. Returns the same row shape as Airbnb availability for SDK convenience.
26 27 28 29 |
# File 'lib/repull/api/plumguide_api.rb', line 26 def get_plumguide_availability(opts = {}) get_plumguide_availability_with_http_info(opts) nil end |
#get_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide availability Read the per-day availability calendar for a Plumguide listing. Returns the same row shape as Airbnb availability for SDK convenience.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/repull/api/plumguide_api.rb', line 35 def get_plumguide_availability_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.get_plumguide_availability ...' end # resource path local_var_path = '/v1/channels/plumguide/availability' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.get_plumguide_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#get_plumguide_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_plumguide_pricing(opts = {}) ⇒ nil
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
81 82 83 84 |
# File 'lib/repull/api/plumguide_api.rb', line 81 def get_plumguide_pricing(opts = {}) get_plumguide_pricing_with_http_info(opts) nil end |
#get_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get Plumguide pricing Read the current pricing for a Plumguide listing (base price, currency, weekend uplift).
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/repull/api/plumguide_api.rb', line 90 def get_plumguide_pricing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.get_plumguide_pricing ...' end # resource path local_var_path = '/v1/channels/plumguide/pricing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.get_plumguide_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#get_plumguide_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_plumguide_listings(opts = {}) ⇒ PlumguideListingListResponse
List Plumguide listings List Plumguide listings this workspace has access to. Plumguide is approval-based — listings appear once Plumguide has accepted them.
136 137 138 139 |
# File 'lib/repull/api/plumguide_api.rb', line 136 def list_plumguide_listings(opts = {}) data, _status_code, _headers = list_plumguide_listings_with_http_info(opts) data end |
#list_plumguide_listings_with_http_info(opts = {}) ⇒ Array<(PlumguideListingListResponse, Integer, Hash)>
List Plumguide listings List Plumguide listings this workspace has access to. Plumguide is approval-based — listings appear once Plumguide has accepted them.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/repull/api/plumguide_api.rb', line 145 def list_plumguide_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.list_plumguide_listings ...' end # resource path local_var_path = '/v1/channels/plumguide/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PlumguideListingListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.list_plumguide_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#list_plumguide_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_plumguide_availability(opts = {}) ⇒ nil
Push availability to Plumguide Push per-day availability changes to Plumguide. Plumguide accepts only the next 24 months — dates beyond that are silently ignored.
193 194 195 196 |
# File 'lib/repull/api/plumguide_api.rb', line 193 def update_plumguide_availability(opts = {}) update_plumguide_availability_with_http_info(opts) nil end |
#update_plumguide_availability_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push availability to Plumguide Push per-day availability changes to Plumguide. Plumguide accepts only the next 24 months — dates beyond that are silently ignored.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/repull/api/plumguide_api.rb', line 202 def update_plumguide_availability_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.update_plumguide_availability ...' end # resource path local_var_path = '/v1/channels/plumguide/availability' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.update_plumguide_availability", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#update_plumguide_availability\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_plumguide_pricing(opts = {}) ⇒ nil
Push pricing to Plumguide Push pricing changes to Plumguide. Plumguide rounds all prices to whole units of the listing currency — sub-unit precision is silently truncated.
248 249 250 251 |
# File 'lib/repull/api/plumguide_api.rb', line 248 def update_plumguide_pricing(opts = {}) update_plumguide_pricing_with_http_info(opts) nil end |
#update_plumguide_pricing_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Push pricing to Plumguide Push pricing changes to Plumguide. Plumguide rounds all prices to whole units of the listing currency — sub-unit precision is silently truncated.
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/repull/api/plumguide_api.rb', line 257 def update_plumguide_pricing_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PlumguideApi.update_plumguide_pricing ...' end # resource path local_var_path = '/v1/channels/plumguide/pricing' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"PlumguideApi.update_plumguide_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PlumguideApi#update_plumguide_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |