Class: Repull::Property
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::Property
- Defined in:
- lib/repull/models/property.rb
Overview
A vacation rental property from a connected PMS
Instance Attribute Summary collapse
-
#address ⇒ Object
Full address.
-
#amenities ⇒ Object
Amenity rows for the property.
-
#bathrooms ⇒ Object
Returns the value of attribute bathrooms.
-
#bedrooms ⇒ Object
Returns the value of attribute bedrooms.
-
#city ⇒ Object
Returns the value of attribute city.
-
#country ⇒ Object
Returns the value of attribute country.
-
#external_id ⇒ Object
ID in the source PMS.
-
#id ⇒ Object
Internal Repull property ID.
-
#latitude ⇒ Object
Returns the value of attribute latitude.
-
#longitude ⇒ Object
Returns the value of attribute longitude.
-
#max_guests ⇒ Object
Returns the value of attribute max_guests.
-
#name ⇒ Object
Property name.
-
#provider ⇒ Object
Source PMS.
-
#state ⇒ Object
Returns the value of attribute state.
-
#thumbnail ⇒ Object
Primary photo URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Property
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Property
Initializes the object
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/repull/models/property.rb', line 116 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::Property` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::Property`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'latitude') self.latitude = attributes[:'latitude'] end if attributes.key?(:'longitude') self.longitude = attributes[:'longitude'] end if attributes.key?(:'bedrooms') self.bedrooms = attributes[:'bedrooms'] end if attributes.key?(:'bathrooms') self.bathrooms = attributes[:'bathrooms'] end if attributes.key?(:'max_guests') self.max_guests = attributes[:'max_guests'] end if attributes.key?(:'thumbnail') self.thumbnail = attributes[:'thumbnail'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'amenities') if (value = attributes[:'amenities']).is_a?(Array) self.amenities = value end end end |
Instance Attribute Details
#address ⇒ Object
Full address
29 30 31 |
# File 'lib/repull/models/property.rb', line 29 def address @address end |
#amenities ⇒ Object
Amenity rows for the property. **Only present when the caller passes ‘?include=amenities`.** Empty array (`[]`) when the property has no amenity rows.
54 55 56 |
# File 'lib/repull/models/property.rb', line 54 def amenities @amenities end |
#bathrooms ⇒ Object
Returns the value of attribute bathrooms.
43 44 45 |
# File 'lib/repull/models/property.rb', line 43 def bathrooms @bathrooms end |
#bedrooms ⇒ Object
Returns the value of attribute bedrooms.
41 42 43 |
# File 'lib/repull/models/property.rb', line 41 def bedrooms @bedrooms end |
#city ⇒ Object
Returns the value of attribute city.
31 32 33 |
# File 'lib/repull/models/property.rb', line 31 def city @city end |
#country ⇒ Object
Returns the value of attribute country.
35 36 37 |
# File 'lib/repull/models/property.rb', line 35 def country @country end |
#external_id ⇒ Object
ID in the source PMS
23 24 25 |
# File 'lib/repull/models/property.rb', line 23 def external_id @external_id end |
#id ⇒ Object
Internal Repull property ID
20 21 22 |
# File 'lib/repull/models/property.rb', line 20 def id @id end |
#latitude ⇒ Object
Returns the value of attribute latitude.
37 38 39 |
# File 'lib/repull/models/property.rb', line 37 def latitude @latitude end |
#longitude ⇒ Object
Returns the value of attribute longitude.
39 40 41 |
# File 'lib/repull/models/property.rb', line 39 def longitude @longitude end |
#max_guests ⇒ Object
Returns the value of attribute max_guests.
45 46 47 |
# File 'lib/repull/models/property.rb', line 45 def max_guests @max_guests end |
#name ⇒ Object
Property name
26 27 28 |
# File 'lib/repull/models/property.rb', line 26 def name @name end |
#provider ⇒ Object
Source PMS
51 52 53 |
# File 'lib/repull/models/property.rb', line 51 def provider @provider end |
#state ⇒ Object
Returns the value of attribute state.
33 34 35 |
# File 'lib/repull/models/property.rb', line 33 def state @state end |
#thumbnail ⇒ Object
Primary photo URL
48 49 50 |
# File 'lib/repull/models/property.rb', line 48 def thumbnail @thumbnail end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/repull/models/property.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/repull/models/property.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/repull/models/property.rb', line 57 def self.attribute_map { :'id' => :'id', :'external_id' => :'externalId', :'name' => :'name', :'address' => :'address', :'city' => :'city', :'state' => :'state', :'country' => :'country', :'latitude' => :'latitude', :'longitude' => :'longitude', :'bedrooms' => :'bedrooms', :'bathrooms' => :'bathrooms', :'max_guests' => :'maxGuests', :'thumbnail' => :'thumbnail', :'provider' => :'provider', :'amenities' => :'amenities' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/repull/models/property.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
109 110 111 112 |
# File 'lib/repull/models/property.rb', line 109 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/repull/models/property.rb', line 88 def self.openapi_types { :'id' => :'String', :'external_id' => :'String', :'name' => :'String', :'address' => :'String', :'city' => :'String', :'state' => :'String', :'country' => :'String', :'latitude' => :'Float', :'longitude' => :'Float', :'bedrooms' => :'Integer', :'bathrooms' => :'Float', :'max_guests' => :'Integer', :'thumbnail' => :'String', :'provider' => :'String', :'amenities' => :'Array<ListingAmenity>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/repull/models/property.rb', line 210 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && external_id == o.external_id && name == o.name && address == o.address && city == o.city && state == o.state && country == o.country && latitude == o.latitude && longitude == o.longitude && bedrooms == o.bedrooms && bathrooms == o.bathrooms && max_guests == o.max_guests && thumbnail == o.thumbnail && provider == o.provider && amenities == o.amenities end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/repull/models/property.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/repull/models/property.rb', line 238 def hash [id, external_id, name, address, city, state, country, latitude, longitude, bedrooms, bathrooms, max_guests, thumbnail, provider, amenities].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
195 196 197 198 199 |
# File 'lib/repull/models/property.rb', line 195 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/repull/models/property.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 |
# File 'lib/repull/models/property.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |