Class: Repull::StudioGeneration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::StudioGeneration
- Defined in:
- lib/repull/models/studio_generation.rb
Overview
A single Repull AI generation run — captures the prompt, the model output, and token accounting.
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#generation_id ⇒ Object
Returns the value of attribute generation_id.
-
#model ⇒ Object
Model identifier used to produce the response.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#prompt ⇒ Object
Returns the value of attribute prompt.
-
#response ⇒ Object
Generated text output.
-
#tokens_in ⇒ Object
Prompt tokens consumed.
-
#tokens_out ⇒ Object
Completion tokens produced.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StudioGeneration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StudioGeneration
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/repull/models/studio_generation.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::StudioGeneration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::StudioGeneration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'generation_id') self.generation_id = attributes[:'generation_id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'prompt') self.prompt = attributes[:'prompt'] end if attributes.key?(:'response') self.response = attributes[:'response'] end if attributes.key?(:'tokens_in') self.tokens_in = attributes[:'tokens_in'] end if attributes.key?(:'tokens_out') self.tokens_out = attributes[:'tokens_out'] end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
37 38 39 |
# File 'lib/repull/models/studio_generation.rb', line 37 def created_at @created_at end |
#generation_id ⇒ Object
Returns the value of attribute generation_id.
19 20 21 |
# File 'lib/repull/models/studio_generation.rb', line 19 def generation_id @generation_id end |
#model ⇒ Object
Model identifier used to produce the response.
35 36 37 |
# File 'lib/repull/models/studio_generation.rb', line 35 def model @model end |
#project_id ⇒ Object
Returns the value of attribute project_id.
21 22 23 |
# File 'lib/repull/models/studio_generation.rb', line 21 def project_id @project_id end |
#prompt ⇒ Object
Returns the value of attribute prompt.
23 24 25 |
# File 'lib/repull/models/studio_generation.rb', line 23 def prompt @prompt end |
#response ⇒ Object
Generated text output.
26 27 28 |
# File 'lib/repull/models/studio_generation.rb', line 26 def response @response end |
#tokens_in ⇒ Object
Prompt tokens consumed.
29 30 31 |
# File 'lib/repull/models/studio_generation.rb', line 29 def tokens_in @tokens_in end |
#tokens_out ⇒ Object
Completion tokens produced.
32 33 34 |
# File 'lib/repull/models/studio_generation.rb', line 32 def tokens_out @tokens_out end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/repull/models/studio_generation.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/repull/models/studio_generation.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/repull/models/studio_generation.rb', line 40 def self.attribute_map { :'generation_id' => :'generation_id', :'project_id' => :'project_id', :'prompt' => :'prompt', :'response' => :'response', :'tokens_in' => :'tokens_in', :'tokens_out' => :'tokens_out', :'model' => :'model', :'created_at' => :'created_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/repull/models/studio_generation.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/repull/models/studio_generation.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/repull/models/studio_generation.rb', line 64 def self.openapi_types { :'generation_id' => :'String', :'project_id' => :'String', :'prompt' => :'String', :'response' => :'String', :'tokens_in' => :'Integer', :'tokens_out' => :'Integer', :'model' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/repull/models/studio_generation.rb', line 149 def ==(o) return true if self.equal?(o) self.class == o.class && generation_id == o.generation_id && project_id == o.project_id && prompt == o.prompt && response == o.response && tokens_in == o.tokens_in && tokens_out == o.tokens_out && model == o.model && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/repull/models/studio_generation.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/repull/models/studio_generation.rb', line 170 def hash [generation_id, project_id, prompt, response, tokens_in, tokens_out, model, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
134 135 136 137 138 |
# File 'lib/repull/models/studio_generation.rb', line 134 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/repull/models/studio_generation.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
142 143 144 145 |
# File 'lib/repull/models/studio_generation.rb', line 142 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |