Class: Repull::VRBOApi
- Inherits:
-
Object
- Object
- Repull::VRBOApi
- Defined in:
- lib/repull/api/vrbo_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ VRBOApi
constructor
A new instance of VRBOApi.
-
#list_vrbo_listings(opts = {}) ⇒ VrboListingListResponse
List VRBO listings List VRBO listings this workspace owns.
-
#list_vrbo_listings_with_http_info(opts = {}) ⇒ Array<(VrboListingListResponse, Integer, Hash)>
List VRBO listings List VRBO listings this workspace owns.
-
#list_vrbo_reservations(opts = {}) ⇒ VrboReservationListResponse
List VRBO reservations Cursor-paginated list of VRBO reservations sourced from the public booking feed.
-
#list_vrbo_reservations_with_http_info(opts = {}) ⇒ Array<(VrboReservationListResponse, Integer, Hash)>
List VRBO reservations Cursor-paginated list of VRBO reservations sourced from the public booking feed.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/vrbo_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#list_vrbo_listings(opts = {}) ⇒ VrboListingListResponse
List VRBO listings List VRBO listings this workspace owns. VRBO is agency-model — Repull reads listings via the public iCal/HTTP feeds.
26 27 28 29 |
# File 'lib/repull/api/vrbo_api.rb', line 26 def list_vrbo_listings(opts = {}) data, _status_code, _headers = list_vrbo_listings_with_http_info(opts) data end |
#list_vrbo_listings_with_http_info(opts = {}) ⇒ Array<(VrboListingListResponse, Integer, Hash)>
List VRBO listings List VRBO listings this workspace owns. VRBO is agency-model — Repull reads listings via the public iCal/HTTP feeds.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/repull/api/vrbo_api.rb', line 35 def list_vrbo_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.list_vrbo_listings ...' end # resource path local_var_path = '/v1/channels/vrbo/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VrboListingListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.list_vrbo_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#list_vrbo_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_vrbo_reservations(opts = {}) ⇒ VrboReservationListResponse
List VRBO reservations
Cursor-paginated list of VRBO reservations sourced from the public booking feed. Lag is typically 5-10 minutes vs. Airbnb / Booking.com. ?offset= is accepted as a first-class alias for ?cursor= (mutually exclusive; offset capped at 10000).
87 88 89 90 |
# File 'lib/repull/api/vrbo_api.rb', line 87 def list_vrbo_reservations(opts = {}) data, _status_code, _headers = list_vrbo_reservations_with_http_info(opts) data end |
#list_vrbo_reservations_with_http_info(opts = {}) ⇒ Array<(VrboReservationListResponse, Integer, Hash)>
List VRBO reservations Cursor-paginated list of VRBO reservations sourced from the public booking feed. Lag is typically 5-10 minutes vs. Airbnb / Booking.com. `?offset=` is accepted as a first-class alias for `?cursor=` (mutually exclusive; offset capped at 10000).
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/repull/api/vrbo_api.rb', line 100 def list_vrbo_reservations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.list_vrbo_reservations ...' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] > 10000 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling VRBOApi.list_vrbo_reservations, must be smaller than or equal to 10000.' end if @api_client.config.client_side_validation && !opts[:'offset'].nil? && opts[:'offset'] < 0 fail ArgumentError, 'invalid value for "opts[:"offset"]" when calling VRBOApi.list_vrbo_reservations, must be greater than or equal to 0.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] > 100 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VRBOApi.list_vrbo_reservations, must be smaller than or equal to 100.' end if @api_client.config.client_side_validation && !opts[:'limit'].nil? && opts[:'limit'] < 1 fail ArgumentError, 'invalid value for "opts[:"limit"]" when calling VRBOApi.list_vrbo_reservations, must be greater than or equal to 1.' end # resource path local_var_path = '/v1/channels/vrbo/reservations' # query parameters query_params = opts[:query_params] || {} query_params[:'cursor'] = opts[:'cursor'] if !opts[:'cursor'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'include_total'] = opts[:'include_total'] if !opts[:'include_total'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VrboReservationListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.list_vrbo_reservations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#list_vrbo_reservations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |