Class: Repull::VRBOApi
- Inherits:
-
Object
- Object
- Repull::VRBOApi
- Defined in:
- lib/repull/api/vrbo_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_vrbo_listing_pricing(id, opts = {}) ⇒ nil
Get VRBO pricing (501 — agency model) VRBO uses the agency model — VRBO PULLS rates from ‘/api/webhooks/vrbo/listings-xml/rates/listing/unit` rather than accepting a push API.
-
#get_vrbo_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get VRBO pricing (501 — agency model) VRBO uses the agency model — VRBO PULLS rates from `/api/webhooks/vrbo/listings-xml/rates/listing/unit` rather than accepting a push API.
-
#initialize(api_client = ApiClient.default) ⇒ VRBOApi
constructor
A new instance of VRBOApi.
-
#list_vrbo_listings(opts = {}) ⇒ VrboListingListResponse
List VRBO listings List VRBO listings this workspace owns.
-
#list_vrbo_listings_with_http_info(opts = {}) ⇒ Array<(VrboListingListResponse, Integer, Hash)>
List VRBO listings List VRBO listings this workspace owns.
-
#list_vrbo_reservations(opts = {}) ⇒ VrboReservationListResponse
List VRBO reservations List VRBO reservations sourced from the public booking feed.
-
#list_vrbo_reservations_with_http_info(opts = {}) ⇒ Array<(VrboReservationListResponse, Integer, Hash)>
List VRBO reservations List VRBO reservations sourced from the public booking feed.
-
#update_vrbo_listing_pricing(id, opts = {}) ⇒ nil
Update VRBO pricing (501 — no push API exists) VRBO has no rate-push API.
-
#update_vrbo_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update VRBO pricing (501 — no push API exists) VRBO has no rate-push API.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/repull/api/vrbo_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_vrbo_listing_pricing(id, opts = {}) ⇒ nil
Get VRBO pricing (501 — agency model) VRBO uses the agency model — VRBO PULLS rates from ‘/api/webhooks/vrbo/listings-xml/rates/listing/unit` rather than accepting a push API. This endpoint is declared for symmetry with the other channel-pricing routes but currently returns **501 Not Implemented** with a pointer at the public rate URL VRBO consumes. Use `GET /v1/listings/id/calendar` (once wired) to inspect the underlying source-of-truth. When the listings-XML rate-builder is ported into this repo, this endpoint will return the parsed rates VRBO sees.
27 28 29 30 |
# File 'lib/repull/api/vrbo_api.rb', line 27 def get_vrbo_listing_pricing(id, opts = {}) get_vrbo_listing_pricing_with_http_info(id, opts) nil end |
#get_vrbo_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Get VRBO pricing (501 — agency model) VRBO uses the agency model — VRBO PULLS rates from `/api/webhooks/vrbo/listings-xml/rates/listing/unit` rather than accepting a push API. This endpoint is declared for symmetry with the other channel-pricing routes but currently returns **501 Not Implemented** with a pointer at the public rate URL VRBO consumes. Use `GET /v1/listings/id/calendar` (once wired) to inspect the underlying source-of-truth. When the listings-XML rate-builder is ported into this repo, this endpoint will return the parsed rates VRBO sees.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/repull/api/vrbo_api.rb', line 37 def get_vrbo_listing_pricing_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.get_vrbo_listing_pricing ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling VRBOApi.get_vrbo_listing_pricing" end # resource path local_var_path = '/v1/channels/vrbo/listings/{id}/pricing'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.get_vrbo_listing_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#get_vrbo_listing_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_vrbo_listings(opts = {}) ⇒ VrboListingListResponse
List VRBO listings List VRBO listings this workspace owns. VRBO is agency-model — Repull reads listings via the public iCal/HTTP feeds.
89 90 91 92 |
# File 'lib/repull/api/vrbo_api.rb', line 89 def list_vrbo_listings(opts = {}) data, _status_code, _headers = list_vrbo_listings_with_http_info(opts) data end |
#list_vrbo_listings_with_http_info(opts = {}) ⇒ Array<(VrboListingListResponse, Integer, Hash)>
List VRBO listings List VRBO listings this workspace owns. VRBO is agency-model — Repull reads listings via the public iCal/HTTP feeds.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/repull/api/vrbo_api.rb', line 98 def list_vrbo_listings_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.list_vrbo_listings ...' end # resource path local_var_path = '/v1/channels/vrbo/listings' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VrboListingListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.list_vrbo_listings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#list_vrbo_listings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_vrbo_reservations(opts = {}) ⇒ VrboReservationListResponse
List VRBO reservations List VRBO reservations sourced from the public booking feed. Lag is typically 5-10 minutes vs. Airbnb / Booking.com.
146 147 148 149 |
# File 'lib/repull/api/vrbo_api.rb', line 146 def list_vrbo_reservations(opts = {}) data, _status_code, _headers = list_vrbo_reservations_with_http_info(opts) data end |
#list_vrbo_reservations_with_http_info(opts = {}) ⇒ Array<(VrboReservationListResponse, Integer, Hash)>
List VRBO reservations List VRBO reservations sourced from the public booking feed. Lag is typically 5-10 minutes vs. Airbnb / Booking.com.
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/repull/api/vrbo_api.rb', line 155 def list_vrbo_reservations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.list_vrbo_reservations ...' end # resource path local_var_path = '/v1/channels/vrbo/reservations' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VrboReservationListResponse' # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.list_vrbo_reservations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#list_vrbo_reservations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_vrbo_listing_pricing(id, opts = {}) ⇒ nil
Update VRBO pricing (501 — no push API exists) VRBO has no rate-push API. To change what VRBO sees, update the underlying Vanio calendar/pricing-settings (e.g. ‘PUT /v1/listings/id/calendar` once wired) — VRBO will pick up the change on its next pull. This endpoint always returns 501 rather than fake-stubbing a successful push the SDK would silently swallow.
204 205 206 207 |
# File 'lib/repull/api/vrbo_api.rb', line 204 def update_vrbo_listing_pricing(id, opts = {}) update_vrbo_listing_pricing_with_http_info(id, opts) nil end |
#update_vrbo_listing_pricing_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Update VRBO pricing (501 — no push API exists) VRBO has no rate-push API. To change what VRBO sees, update the underlying Vanio calendar/pricing-settings (e.g. `PUT /v1/listings/id/calendar` once wired) — VRBO will pick up the change on its next pull. This endpoint always returns 501 rather than fake-stubbing a successful push the SDK would silently swallow.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/repull/api/vrbo_api.rb', line 214 def update_vrbo_listing_pricing_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: VRBOApi.update_vrbo_listing_pricing ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling VRBOApi.update_vrbo_listing_pricing" end # resource path local_var_path = '/v1/channels/vrbo/listings/{id}/pricing'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['bearerAuth'] = opts.merge( :operation => :"VRBOApi.update_vrbo_listing_pricing", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: VRBOApi#update_vrbo_listing_pricing\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |