Class: Repull::WebhookDeliveryDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::WebhookDeliveryDetail
- Defined in:
- lib/repull/models/webhook_delivery_detail.rb
Overview
Full request + response capture for one delivery attempt. ‘payload` is the exact `WebhookEvent` envelope that was (or would have been) POSTed to the subscription URL.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attempt ⇒ Object
Returns the value of attribute attempt.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#error_message ⇒ Object
Returns the value of attribute error_message.
-
#event_id ⇒ Object
Returns the value of attribute event_id.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#id ⇒ Object
Returns the value of attribute id.
-
#payload ⇒ Object
Returns the value of attribute payload.
-
#request_headers ⇒ Object
Returns the value of attribute request_headers.
-
#response_body ⇒ Object
Returns the value of attribute response_body.
-
#response_headers ⇒ Object
Returns the value of attribute response_headers.
-
#response_time_ms ⇒ Object
Returns the value of attribute response_time_ms.
-
#status_code ⇒ Object
Returns the value of attribute status_code.
-
#success ⇒ Object
Returns the value of attribute success.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookDeliveryDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookDeliveryDetail
Initializes the object
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 129 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::WebhookDeliveryDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::WebhookDeliveryDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'event_id') self.event_id = attributes[:'event_id'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] end if attributes.key?(:'payload') self.payload = attributes[:'payload'] end if attributes.key?(:'request_headers') self.request_headers = attributes[:'request_headers'] end if attributes.key?(:'status_code') self.status_code = attributes[:'status_code'] end if attributes.key?(:'response_headers') self.response_headers = attributes[:'response_headers'] end if attributes.key?(:'response_body') self.response_body = attributes[:'response_body'] end if attributes.key?(:'response_time_ms') self.response_time_ms = attributes[:'response_time_ms'] end if attributes.key?(:'attempt') self.attempt = attributes[:'attempt'] end if attributes.key?(:'success') self.success = attributes[:'success'] end if attributes.key?(:'error_message') self. = attributes[:'error_message'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end end |
Instance Attribute Details
#attempt ⇒ Object
Returns the value of attribute attempt.
37 38 39 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 37 def attempt @attempt end |
#created_at ⇒ Object
Returns the value of attribute created_at.
43 44 45 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 43 def created_at @created_at end |
#error_message ⇒ Object
Returns the value of attribute error_message.
41 42 43 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 41 def @error_message end |
#event_id ⇒ Object
Returns the value of attribute event_id.
21 22 23 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 21 def event_id @event_id end |
#event_type ⇒ Object
Returns the value of attribute event_type.
23 24 25 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 23 def event_type @event_type end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 19 def id @id end |
#payload ⇒ Object
Returns the value of attribute payload.
25 26 27 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 25 def payload @payload end |
#request_headers ⇒ Object
Returns the value of attribute request_headers.
27 28 29 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 27 def request_headers @request_headers end |
#response_body ⇒ Object
Returns the value of attribute response_body.
33 34 35 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 33 def response_body @response_body end |
#response_headers ⇒ Object
Returns the value of attribute response_headers.
31 32 33 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 31 def response_headers @response_headers end |
#response_time_ms ⇒ Object
Returns the value of attribute response_time_ms.
35 36 37 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 35 def response_time_ms @response_time_ms end |
#status_code ⇒ Object
Returns the value of attribute status_code.
29 30 31 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 29 def status_code @status_code end |
#success ⇒ Object
Returns the value of attribute success.
39 40 41 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 39 def success @success end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 68 def self.attribute_map { :'id' => :'id', :'event_id' => :'eventId', :'event_type' => :'eventType', :'payload' => :'payload', :'request_headers' => :'requestHeaders', :'status_code' => :'statusCode', :'response_headers' => :'responseHeaders', :'response_body' => :'responseBody', :'response_time_ms' => :'responseTimeMs', :'attempt' => :'attempt', :'success' => :'success', :'error_message' => :'errorMessage', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 120 121 122 123 124 125 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 116 def self.openapi_nullable Set.new([ :'request_headers', :'status_code', :'response_headers', :'response_body', :'response_time_ms', :'error_message', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 97 def self.openapi_types { :'id' => :'String', :'event_id' => :'String', :'event_type' => :'WebhookEventType', :'payload' => :'WebhookEvent', :'request_headers' => :'Object', :'status_code' => :'Integer', :'response_headers' => :'Object', :'response_body' => :'String', :'response_time_ms' => :'Integer', :'attempt' => :'Integer', :'success' => :'Boolean', :'error_message' => :'String', :'created_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 213 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && event_id == o.event_id && event_type == o.event_type && payload == o.payload && request_headers == o.request_headers && status_code == o.status_code && response_headers == o.response_headers && response_body == o.response_body && response_time_ms == o.response_time_ms && attempt == o.attempt && success == o.success && == o. && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 239 def hash [id, event_id, event_type, payload, request_headers, status_code, response_headers, response_body, response_time_ms, attempt, success, , created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
198 199 200 201 202 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 198 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 |
# File 'lib/repull/models/webhook_delivery_detail.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |