Class: Repull::WebhookDeliveryDetail

Inherits:
ApiModelBase show all
Defined in:
lib/repull/models/webhook_delivery_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ WebhookDeliveryDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/repull/models/webhook_delivery_detail.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::WebhookDeliveryDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::WebhookDeliveryDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'event_id')
    self.event_id = attributes[:'event_id']
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  end

  if attributes.key?(:'payload')
    self.payload = attributes[:'payload']
  end

  if attributes.key?(:'request_headers')
    self.request_headers = attributes[:'request_headers']
  end

  if attributes.key?(:'status_code')
    self.status_code = attributes[:'status_code']
  end

  if attributes.key?(:'response_headers')
    self.response_headers = attributes[:'response_headers']
  end

  if attributes.key?(:'response_body')
    self.response_body = attributes[:'response_body']
  end

  if attributes.key?(:'response_time_ms')
    self.response_time_ms = attributes[:'response_time_ms']
  end

  if attributes.key?(:'attempt')
    self.attempt = attributes[:'attempt']
  end

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end
end

Instance Attribute Details

#attemptObject

Returns the value of attribute attempt.



36
37
38
# File 'lib/repull/models/webhook_delivery_detail.rb', line 36

def attempt
  @attempt
end

#created_atObject

Returns the value of attribute created_at.



42
43
44
# File 'lib/repull/models/webhook_delivery_detail.rb', line 42

def created_at
  @created_at
end

#error_messageObject

Returns the value of attribute error_message.



40
41
42
# File 'lib/repull/models/webhook_delivery_detail.rb', line 40

def error_message
  @error_message
end

#event_idObject

Returns the value of attribute event_id.



20
21
22
# File 'lib/repull/models/webhook_delivery_detail.rb', line 20

def event_id
  @event_id
end

#event_typeObject

Returns the value of attribute event_type.



22
23
24
# File 'lib/repull/models/webhook_delivery_detail.rb', line 22

def event_type
  @event_type
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/repull/models/webhook_delivery_detail.rb', line 18

def id
  @id
end

#payloadObject

Returns the value of attribute payload.



24
25
26
# File 'lib/repull/models/webhook_delivery_detail.rb', line 24

def payload
  @payload
end

#request_headersObject

Returns the value of attribute request_headers.



26
27
28
# File 'lib/repull/models/webhook_delivery_detail.rb', line 26

def request_headers
  @request_headers
end

#response_bodyObject

Returns the value of attribute response_body.



32
33
34
# File 'lib/repull/models/webhook_delivery_detail.rb', line 32

def response_body
  @response_body
end

#response_headersObject

Returns the value of attribute response_headers.



30
31
32
# File 'lib/repull/models/webhook_delivery_detail.rb', line 30

def response_headers
  @response_headers
end

#response_time_msObject

Returns the value of attribute response_time_ms.



34
35
36
# File 'lib/repull/models/webhook_delivery_detail.rb', line 34

def response_time_ms
  @response_time_ms
end

#status_codeObject

Returns the value of attribute status_code.



28
29
30
# File 'lib/repull/models/webhook_delivery_detail.rb', line 28

def status_code
  @status_code
end

#successObject

Returns the value of attribute success.



38
39
40
# File 'lib/repull/models/webhook_delivery_detail.rb', line 38

def success
  @success
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/repull/models/webhook_delivery_detail.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/repull/models/webhook_delivery_detail.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/repull/models/webhook_delivery_detail.rb', line 45

def self.attribute_map
  {
    :'id' => :'id',
    :'event_id' => :'eventId',
    :'event_type' => :'eventType',
    :'payload' => :'payload',
    :'request_headers' => :'requestHeaders',
    :'status_code' => :'statusCode',
    :'response_headers' => :'responseHeaders',
    :'response_body' => :'responseBody',
    :'response_time_ms' => :'responseTimeMs',
    :'attempt' => :'attempt',
    :'success' => :'success',
    :'error_message' => :'errorMessage',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/repull/models/webhook_delivery_detail.rb', line 223

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
102
# File 'lib/repull/models/webhook_delivery_detail.rb', line 93

def self.openapi_nullable
  Set.new([
    :'request_headers',
    :'status_code',
    :'response_headers',
    :'response_body',
    :'response_time_ms',
    :'error_message',
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/repull/models/webhook_delivery_detail.rb', line 74

def self.openapi_types
  {
    :'id' => :'String',
    :'event_id' => :'String',
    :'event_type' => :'String',
    :'payload' => :'Object',
    :'request_headers' => :'Object',
    :'status_code' => :'Integer',
    :'response_headers' => :'Object',
    :'response_body' => :'String',
    :'response_time_ms' => :'Integer',
    :'attempt' => :'Integer',
    :'success' => :'Boolean',
    :'error_message' => :'String',
    :'created_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/repull/models/webhook_delivery_detail.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      event_id == o.event_id &&
      event_type == o.event_type &&
      payload == o.payload &&
      request_headers == o.request_headers &&
      status_code == o.status_code &&
      response_headers == o.response_headers &&
      response_body == o.response_body &&
      response_time_ms == o.response_time_ms &&
      attempt == o.attempt &&
      success == o.success &&
      error_message == o.error_message &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


210
211
212
# File 'lib/repull/models/webhook_delivery_detail.rb', line 210

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



216
217
218
# File 'lib/repull/models/webhook_delivery_detail.rb', line 216

def hash
  [id, event_id, event_type, payload, request_headers, status_code, response_headers, response_body, response_time_ms, attempt, success, error_message, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
# File 'lib/repull/models/webhook_delivery_detail.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/repull/models/webhook_delivery_detail.rb', line 245

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
# File 'lib/repull/models/webhook_delivery_detail.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end