Class: Repull::WebhookSubscription
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- Repull::WebhookSubscription
- Defined in:
- lib/repull/models/webhook_subscription.rb
Overview
A registered webhook endpoint. The ‘secret` field is only present in the response of `POST /v1/webhooks` and `POST /v1/webhooks/#id/rotate-secret` (Stripe pattern — capture it then; it is masked everywhere else).
Instance Attribute Summary collapse
-
#api_version ⇒ Object
Returns the value of attribute api_version.
-
#consecutive_failures ⇒ Object
Returns the value of attribute consecutive_failures.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the value of attribute description.
-
#disabled_at ⇒ Object
Returns the value of attribute disabled_at.
-
#events ⇒ Object
Returns the value of attribute events.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_delivered_at ⇒ Object
Returns the value of attribute last_delivered_at.
-
#last_delivery_status ⇒ Object
Returns the value of attribute last_delivery_status.
-
#last_failure_at ⇒ Object
Returns the value of attribute last_failure_at.
-
#last_success_at ⇒ Object
Returns the value of attribute last_success_at.
-
#secret ⇒ Object
Plaintext signing secret.
-
#secret_masked ⇒ Object
Returns the value of attribute secret_masked.
-
#status ⇒ Object
Returns the value of attribute status.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookSubscription
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookSubscription
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/repull/models/webhook_subscription.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Repull::WebhookSubscription` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Repull::WebhookSubscription`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'events') if (value = attributes[:'events']).is_a?(Array) self.events = value end end if attributes.key?(:'api_version') self.api_version = attributes[:'api_version'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'consecutive_failures') self.consecutive_failures = attributes[:'consecutive_failures'] end if attributes.key?(:'last_delivered_at') self.last_delivered_at = attributes[:'last_delivered_at'] end if attributes.key?(:'last_success_at') self.last_success_at = attributes[:'last_success_at'] end if attributes.key?(:'last_failure_at') self.last_failure_at = attributes[:'last_failure_at'] end if attributes.key?(:'last_delivery_status') self.last_delivery_status = attributes[:'last_delivery_status'] end if attributes.key?(:'disabled_at') self.disabled_at = attributes[:'disabled_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'secret_masked') self.secret_masked = attributes[:'secret_masked'] end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end end |
Instance Attribute Details
#api_version ⇒ Object
Returns the value of attribute api_version.
27 28 29 |
# File 'lib/repull/models/webhook_subscription.rb', line 27 def api_version @api_version end |
#consecutive_failures ⇒ Object
Returns the value of attribute consecutive_failures.
31 32 33 |
# File 'lib/repull/models/webhook_subscription.rb', line 31 def consecutive_failures @consecutive_failures end |
#created_at ⇒ Object
Returns the value of attribute created_at.
43 44 45 |
# File 'lib/repull/models/webhook_subscription.rb', line 43 def created_at @created_at end |
#description ⇒ Object
Returns the value of attribute description.
23 24 25 |
# File 'lib/repull/models/webhook_subscription.rb', line 23 def description @description end |
#disabled_at ⇒ Object
Returns the value of attribute disabled_at.
41 42 43 |
# File 'lib/repull/models/webhook_subscription.rb', line 41 def disabled_at @disabled_at end |
#events ⇒ Object
Returns the value of attribute events.
25 26 27 |
# File 'lib/repull/models/webhook_subscription.rb', line 25 def events @events end |
#id ⇒ Object
Returns the value of attribute id.
19 20 21 |
# File 'lib/repull/models/webhook_subscription.rb', line 19 def id @id end |
#last_delivered_at ⇒ Object
Returns the value of attribute last_delivered_at.
33 34 35 |
# File 'lib/repull/models/webhook_subscription.rb', line 33 def last_delivered_at @last_delivered_at end |
#last_delivery_status ⇒ Object
Returns the value of attribute last_delivery_status.
39 40 41 |
# File 'lib/repull/models/webhook_subscription.rb', line 39 def last_delivery_status @last_delivery_status end |
#last_failure_at ⇒ Object
Returns the value of attribute last_failure_at.
37 38 39 |
# File 'lib/repull/models/webhook_subscription.rb', line 37 def last_failure_at @last_failure_at end |
#last_success_at ⇒ Object
Returns the value of attribute last_success_at.
35 36 37 |
# File 'lib/repull/models/webhook_subscription.rb', line 35 def last_success_at @last_success_at end |
#secret ⇒ Object
Plaintext signing secret. Only returned by create + rotate. Capture and store securely.
50 51 52 |
# File 'lib/repull/models/webhook_subscription.rb', line 50 def secret @secret end |
#secret_masked ⇒ Object
Returns the value of attribute secret_masked.
47 48 49 |
# File 'lib/repull/models/webhook_subscription.rb', line 47 def secret_masked @secret_masked end |
#status ⇒ Object
Returns the value of attribute status.
29 30 31 |
# File 'lib/repull/models/webhook_subscription.rb', line 29 def status @status end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
45 46 47 |
# File 'lib/repull/models/webhook_subscription.rb', line 45 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
21 22 23 |
# File 'lib/repull/models/webhook_subscription.rb', line 21 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/repull/models/webhook_subscription.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/repull/models/webhook_subscription.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/repull/models/webhook_subscription.rb', line 53 def self.attribute_map { :'id' => :'id', :'url' => :'url', :'description' => :'description', :'events' => :'events', :'api_version' => :'apiVersion', :'status' => :'status', :'consecutive_failures' => :'consecutiveFailures', :'last_delivered_at' => :'lastDeliveredAt', :'last_success_at' => :'lastSuccessAt', :'last_failure_at' => :'lastFailureAt', :'last_delivery_status' => :'lastDeliveryStatus', :'disabled_at' => :'disabledAt', :'created_at' => :'createdAt', :'updated_at' => :'updatedAt', :'secret_masked' => :'secretMasked', :'secret' => :'secret' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/repull/models/webhook_subscription.rb', line 256 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/repull/models/webhook_subscription.rb', line 107 def self.openapi_nullable Set.new([ :'description', :'last_delivered_at', :'last_success_at', :'last_failure_at', :'last_delivery_status', :'disabled_at', :'secret_masked', :'secret' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/repull/models/webhook_subscription.rb', line 85 def self.openapi_types { :'id' => :'String', :'url' => :'String', :'description' => :'String', :'events' => :'Array<String>', :'api_version' => :'String', :'status' => :'String', :'consecutive_failures' => :'Integer', :'last_delivered_at' => :'Time', :'last_success_at' => :'Time', :'last_failure_at' => :'Time', :'last_delivery_status' => :'Integer', :'disabled_at' => :'Time', :'created_at' => :'Time', :'updated_at' => :'Time', :'secret_masked' => :'String', :'secret' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/repull/models/webhook_subscription.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && url == o.url && description == o.description && events == o.events && api_version == o.api_version && status == o.status && consecutive_failures == o.consecutive_failures && last_delivered_at == o.last_delivered_at && last_success_at == o.last_success_at && last_failure_at == o.last_failure_at && last_delivery_status == o.last_delivery_status && disabled_at == o.disabled_at && created_at == o.created_at && updated_at == o.updated_at && secret_masked == o.secret_masked && secret == o.secret end |
#eql?(o) ⇒ Boolean
243 244 245 |
# File 'lib/repull/models/webhook_subscription.rb', line 243 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
249 250 251 |
# File 'lib/repull/models/webhook_subscription.rb', line 249 def hash [id, url, description, events, api_version, status, consecutive_failures, last_delivered_at, last_success_at, last_failure_at, last_delivery_status, disabled_at, created_at, updated_at, secret_masked, secret].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
205 206 207 208 209 |
# File 'lib/repull/models/webhook_subscription.rb', line 205 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/repull/models/webhook_subscription.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
213 214 215 216 |
# File 'lib/repull/models/webhook_subscription.rb', line 213 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |